@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005 Nicolas Hadacek <hadacek@kde.org>                  *
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -10,6 +10,7 @@
 #define CLI_LOG_H
 
 #include "common/global/log.h"
+#include "common/global/pfile.h"
 
 namespace CLI
 {
@@ -17,13 +18,18 @@ namespace CLI
 class View : public Log::View
 {
 public:
-  virtual void appendToLastLine(const QString &text);
+  View();
   virtual void clear() {}
   virtual void sorry(const QString &message, const QString &details);
   virtual bool askContinue(const QString &message);
   virtual void logUserAbort();
 
+  bool setLogFile(const PURL::Url& url);
+  void logInFile(Log::LineType type, const QString& text);
+
 private:
+  PURL::File _file;
+
   virtual void doLog(Log::LineType type, const QString &text, Log::Action action);
   virtual void doLog(Log::DebugLevel level, const QString &text, Log::Action action);
 };
