@@ -25,14 +25,14 @@ BEGIN_DECLARE_ENUM(Support)
 END_DECLARE_ENUM_KEY_LABEL(Support)
 
 //-----------------------------------------------------------------------------
-class Base
+class Base : public NoCopyClass
 {
 public:
   class Data {
   public:
-    Data() : data(0), support(Support::None) {}
-    const Device::Data *data;
-    Support support;
+    Data() : data(NULL), support(Support::None) {}
+    const Device::Data* data;
+    Support             support;
   };
   typedef QMap<QString, Data>::ConstIterator ConstIterator;
 
@@ -67,12 +67,12 @@ private:
 class BaseGui
 {
 public:
-  BaseGui() : _group(0) {}
+  BaseGui() : _group(NULL) {}
   virtual ~BaseGui() {}
-  const Base &group() const { return *_group; }
+  Base &group() const { return *_group; }
 
 private:
-  const Base *_group;
+  Base *_group;
 
   template <class GroupType> friend class Lister;
 };
