@@ -62,15 +62,15 @@ public: \
   } \
   QString key() const { \
     if ( _value==Nb_Types ) return QString::null; \
-    Q_ASSERT(DATA[_value].key); \
+    ASSERT(DATA[_value].key); \
     return DATA[_value].key; \
   }
 
 #define DECLARE_LABEL_METHODS \
 public: \
   QString label() const { \
-    CRASH_ASSERT( _value!=Nb_Types ); \
-    Q_ASSERT(DATA[_value].label); \
+    ASSERT( _value!=Nb_Types ); \
+    ASSERT(DATA[_value].label); \
     return i18n(DATA[_value].label); \
   } \
   QString semicolonLabel() const { return i18n("%1:").arg(label()); } \
@@ -79,7 +79,7 @@ public: \
 #define DECLARE_DATA \
 public: \
   const Data &data() const { \
-    CRASH_ASSERT( _value!=Nb_Types ); \
+    ASSERT( _value!=Nb_Types ); \
     return DATA[_value]; \
   } \
   private: \
@@ -87,7 +87,7 @@ public: \
 
 #define DECLARE_ENUM_CLASS(Enum) \
 public: \
-  Enum(Type value = Type(0)) : GenericEnum(value) { Q_ASSERT( value>=0 && value<=Type(Nb_Types)); } \
+  Enum(Type value = Type(0)) : GenericEnum(value) { ASSERT( value>=0 && value<=Type(Nb_Types)); } \
   Type type() const { return Type(_value); } \
 };
 
@@ -142,13 +142,13 @@ class ClassName \
 public: \
   typedef Typename Data; \
   enum { Nb_Types = Enum::Nb_Types }; \
-  static Data const data(Enum type) { \
-    Q_ASSERT( type.type()<Enum::Nb_Types ); \
+  static const Data& data(Enum type) { \
+    ASSERT( type.type()<Enum::Nb_Types ); \
     return DATA[type.type()]; \
   } \
 \
 private: \
-  static Data const DATA[Enum::Nb_Types]; \
+  static const Data DATA[Enum::Nb_Types]; \
 };
 
 template <typename Enum, typename Type>
