@@ -18,9 +18,10 @@ template <class GroupType>
 class Lister
 {
 public:
+  typedef GroupType Group;
   typedef typename QMap<QString, const GroupType *>::ConstIterator ConstIterator;
   ConstIterator begin() const { return ConstIterator(_groups.begin()); }
-  ConstIterator end() const { return ConstIterator(_groups.end()); }
+  ConstIterator end() const   { return ConstIterator(_groups.end()); }
 
   virtual ~Lister() {
     for (ConstIterator it=begin(); it!=end(); ++it) delete it.data();
@@ -52,16 +53,16 @@ public:
 
 protected:
   void addGroup(GroupType *group, BaseGui *gui) {
-    Q_ASSERT(group);
+    ASSERT(group != NULL);
     group->_gui = gui;
-    if (gui) gui->_group = group;
+    if (gui != NULL) gui->_group = group;
     group->init();
-    Q_ASSERT( !_groups.contains(group->name()) );
+    ASSERT( !_groups.contains(group->name()) );
     _groups.insert(group->name(), group);
   }
 
 private:
-  QMap<QString, const GroupType *> _groups;
+  QMap<QString, const GroupType*> _groups;
 };
 
 } // namespace
