@@ -11,6 +11,7 @@
 
 #include <qstring.h>
 
+//----------------------------------------------------------------------------
 inline QString repeat(const char *r, uint nb)
 {
   QString s;
@@ -33,9 +34,22 @@ extern Q_UINT32 getULong(const QByteArray &data, uint offset, uint nbBytes, bool
 
 extern QString escapeXml(const QString &s);
 extern QString htmlTableRow(const QString &title, const QString &value);
-extern void crash(const char *assert, const char *file, int line);
-#define CRASH_ASSERT(x) ((x) ? void(0) : crash(#x, __FILE__, __LINE__))
+extern void piklabAssert(const char* s, const char* file, int line);
+#undef ASSERT
+#define ASSERT(x) ((x) ? void(0) : piklabAssert(#x, __FILE__, __LINE__))
 
 extern QString formatDouble(double v, uint precision);
+extern const char* stringToChar(const QString &s);
+
+//----------------------------------------------------------------------------
+class NoCopyClass
+{
+  public:
+    NoCopyClass() {}
+
+  private:
+    NoCopyClass(const NoCopyClass&);
+    NoCopyClass& operator=(const NoCopyClass&);
+};
 
 #endif
