@@ -23,7 +23,9 @@ public slots:
   void done();
 
 private:
-  QTimer _timer;
+  enum State { Stopped, Running, Done };
+  State _state;
+  QTimer *_timer;
 #if QT_VERSION>=0x040000
   QEventLoop *_loop;
 #endif
