@@ -14,6 +14,8 @@
 #  include "svn_revision/svn_revision.h"
 #endif
 
+#include "process.h"
+
 //---------------------------------------------------------------------------
 const Piklab::UrlType::Data Piklab::UrlType::DATA[Nb_Types] = {
   { "http://piklab.sourceforge.net"                                        },
@@ -23,7 +25,7 @@ const Piklab::UrlType::Data Piklab::UrlType::DATA[Nb_Types] = {
 
 //-----------------------------------------------------------------------------
 Piklab::OptionList::OptionList(const KCmdLineOptions *options)
-  : _options(0)
+: _options(NULL)
 {
   for (uint i=0; options[i].name; i++) append(options[i]);
 }
@@ -34,51 +36,80 @@ const KCmdLineOptions *Piklab::OptionList::ptr() const
   _options = new KCmdLineOptions[count()+1];
   for (uint i=0; i<uint(count()); i++) {
     _options[i] = *at(i);
-    Q_ASSERT( _options[i].name );
+    Q_ASSERT(_options[i].name != NULL);
   }
-  _options[count()].name = 0;
+  _options[count()].name = NULL;
   return _options;
 }
 
 //-----------------------------------------------------------------------------
-void Piklab::init(KAboutData *about, int argc, char **argv, bool gui, const KCmdLineOptions *options)
+void Piklab::initArgs(const KAboutData& about, int argc, char **argv, const KCmdLineOptions& options)
+{
+  KCmdLineArgs::init(argc, argv, &about);
+  KCmdLineArgs::addCmdLineOptions(&options);
+}
+
+void Piklab::createApplication(const char* executable, int argc, char **argv,
+                               bool gui, Log::Generic* log)
 {
-  Q_ASSERT(about);
-#if defined(NO_KDE)
-#  if defined(Q_OS_WIN)
-  printf("%s \"win32\": version %s\n", about->appName(), VERSION);
-#  else
-  printf("%s \"qt-only\": version %s (rev. %s)\n", about->appName(), VERSION, SVN_REVISION);
-#  endif
-  Q_UNUSED(gui);
-  Q_ASSERT( !gui );
-#else
-  printf("%s: version %s (rev. %s)\n", about->appName(), VERSION, SVN_REVISION);
-  if ( !gui ) KApplication::disableAutoDcopRegistration();
-#endif
-  KCmdLineArgs::init(argc, argv, about);
-  KCmdLineArgs::addCmdLineOptions(options);
 #if defined(NO_KDE)
 #  if QT_VERSION<0x040000
   (void)new QApplication(argc, argv, QApplication::Tty);
 #  else
   (void)new QCoreApplication(argc, argv);
 #  endif
+  Q_UNUSED(gui);
 #else
+  if (!gui) KApplication::disableAutoDcopRegistration();
   (void)new KApplication(gui, gui);
+  Q_UNUSED(argc);
+  Q_UNUSED(argv);
 #endif
+
+  QString version = executable;
+#if defined(NO_KDE)
+#  if defined(Q_OS_WIN)
+  version += "\"win32\"";
+#  else
+  version += "\"qt-only\"";
+#  endif
+#endif
+  version += QString(": version ") + VERSION + " (rev. " + SVN_REVISION + ")";
+  if (log != NULL) {
+    log->log(Log::LineType::Comment, version);
+    Process::LineOutput process;
+    QStringList args;
+    args += "-srmpo";
+    process.setup("uname", args, false);
+    Process::State state = Process::runSynchronously(process, Process::Start, 100);
+    if (state == Process::Exited) {
+      QStringList lines = process.lines(Process::OutputType::Stdout);
+      if (!lines.isEmpty() && !lines[0].isEmpty())
+        log->log(Log::LineType::Comment, lines[0], Log::LogFileOnly);
+    }
+    process.setup("date", QStringList(), false);
+    state = Process::runSynchronously(process, Process::Start, 100);
+    if (state == Process::Exited) {
+      QStringList lines = process.lines(Process::OutputType::Stdout);
+      if (!lines.isEmpty() && !lines[0].isEmpty())
+        log->log(Log::LineType::Comment, lines[0], Log::LogFileOnly);
+    }
+  } else {
+    version += "\n";
+    fprintf(stdout, stringToChar(version));
+  }
 }
 
 //---------------------------------------------------------------------------
 Piklab::AboutData::AboutData(const char *executable, const char *name,
-			     const char *description)
-  : KAboutData(executable, name, VERSION, description, KAboutData::License_GPL,
-               "(c) 2005-2007 Nicolas Hadacek\n(c) 2002-2005 Alain Gibaud\n(c) 2003-2004 Stephen Landamore\n(c) 2005 Lorenz Möenlechner and Matthias Kranz\n(c) 2001-2005 Craig Franklin",
-               0, UrlType(UrlType::Homepage).data().url, UrlType(UrlType::BugReport).data().url)
+                             const char *description)
+: KAboutData(executable, name, VERSION, description, KAboutData::License_GPL,
+             "(c) 2005-2009 Nicolas Hadacek\n(c) 2002-2005 Alain Gibaud\n(c) 2003-2004 Stephen Landamore\n(c) 2005 Lorenz Möenlechner and Matthias Kranz\n(c) 2001-2005 Craig Franklin",
+             0, UrlType(UrlType::Homepage).data().url, UrlType(UrlType::BugReport).data().url)
 {
   addAuthor("Nicolas Hadacek", I18N_NOOP("Author and maintainer."), "hadacek@kde.org");
-  addAuthor("Alain Gibaud", I18N_NOOP("Original author of PiKdev."), "alain.gibaud@free.fr");
-  addAuthor("Stephen Landamore", I18N_NOOP("LPLAB author (original microchip programmer support)."), "webmaster@landamore.com");
+  addAuthor("Alain Gibaud", I18N_NOOP("Author of PiKdev."), "alain.gibaud@free.fr");
+  addAuthor("Stephen Landamore", I18N_NOOP("Author of LPLAB (original Microchip programmer support)."), "webmaster@landamore.com");
   addAuthor("Craig Franklin", I18N_NOOP("Author of gputils"), "craigfranklin@users.sourceforge.net");
   addAuthor("Sébastien Laoût", I18N_NOOP("Author of likeback"), "slaout@linux62.org");
 
