@@ -11,6 +11,7 @@
 
 #include "global.h"
 #include "common/common/key_enum.h"
+#include "log.h"
 
 namespace Piklab
 {
@@ -26,7 +27,7 @@ END_DECLARE_ENUM_DATA_ONLY(UrlType, UrlTypeData)
 class OptionList : public QValueList<KCmdLineOptions>
 {
 public:
-  OptionList() : _options(0) {}
+  OptionList() : _options(NULL) {}
   OptionList(const KCmdLineOptions *options);
   virtual ~OptionList() { delete[] _options; }
   const KCmdLineOptions *ptr() const;
@@ -36,7 +37,8 @@ private:
 };
 
 //-----------------------------------------------------------------------------
-extern void init(KAboutData *about, int argc, char **argv, bool gui, const KCmdLineOptions *options);
+void initArgs(const KAboutData& aboutData, int argc, char** argv, const KCmdLineOptions& options);
+void createApplication(const char *executable, int argc, char **argv, bool gui, Log::Generic* log);
 
 //-----------------------------------------------------------------------------
 class AboutData : public KAboutData
