@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2008 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -189,6 +189,23 @@ QString Process::StringOutput::allOutputs()
 }
 
 //----------------------------------------------------------------------------
+void filterControlSequence(QString &s)
+{
+    for (uint i=0; i<uint(s.length()); ++i) {
+        if (s[i] == char(0x1B) // ESC
+            && (i+1)<uint(s.length())
+            && s[i+1] == '[') {
+            // terminal control sequence
+            for (uint k=i+2; k<uint(s.length()); ++k) {
+                if (s[k]>=char(0x40) && s[k]<=char(0x7E)) { // end of sequence character
+                    s.remove(i, k-i+1);
+                    break;
+                }
+            }
+        }
+    }
+}
+
 QStringList received(const QString &s, QString &buffer)
 {
   buffer += s;
@@ -196,6 +213,9 @@ QStringList received(const QString &s, QString &buffer)
   QStringList lines = QStringList::split('\n', buffer, true);
   if ( lines.isEmpty() ) buffer = QString::null;
   else {
+    for (QStringList::iterator it=lines.begin(); it!=lines.end(); ++it) {
+      filterControlSequence(*it);
+    }
     buffer = lines.last();
     lines.pop_back();
   }
@@ -206,10 +226,11 @@ void Process::LineBase::received(OutputType type, const QString &s)
 {
   QString& sout  = _outputs[type];
   QStringList lines = ::received(s, sout);
-  for (QStringList::const_iterator it=lines.begin(); it!=lines.end(); ++it)
+  for (QStringList::const_iterator it=lines.begin(); it!=lines.end(); ++it) {
     if ( !isFilteredLine(*it) ) {
       addLine(type, *it);
     }
+  }
   if ( !_process->isRunning() && !isFilteredLine(sout) ) addLine(type, sout);
 }
 
@@ -227,3 +248,7 @@ void Process::LineOutput::clearOutputs()
   FOR_EACH(OutputType, type) _lines[type].clear();
 }
 
+void Process::LineOutput::addLine(OutputType type, const QString &line)
+{
+    _lines[type] += line;
+}
