@@ -138,7 +138,7 @@ public:
 protected:
   EnumVector<OutputType, QStringList> _lines;
 
-  virtual void addLine(OutputType type, const QString &line) { _lines[type] += line; }
+  virtual void addLine(OutputType type, const QString &line);
 };
 
 //----------------------------------------------------------------------------
