@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2006 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -41,12 +41,13 @@ namespace PURL
 class Private
 {
 public:
-  static Private *self();
-  QString convertWindowsFilepath(const QString &filepath);
+  static QString convertWindowsFilepath(const QString &filepath);
 
 private:
   Private();
-  static Private *_self;
+  static Private& self();
+
+  static Private* _self;
   QString _winDrivesPath;           // root Windows drives
   QMap<QString, QString> _winPaths; // Windows path -> Unix path
 
@@ -59,8 +60,6 @@ private:
 
 } // namespace
 
-PURL::Private *PURL::Private::_self = 0;
-
 PURL::Private::Private()
 {
   QStringList args;
@@ -79,10 +78,12 @@ PURL::Private::Private()
   }
 }
 
-PURL::Private *PURL::Private::self()
+PURL::Private* PURL::Private::_self = NULL;
+
+PURL::Private& PURL::Private::self()
 {
-  if ( _self==0 ) _self = new Private;
-  return _self;
+  if (_self == NULL) _self = new Private;
+  return *_self;
 }
 
 bool PURL::Private::checkCachedPath(QString &filepath) const
@@ -100,18 +101,19 @@ QString PURL::Private::cachePath(const QString &origin, const QString &filepath)
 
 QString PURL::Private::convertWindowsFilepath(const QString &filepath)
 {
-  // cached
   QString tmp = filepath;
-  if ( checkCachedPath(tmp) ) return tmp;
   tmp.replace('\\', "/");
 
+  // cached
+  if (_self != NULL && _self->checkCachedPath(tmp)) return tmp;
+
   // appears to be an absolute Windows path
-  if ( filepath[0]=='\\' ) return cachePath(filepath, convertWindowsShortFilepath(tmp));
+  if ( filepath[0]=='\\' ) return self().cachePath(filepath, self().convertWindowsShortFilepath(tmp));
 
   // appears to be a windows path with a drive
   if ( (tmp.length()>=2 && tmp[0].isLetter() && tmp[1]==':') ) {
-    tmp = _winDrivesPath + "/" + tmp[0].lower() + ":" + tmp.mid(2);
-    return cachePath(filepath, convertWindowsShortFilepath(tmp));
+    tmp = self()._winDrivesPath + "/" + tmp[0].lower() + ":" + tmp.mid(2);
+    return self().cachePath(filepath, self().convertWindowsShortFilepath(tmp));
   }
 
   return filepath;
@@ -173,7 +175,7 @@ PURL::Base::Base(const QString &filepath)
 {
   if ( !filepath.isEmpty() ) {
 #if defined(Q_OS_UNIX)
-    QString tmp = Private::self()->convertWindowsFilepath(filepath);
+    QString tmp = Private::convertWindowsFilepath(filepath);
 #else
     QString tmp = filepath;
 #endif
@@ -211,7 +213,7 @@ bool PURL::Base::operator ==(const Base &url) const
 QString PURL::Base::path(TerminationType ttype, SeparatorType stype) const
 {
 #if defined(NO_KDE)
-  QString s = _url.dirPath();
+  QString s = _url.dirPath().stripWhiteSpace();
   switch (ttype) {
     case Terminated:
       if ( !s.isEmpty() && !s.endsWith("/") ) s += '/';
@@ -230,7 +232,7 @@ QString PURL::Base::path(TerminationType ttype, SeparatorType stype) const
         if ( s[i]=='/' ) s[i] = '\\';
       break;
   }
-  return s;
+  return s.stripWhiteSpace();
 }
 
 QString PURL::Base::pretty() const
@@ -299,13 +301,6 @@ bool PURL::Base::exists(QDateTime *lastModified) const
 }
 
 //----------------------------------------------------------------------------
-PURL::Url PURL::Url::fromPathOrUrl(const QString &s)
-{
-  KURL kurl = KURL::fromPathOrURL(s);
-  if ( !kurl.protocol().isEmpty() && kurl.protocol()!="file" && kurl.protocol().length()!=1 ) return kurl;
-  return Url(s.startsWith("file://") ? s.mid(7) : s);
-}
-
 PURL::Url::Url(const Directory &dir, const QString &filename, FileType type)
   : Base(dir.path() + '/' + addExtension(filename, type))
 {}
@@ -422,7 +417,26 @@ PURL::Url PURL::Directory::findMatchingFilename(const QString &filename) const
   return Url(*this, filename);
 }
 
-PURL::Directory PURL::Directory::current()
+//-----------------------------------------------------------------------------
+bool PURL::isRelative(const QString &filepath)
+{
+  Base base(filepath);
+  return base.isRelative();
+}
+
+PURL::Directory PURL::currentDirectory()
 {
   return QDir::currentDirPath();
 }
+
+PURL::Url PURL::fromPathOrUrl(const QString &s, bool keepRelative)
+{
+  if (s.isEmpty()) return PURL::Url();
+  KURL kurl = KURL::fromPathOrURL(s);
+  if (!kurl.protocol().isEmpty()
+       && kurl.protocol() != "file"
+       && kurl.protocol().length() != 1) return kurl;
+  QString filepath = (s.startsWith("file://") ? s.mid(7) : s);
+  if (isRelative(filepath) && !keepRelative) return Url(currentDirectory(), filepath);
+  return Url(filepath);
+}
