@@ -15,6 +15,7 @@
 #include <qvaluevector.h>
 #include <qvariant.h>
 
+#include "common/common/misc.h"
 #include "container.h"
 
 //-----------------------------------------------------------------------------
@@ -23,7 +24,7 @@ class ConfigWidget : public Container::Grid
 Q_OBJECT
 public:
   ConfigWidget(QWidget *parent = 0) : Container::Grid(parent) {}
-  virtual QString title() const { return QString::null; }
+  virtual QString title() const  { return QString::null; }
   virtual QString header() const { return QString::null; }
   virtual QPixmap pixmap() const { return QPixmap(); }
 
@@ -62,7 +63,7 @@ private:
         w = new QCheckBox(type.label(), widget);
         widget->addWidget(w, row,row, 0,1);
         break;
-      default: Q_ASSERT(false); break;
+      default: ASSERT(false); break;
     }
     return w;
   }
@@ -71,7 +72,7 @@ private:
       case QVariant::Bool:
         static_cast<QCheckBox *>(widget)->setChecked(readConfigEntry(type).toBool());
         break;
-      default: Q_ASSERT(false); break;
+      default: ASSERT(false); break;
     }
   }
   void save(Type type, QWidget *widget) {
@@ -79,7 +80,7 @@ private:
       case QVariant::Bool:
         writeConfigEntry(type, QVariant(static_cast<QCheckBox *>(widget)->isChecked(), 0));
         break;
-      default: Q_ASSERT(false); break;
+      default: ASSERT(false); break;
     }
   }
   void setDefault(Type type, QWidget *widget) const {
@@ -87,7 +88,7 @@ private:
       case QVariant::Bool:
         static_cast<QCheckBox *>(widget)->setChecked(type.data().defValue.toBool());
         break;
-      default: Q_ASSERT(false); break;
+      default: ASSERT(false); break;
     }
   }
 };
