@@ -67,7 +67,7 @@
 #endif
 
 #ifdef Q_WS_WIN
-#include <win32_utils.h>
+#include "win32_utils.h"
 #endif
 
 template class QAsciiDict<QCString>;
