@@ -113,7 +113,7 @@ void Device::Array::append(uint v)
 
 Device::Array Device::Array::mid(uint index, int s) const
 {
-  CRASH_ASSERT( index<=size() && s<=int(size()-index) && s>=-1 );
+  ASSERT( index<=size() && s<=int(size()-index) && s>=-1 );
   Array array(s==-1 ? size()-index : s);
   for (uint i=0; i<array.size(); i++) array[i] = _data[index+i];
   return array;
