@@ -19,5 +19,5 @@ void Device::HexView::display(Memory *memory)
   for (uint i=0; i<_editors.count(); i++) delete _editors[i];
   _editors.clear();
   if ( _memory==0 ) return;
-  display();
+  internalDisplay();
 }
