@@ -28,7 +28,7 @@ public:
   const Memory *originalMemory() const { return _editor.originalMemory(); }
 
 protected:
-  virtual void display() = 0;
+  virtual void internalDisplay() = 0;
 
 private:
   const HexEditor &_editor;
