@@ -13,8 +13,6 @@
 #include "devices/pic/pic/pic_group.h"
 #include "devices/mem24/mem24/mem24_group.h"
 
-const Device::AutoData Device::AUTO_DATA = { "*", I18N_NOOP("<auto>") };
-
 const Device::Data *Device::Lister::data(const QString &device) const
 {
   for (ConstIterator it=begin(); it!=end(); it++) {
@@ -26,7 +24,6 @@ const Device::Data *Device::Lister::data(const QString &device) const
 
 QString Device::Lister::checkName(const QString &device) const
 {
-  if ( device==AUTO_DATA.name ) return device;
   if ( isSupported(device) ) return device;
   if ( device.startsWith("p") ) // compat mode for PiKdev
     return checkName(device.mid(1));
