@@ -15,11 +15,6 @@
 namespace Device
 {
 
-struct AutoData {
-  const char *name, *label;
-};
-extern const AutoData AUTO_DATA;
-
 class Lister : public ::Group::Lister<GroupBase>
 {
 public:
