@@ -18,7 +18,7 @@ Mem24::HexView::HexView(const HexEditor &editor, QWidget *parent)
   : Device::HexView(editor, parent, "mem24_hex_view")
 {}
 
-void Mem24::HexView::display()
+void Mem24::HexView::internalDisplay()
 {
   Memory *pmemory = static_cast<Memory *>(_memory);
   MemoryTypeEditor *e = new MemoryTypeEditor(this, *pmemory, this);
