@@ -48,7 +48,7 @@ const Pic::Architecture::Data Pic::Architecture::DATA[Nb_Types] = {
   { "24F", I18N_NOOP("24F Family"),      23, 4, 16, 0x800, { 24,  0,  0, 16, 24,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 },
   { "24H", I18N_NOOP("24H Family"),      23, 4, 16, 0x800, { 24,  0,  8, 16,  8,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 },
   { "30F", I18N_NOOP("30F Family"),      23, 4, 16, 0xA00, { 24,  0, 24, 16, 16, 16, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite, 5.0 }, // dsPIC: eeprom max = 2 kwords = 4 kbytes
-  { "33F", I18N_NOOP("33F Family"),      23, 4, 16, 0x800, { 24,  0,  8, 16,  8,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 }
+  { "33F", I18N_NOOP("33F Family"),      23, 4, 16, 0x800, { 24,  0, 16, 16, 16,  0, 24,  0,  0, 24 }, RandomMemoryAccess | SelfWrite | JFamily, 3.3 }
 };
 
 const Pic::Checksum::Algorithm::Data Pic::Checksum::Algorithm::DATA[Nb_Types] = {
@@ -97,6 +97,7 @@ Pic::Data::Data()
 Pic::Data::~Data()
 {
   delete _config;
+  _config = NULL;
 }
 
 bool Pic::Data::isReadable(MemoryRangeType type) const
@@ -335,13 +336,26 @@ bool Pic::Data::isGotoInstruction(BitValue instruction) const
 uint Pic::Data::nbWordsWriteAlignment(MemoryRangeType type) const
 {
   if ( type!=MemoryRangeType::Code ) return 1;
-  return _nbWordsCodeWrite;
+  if (_nbWordsCodeWrite == 0) {
+    switch (architecture().type()) {
+      case Architecture::P24H:
+      case Architecture::P33F: return 64;
+      case Architecture::P30F: return 32; // ?
+      default:                 return 16; // default ??
+    }
+  } else return _nbWordsCodeWrite;
 }
 
 uint Pic::Data::nbWordsRowEraseAlignment(MemoryRangeType type) const
 {
   if ( type!=MemoryRangeType::Code ) return 1;
-  return _nbWordsCodeRowErase;
+  if (_nbWordsCodeRowErase == 0) {
+    switch (architecture().type()) {
+      case Architecture::P24H:
+      case Architecture::P33F: return 512;
+      default:                 return 16; // default ??
+    }
+  } else return _nbWordsCodeRowErase;
 }
 
 //----------------------------------------------------------------------------
