@@ -12,7 +12,7 @@
 
 const Pic::ConfigNameType::Data Pic::ConfigNameType::DATA[Nb_Types] = {
   { "cname"      },
-  { "ecname"     },
+  { "ecnames"    },
   { "sdcc_cname" }
 };
 
@@ -63,6 +63,14 @@ const Pic::Config::Data Pic::Config::DATA[] = {
     { "H4S", I18N_NOOP("High speed crystal/resonator with software controlled 4x PLL") },
     { "INTXT", I18N_NOOP("Internal oscillator, XT used by USB") },
     { "INTHS", I18N_NOOP("Internal oscillator, HS used by USB") },
+
+    // for 18FxxKxx
+    { "EC_CLKOUT_HIGH", I18N_NOOP("External clock with CLKOUT, high power") },
+    { "EC_CLKOUT_MED", I18N_NOOP("External clock with CLKOUT, medium power") },
+    { "EC_CLKOUT_LOW", I18N_NOOP("External clock with CLKOUT, low power") },
+    { "EC_HIGH", I18N_NOOP("External clock (no CLKOUT), high power") },
+    { "EC_MED", I18N_NOOP("External clock (no CLKOUT), medium power") },
+    { "EC_LOW", I18N_NOOP("External clock (no CLKOUT), low power") },
     { 0, 0 } } },
 
   { { "BG",    I18N_NOOP("Bandgap voltage calibration") }, Fixed, {
@@ -75,6 +83,7 @@ const Pic::Config::Data Pic::Config::DATA[] = {
     { "10", I18N_NOOP("10") }, { "11", I18N_NOOP("11") }, { 0, 0 } } },
   { { "BODEN", I18N_NOOP("Brown-out detect")       }, Toggle, {
     { "On_run",   I18N_NOOP("Enabled in run - Disabled in sleep") },
+    { "Hardware", I18N_NOOP("Hardware only") },
     { "Software", I18N_NOOP("SBODEN controls BOD function")       }, { 0, 0 } } },
   { { "FCMEN", I18N_NOOP("Fail-safe clock monitor")      }, Toggle, { { 0, 0 } } },
   { { "IESO",  I18N_NOOP("Internal-external switchover") }, Toggle, { { 0, 0 } } },
@@ -206,6 +215,11 @@ const Pic::Config::Data Pic::Config::DATA[] = {
     { "8MHZ", I18N_NOOP("8 MHz") },
     { "4MHZ", I18N_NOOP("4 MHz") }, { 0, 0 } } },
 
+  //18K specific
+  { { "PLL4EN", I18N_NOOP("4x PLL enable") }, Toggle, { { 0, 0 } } },
+  { { "PRICLKEN", I18N_NOOP("Primary clock enable") }, Toggle, { { 0, 0 } } },
+  { { "HFOFST", I18N_NOOP("HFINTOSC fast start") }, Toggle, { { 0, 0 } } },
+
   // 18J specific
   { { "ETHLED", I18N_NOOP("Ethernet LED enable") }, Toggle, { { 0, 0 } } },
   { { "FOSC2", I18N_NOOP("Default system clock select") }, Fixed, {
@@ -252,6 +266,7 @@ const Pic::Config::Data Pic::Config::DATA[] = {
     { "PRIM_PLL",    I18N_NOOP("Primary oscillator with PLL") },
     { "SECOND",      I18N_NOOP("Secondary oscillator (LP)") },
     { "EXTRC_LP",    I18N_NOOP("Low power RC oscillator") },
+    { "INTRC_F_16",  I18N_NOOP("Internal fast RC oscillator with divide-by-16") },
     { "INTRC_F_POST",  I18N_NOOP("Internal fast RC oscillator with postscaler") }, { 0, 0 } } },
   { { "POSCMD", I18N_NOOP("Primary oscillator mode") }, Fixed, {
     { "Off", I18N_NOOP("Off") },
@@ -276,6 +291,9 @@ const Pic::Config::Data Pic::Config::DATA[] = {
   { { "FRANGE", I18N_NOOP("Frequency range selection for FRC oscillator") }, Fixed, {
     { "High range", I18N_NOOP("High range (nominal FRC frequency is 14.1 MHz)") },
     { "Low range", I18N_NOOP("Low range (nominal FRC frequency is 9.7 MHz)") }, { 0, 0 } } },
+  { { "BOREN", I18N_NOOP("Brown-out reset") }, Fixed, {
+    { "Off", I18N_NOOP("Off") },
+    { "On", I18N_NOOP("Enabled in hardware") }, { 0, 0 } } },
 
   { { 0, 0 }, Fixed, { { 0, 0 } } }
 };
