@@ -31,7 +31,7 @@ public:
 private:
   static const MemoryRangeType::Type MEMORY_DATA[];
 
-  virtual void display();
+  virtual void internalDisplay();
 };
 
 } // namespace
