@@ -317,7 +317,7 @@ void Pic::MemoryUserIdEditor::init(bool first)
 {
   MemoryTypeRangeEditor::init(first);
   _setToChecksum = new KToggleAction(i18n("Set to unprotected checksum"), 0, 0,
-                                     this, SLOT(toggleSetToChecksum()), MainWindow::self()->actionCollection());
+                                     this, SLOT(toggleSetToChecksum()), MainWindow::self().actionCollection());
   addAction(_setToChecksum);
   if ( readConfigEntry(BaseGlobalConfig::UserIdSetToChecksum).toBool() && memory().isClear(MemoryRangeType::UserId) ) {
     _setToChecksum->activate();
