@@ -19,10 +19,8 @@ class PicAdvancedDialog : public ::Programmer::AdvancedDialog
 Q_OBJECT
 public:
   PicAdvancedDialog(PicBase &base, QWidget *parent, const char *name);
-  virtual void updateDisplay();
 
 private:
-  QLabel *_voltages[Pic::Nb_VoltageTypes];
   PicBase &base() { return static_cast<PicBase &>(_base); }
 };
 
