@@ -8,6 +8,7 @@
  ***************************************************************************/
 #include "pic_memory.h"
 
+#include <memory>
 #include <qfile.h>
 
 #include "common/common/misc.h"
@@ -44,14 +45,14 @@ void Pic::Memory::fill(BitValue value)
 
 void Pic::Memory::copyFrom(MemoryRangeType type, const Memory &memory)
 {
-  Q_ASSERT( memory.device().name()==device().name() );
+  ASSERT( memory.device().name()==device().name() );
   for (uint i=0; i<_ranges[type].count(); i++) _ranges[type][i] = memory._ranges[type][i];
 }
 
-void Pic::Memory::copyFrom(const Device::Memory &memory)
+void Pic::Memory::copyFrom(const Device::Memory& memory)
 {
-  Q_ASSERT( memory.device().name()==device().name() );
-  FOR_EACH(MemoryRangeType, i) copyFrom(i, static_cast<const Memory &>(memory));
+  ASSERT(memory.device().name() == device().name());
+  FOR_EACH(MemoryRangeType, type) copyFrom(type, static_cast<const Pic::Memory&>(memory));
 }
 
 Device::Array Pic::Memory::arrayForWriting(MemoryRangeType type) const
@@ -64,7 +65,7 @@ Device::Array Pic::Memory::arrayForWriting(MemoryRangeType type) const
 
 BitValue Pic::Memory::word(MemoryRangeType type, uint offset) const
 {
-  CRASH_ASSERT( offset<_ranges[type].size() );
+  ASSERT( offset<_ranges[type].size() );
   return _ranges[type][offset];
 }
 
@@ -86,13 +87,13 @@ BitValue Pic::Memory::normalizedWord(MemoryRangeType type, uint offset) const
 void Pic::Memory::setWord(MemoryRangeType type, uint offset, BitValue value)
 {
   if ( offset>=_ranges[type].size() ) qDebug("Memory::setWord: type=%s offset=%s size=%s value=%s", type.key().latin1(), toHexLabelAbs(offset).latin1(), toHexLabelAbs(_ranges[type].size()).latin1(), toHexLabelAbs(value).latin1());
-  CRASH_ASSERT( offset<_ranges[type].size() );
+  ASSERT( offset<_ranges[type].size() );
   _ranges[type][offset] = value;
 }
 
 void Pic::Memory::setArray(MemoryRangeType type, const Device::Array &data)
 {
-  CRASH_ASSERT( _ranges[type].size()==data.size() );
+  ASSERT( _ranges[type].size()==data.size() );
   _ranges[type] = data;
 }
 
@@ -241,9 +242,10 @@ void Pic::Memory::setProtection(bool on, Protection::Type ptype, MemoryRangeType
 
 void Pic::Memory::setConfigValue(const QString &maskName, const QString &valueName)
 {
-  uint i;
+  uint i = 0;
   const Config::Mask *mask = device().config().findMask(maskName, &i);
-  Q_ASSERT(mask);
+  ASSERT(mask != NULL);
+  if (mask == NULL) return;
   BitValue v = word(MemoryRangeType::Config, i);
   v = v.clearMaskBits(mask->value);
   for (int k=mask->values.count()-1; k>=0; k--) { // important to get the highest value in case of identical values
@@ -251,7 +253,7 @@ void Pic::Memory::setConfigValue(const QString &maskName, const QString &valueNa
     setWord(MemoryRangeType::Config, i, v | mask->values[k].value);
     return;
   }
-  Q_ASSERT(false);
+  ASSERT(false);
 }
 
 void Pic::Memory::setProtection(bool on, const QString &maskName, Protection::Type ptype)
@@ -274,18 +276,16 @@ void Pic::Memory::setProtection(bool on, const QString &maskName, Protection::Ty
 bool Pic::Memory::hasFlagOn(const QString &maskName, bool valueIfNotPresent) const
 {
   const Config::Mask *mask = device().config().findMask(maskName, 0);
-  if ( mask==0 ) return valueIfNotPresent;
-  Q_ASSERT(mask);
-  Q_ASSERT( mask->values.count()==2 );
-  return ( findValue(maskName)=="On" );
+  if (mask == NULL) return valueIfNotPresent;
+  ASSERT(mask->values.count() == 2);
+  return (findValue(maskName) == "On");
 }
 
 void Pic::Memory::setFlagOn(const QString &maskName, bool on)
 {
   const Config::Mask *mask = device().config().findMask(maskName, 0);
-  Q_UNUSED(mask);
-  Q_ASSERT(mask);
-  Q_ASSERT( mask->values.count()==2 );
+  if (mask == NULL) return;
+  ASSERT(mask->values.count() == 2);
   setConfigValue(maskName, on ? "On" : "Off");
 }
 
@@ -422,16 +422,16 @@ BitValue Pic::Memory::checksum() const
 BitValue Pic::Memory::unprotectedChecksum() const
 {
   const Protection &protection = device().config().protection();
-  Memory tmp(*this);
-  if ( protection.hasBootBlock() ) tmp.setBootProtection(false, Protection::ProgramProtected);
+  std::auto_ptr<Memory> tmp(static_cast<Pic::Memory*>(clone()));
+  if ( protection.hasBootBlock() ) tmp->setBootProtection(false, Protection::ProgramProtected);
   if ( protection.nbBlocks()!=0 ) {
     for (uint i=0; i<protection.nbBlocks(); i++)
-      tmp.setBlockProtection(false, Protection::ProgramProtected, i);
-  } else tmp.setProtection(false, Protection::ProgramProtected, MemoryRangeType::Code);
-  tmp.setProtection(false, Protection::ProgramProtected, MemoryRangeType::Eeprom);
-  tmp.setProtection(false, Protection::ProgramProtected, MemoryRangeType::Config);
-  tmp.setProtection(false, Protection::ProgramProtected, MemoryRangeType::Cal);
-  return tmp.checksum();
+      tmp->setBlockProtection(false, Protection::ProgramProtected, i);
+  } else tmp->setProtection(false, Protection::ProgramProtected, MemoryRangeType::Code);
+  tmp->setProtection(false, Protection::ProgramProtected, MemoryRangeType::Eeprom);
+  tmp->setProtection(false, Protection::ProgramProtected, MemoryRangeType::Config);
+  tmp->setProtection(false, Protection::ProgramProtected, MemoryRangeType::Cal);
+  return tmp->checksum();
 }
 
 void Pic::Memory::setUserIdToUnprotectedChecksum()
@@ -496,7 +496,7 @@ void Pic::Memory::toHexBuffer(MemoryRangeType type, HexBuffer &hb) const
 HexBuffer Pic::Memory::toHexBuffer() const
 {
   HexBuffer hb;
-  FOR_EACH(MemoryRangeType, i) toHexBuffer(i, hb);
+  FOR_EACH(MemoryRangeType, type) toHexBuffer(type, hb);
   return hb;
 }
 
@@ -517,20 +517,31 @@ void Pic::Memory::fromHexBuffer(MemoryRangeType type, const HexBuffer &hb, Warni
   uint byte = 0;
   uint wOffset = 0;
   uint wByte = 0;
-  //qDebug("%s wnb=%i snb=%i", MEMORY_RANGE_TYPE_DATA[type].label, wNbBytes, nbBytes);
-  for (uint k=0; k<wNbBytes*device().nbWords(type); k++) {
+//qDebug("%s wnb=%i snb=%i", type.label().latin1(), wNbBytes, nbBytes);
+  uint nb = wNbBytes * device().nbWords(type);
+  for (uint k=0; k<nb; k++) {
     // set byte
     BitValue s = hb[offset];
-    //if ( k<4 ) qDebug("s=%s so=%s sb=%i wo=%i wb=%i", toHex(s, 8).data(), toHex(offset, 8).data(), byte, wOffset, wByte);
     if ( !s.isInitialized() ) {
       if ( type==MemoryRangeType::Config ) _ranges[type][wOffset] = mask;
       else _ranges[type][wOffset] = BitValue();
     } else {
       inRange[offset] = true;
-      s = s.byte(byte%2);
-      if ( wByte==0 ) _ranges[type][wOffset] = s;
-      else _ranges[type][wOffset] |= (s << (wByte*8));
+      BitValue sb = s.byte(byte%2);
+      if ( wByte==0 ) _ranges[type][wOffset] = sb;
+      else _ranges[type][wOffset] |= (sb << (wByte*8));
     }
+/*
+    uint debugNb = 16;
+    if ( k<debugNb || nb-k-1<debugNb ) {
+        if (s.isInitialized()) qDebug("s=%s so=%s sb=%i wo=%s wb=%i v=%s",
+            toHex(s, 8).latin1(), toHex(offset, 8).latin1(), byte, toHex(wOffset, 8).latin1(), wByte,
+            toHex(_ranges[type][wOffset], 8).latin1());
+        else qDebug("s=<%s> so=%s sb=%i wo=%s wb=%i",
+                    toHex(s, 8).latin1(), toHex(offset, 8).latin1(), byte, toHex(wOffset, 8).latin1(), wByte);
+    }
+    if ( k==debugNb && nb>2*debugNb ) qDebug("...");
+*/
     // increment offsets
     byte++;
     if ( (byte%nbBytes)==0 ) {
@@ -556,5 +567,5 @@ void Pic::Memory::fromHexBuffer(MemoryRangeType type, const HexBuffer &hb, Warni
 void Pic::Memory::fromHexBuffer(const HexBuffer &hb, WarningTypes &result,
                                 QStringList &warnings, QMap<uint, bool> &inRange)
 {
-  FOR_EACH(MemoryRangeType, i) fromHexBuffer(i, hb, result, warnings, inRange);
+  FOR_EACH(MemoryRangeType, type) fromHexBuffer(type, hb, result, warnings, inRange);
 }
