@@ -8,6 +8,8 @@
  ***************************************************************************/
 #include "pic_prog.h"
 
+#include <memory>
+
 #include "common/global/global.h"
 #include "devices/list/device_list.h"
 #include "progs/base/prog_config.h"
@@ -18,7 +20,7 @@
 Debugger::DeviceSpecific *Programmer::PicGroup::createDebuggerDeviceSpecific(::Debugger::Base &base) const
 {
   const Pic::Data *data = static_cast<const Pic::Data *>(base.device());
-  if ( data==0 ) return 0;
+  if ( data==NULL ) return NULL;
   switch (data->architecture().type()) {
     case Pic::Architecture::P10X:
     case Pic::Architecture::P16X: return new ::Debugger::P16FSpecific(base);
@@ -33,24 +35,25 @@ Debugger::DeviceSpecific *Programmer::PicGroup::createDebuggerDeviceSpecific(::D
     case Pic::Architecture::Nb_Types: break;
   }
   Q_ASSERT(false);
-  return 0;
+  return NULL;
 }
 
 //-----------------------------------------------------------------------------
 Programmer::PicBase::PicBase(const Group &group, const Pic::Data *data, const char *name)
   : Base(group, data, name), _deviceMemory(0), _hasProtectedCode(false), _hasProtectedEeprom(false)
 {
-  if (data) _deviceMemory = new Pic::Memory(*data);
+  if (data != NULL) _deviceMemory = new Pic::Memory(*data);
 }
 
 Programmer::PicBase::~PicBase()
 {
   delete _deviceMemory;
+  _deviceMemory = NULL;
 }
 
-uint Programmer::PicBase::nbSteps(Task task, const Device::MemoryRange *range) const
+uint Programmer::PicBase::nbSteps(Task task, const Device::MemoryRange& range) const
 {
-  const Pic::MemoryRange *prange = static_cast<const Pic::MemoryRange *>(range);
+  const Pic::MemoryRange& prange = static_cast<const Pic::MemoryRange&>(range);
   switch (task.type()) {
     case Task::Erase: return 1;
     case Task::Read:
@@ -60,7 +63,7 @@ uint Programmer::PicBase::nbSteps(Task task, const Device::MemoryRange *range) c
       FOR_EACH(Pic::MemoryRangeType, type) {
         if ( type!=Pic::MemoryRangeType::Code && type!=Pic::MemoryRangeType::Eeprom ) continue;
         if ( !device()->isReadable(type) || !specific()->canReadRange(type) ) continue;
-        if ( !prange->all() && prange->_type!=type ) continue;
+        if ( !prange.all() && prange._type!=type ) continue;
         nb += device()->nbWords(type);
       }
       return QMAX(nb, uint(1));
@@ -70,7 +73,7 @@ uint Programmer::PicBase::nbSteps(Task task, const Device::MemoryRange *range) c
       FOR_EACH(Pic::MemoryRangeType, type) {
         if ( type!=Pic::MemoryRangeType::Code && type!=Pic::MemoryRangeType::Eeprom ) continue;
         if ( !device()->isWritable(type) || !specific()->canWriteRange(type) ) continue;
-        if ( !prange->all() && prange->_type!=type ) continue;
+        if ( !prange.all() && prange._type!=type ) continue;
         nb += device()->nbWords(type);
         if ( readConfigEntry(Config::VerifyAfterProgram).toBool() ) nb += device()->nbWords(type);
       }
@@ -431,23 +434,22 @@ bool Programmer::PicBase::readRange(Pic::MemoryRangeType type, Pic::Memory *memo
     log(Log::LineType::Information, i18n("The selected programmer cannot read %1: operation skipped.").arg(type.label()));
     return true;
   }
-  VerifyData *vdata = (vd ? new VerifyData(vd->actions, vd->memory) : 0);
-  if (vdata) {
+  std::auto_ptr<VerifyData> vdata;
+  if (vd != NULL) vdata.reset(new VerifyData(*vd));
+  if (vdata.get() != NULL) {
     log(Log::LineType::Information, i18n("  Verify memory: %1").arg(type.label()));
     if ( !(vdata->actions & IgnoreProtectedVerify) ) {
-      vdata->protectedRanges = static_cast<const Pic::Memory &>(vdata->memory).protectedRanges(Pic::Protection::ProgramProtected, type);
+      vdata->protectedRanges = static_cast<const Pic::Memory &>(vdata->memory()).protectedRanges(Pic::Protection::ProgramProtected, type);
       if ( !vdata->protectedRanges.isEmpty() ) log(Log::LineType::Warning, i18n("  Part of device memory is protected (in %1) and cannot be verified.")
                                                .arg(type.label()));
     } else vdata->protectedRanges.clear();
   } else {
     log(Log::LineType::Information, i18n("  Read memory: %1").arg(type.label()));
-    CRASH_ASSERT(memory);
+    ASSERT(memory);
   }
   Device::Array data;
-  bool ok = specific()->read(type, data, vdata);
-  delete vdata;
-  if (!ok) return false;
-  if (memory) memory->setArray(type, data);
+  if (!specific()->read(type, data, vdata.get())) return false;
+  if (memory != NULL) memory->setArray(type, data);
   return true;
 }
 
@@ -460,24 +462,46 @@ bool Programmer::PicBase::checkRead()
   return true;
 }
 
-bool Programmer::PicBase::internalRead(Device::Memory *memory, const Device::MemoryRange &range, const VerifyData *vdata)
+void Programmer::PicBase::prepareMemoryForWriting(Pic::Memory& memory, bool issueWarnings)
+{
+  if (memory.hasDebugOn() != group().isDebugger()) {
+    if (issueWarnings) {
+      if (group().isDebugger()) log(Log::LineType::Warning, i18n("Enabling DEBUG configuration bit."));
+      else log(Log::LineType::Warning, i18n("Disabling DEBUG configuration bit."));
+    }
+    memory.setDebugOn(group().isDebugger());
+  }
+  if (memory.hasJTagOn()) {
+    if (issueWarnings) log(Log::LineType::Warning, i18n("Disabling JTAGEN configuration bit."));
+    memory.setJTagOn(false);
+  }
+}
+
+bool Programmer::PicBase::internalRead(Device::Memory *memory, const Device::MemoryRange &range, const VerifyData *pvdata)
 {
   if ( !initProgramming(Task::Read) ) return false;
   Pic::Memory *pmemory = static_cast<Pic::Memory *>(memory);
+
+  std::auto_ptr<VerifyData> vdata;
+  if (pvdata != NULL) {
+    vdata.reset(new VerifyData(*pvdata));
+    prepareMemoryForWriting(static_cast<Pic::Memory&>(vdata->memory()), false);
+  }
+
   if ( !range.all() ) {
     Pic::MemoryRangeType type = static_cast<const Pic::MemoryRange &>(range)._type;
     if ( type==Pic::MemoryRangeType::Cal ) {
-      if ( !readRange(Pic::MemoryRangeType::Cal, pmemory, vdata) ) return false;
-      return readRange(Pic::MemoryRangeType::CalBackup, pmemory, vdata);
+      if ( !readRange(Pic::MemoryRangeType::Cal, pmemory, vdata.get()) ) return false;
+      return readRange(Pic::MemoryRangeType::CalBackup, pmemory, vdata.get());
     }
-    return readRange(type, pmemory, vdata);
+    return readRange(type, pmemory, vdata.get());
   }
-  if ( !readRange(Pic::MemoryRangeType::Config,    pmemory, vdata) ) return false;
-  if ( !readRange(Pic::MemoryRangeType::UserId,    pmemory, vdata) ) return false;
-  if ( vdata==0 ) if ( !readRange(Pic::MemoryRangeType::Cal,       pmemory, 0) ) return false;
-  if ( vdata==0 ) if ( !readRange(Pic::MemoryRangeType::CalBackup, pmemory, 0) ) return false;
-  if ( !readRange(Pic::MemoryRangeType::Code,      pmemory, vdata) ) return false;
-  if ( !readRange(Pic::MemoryRangeType::Eeprom,    pmemory, vdata) ) return false;
+  if ( !readRange(Pic::MemoryRangeType::Config,    pmemory, vdata.get()) ) return false;
+  if ( !readRange(Pic::MemoryRangeType::UserId,    pmemory, vdata.get()) ) return false;
+  if (vdata.get() == NULL) if ( !readRange(Pic::MemoryRangeType::Cal,       pmemory, NULL) ) return false;
+  if (vdata.get() == NULL) if ( !readRange(Pic::MemoryRangeType::CalBackup, pmemory, NULL) ) return false;
+  if ( !readRange(Pic::MemoryRangeType::Code,      pmemory, vdata.get()) ) return false;
+  if ( !readRange(Pic::MemoryRangeType::Eeprom,    pmemory, vdata.get()) ) return false;
   return true;
 }
 
@@ -531,37 +555,33 @@ bool Programmer::PicBase::programAll(const Pic::Memory &memory)
   return true;
 }
 
-bool Programmer::PicBase::checkProgram(const Device::Memory &memory)
+bool Programmer::PicBase::checkProgram(const Device::Memory &)
 {
-  if ( device()->memoryTechnology()==Device::MemoryTechnology::Rom || device()->memoryTechnology()==Device::MemoryTechnology::Romless ) {
+  if ( device()->memoryTechnology()==Device::MemoryTechnology::Rom
+       || device()->memoryTechnology()==Device::MemoryTechnology::Romless ) {
     log(Log::LineType::SoftError, i18n("Cannot write ROM or ROMless device."));
     return false;
   }
-  if ( !group().isDebugger() && static_cast<const Pic::Memory &>(memory).hasDebugOn() ) {
-    if ( !askContinue(i18n("DEBUG configuration bit is on. Are you sure you want to continue programming the chip?")) ) {
-      logUserAbort();
-      return false;
-    }
-  }
   return true;
 }
 
 bool Programmer::PicBase::internalProgram(const Device::Memory &memory, const Device::MemoryRange &range)
 {
   if ( !initProgramming(Task::Erase) ) return false;
-  const Pic::Memory &pmemory = static_cast<const Pic::Memory &>(memory);
+  std::auto_ptr<Pic::Memory> pmemory(static_cast<Pic::Memory*>(memory.clone()));
+  prepareMemoryForWriting(*pmemory, true);
 
   // blank check if OTP device
   bool eprom = ( device()->memoryTechnology()==Device::MemoryTechnology::Eprom );
   if (eprom) {
     log(Log::LineType::Information, i18n("  EPROM device: blank checking first..."));
-    Pic::Memory memory(*device());
-    VerifyData vdata(BlankCheckVerify, memory);
+    Pic::Memory tmemory(*device());
+    VerifyData vdata(BlankCheckVerify, tmemory);
     if ( !internalRead(0, range, &vdata) ) return false;
     log(Log::LineType::Information, i18n("  Blank check successful"));
     // check if protecting device
-    bool protectedCode = pmemory.isProtected(Pic::Protection::ProgramProtected, Pic::MemoryRangeType::Code);
-    bool protectedEeprom = pmemory.isProtected(Pic::Protection::ProgramProtected, Pic::MemoryRangeType::Eeprom);
+    bool protectedCode = pmemory->isProtected(Pic::Protection::ProgramProtected, Pic::MemoryRangeType::Code);
+    bool protectedEeprom = pmemory->isProtected(Pic::Protection::ProgramProtected, Pic::MemoryRangeType::Eeprom);
     if ( protectedCode || protectedEeprom ) {
       log(Log::LineType::SoftError, i18n("Protecting code memory or data EEPROM on OTP devices is disabled as a security..."));
       return false;
@@ -572,15 +592,16 @@ bool Programmer::PicBase::internalProgram(const Device::Memory &memory, const De
   bool ok = true;
   if ( !range.all() ) {
     Pic::MemoryRangeType type = static_cast<const Pic::MemoryRange &>(range)._type;
-    if ( (type==Pic::MemoryRangeType::Code && _hasProtectedCode) || (type==Pic::MemoryRangeType::Eeprom && _hasProtectedEeprom) ) {
+    if ( (type==Pic::MemoryRangeType::Code && _hasProtectedCode)
+         || (type==Pic::MemoryRangeType::Eeprom && _hasProtectedEeprom) ) {
       log(Log::LineType::SoftError, i18n("This memory range is programming protected."));
       return false;
     }
     if ( specific()->canEraseRange(type) ) {
       if ( !(specific()->capabilities() & EmulatedErase) && !eraseRange(type) ) return false;
     } else log(Log::LineType::Warning, i18n("The range cannot be erased first by the selected programmer so programming may fail..."));
-    ok = programRange(type, pmemory.arrayForWriting(type));
-    VerifyData vdata(NormalVerify, pmemory);
+    ok = programRange(type, pmemory->arrayForWriting(type));
+    VerifyData vdata(NormalVerify, *pmemory);
     if (ok) ok = readRange(type, 0, &vdata);
   } else {
     if ( !eprom ) {
@@ -592,7 +613,7 @@ bool Programmer::PicBase::internalProgram(const Device::Memory &memory, const De
         }
       } else log(Log::LineType::Warning, i18n("The device cannot be erased first by the selected programmer so programming may fail..."));
     }
-    if (ok) ok = programAll(pmemory);
+    if (ok) ok = programAll(*pmemory);
   }
   if ( !restoreBandGapBits() ) return false;
   return ok;
