@@ -56,7 +56,7 @@ public:
 protected:
   PicHardware *hardware() { return static_cast<PicHardware *>(_hardware); }
   virtual bool verifyDeviceId();
-  virtual uint nbSteps(Task task, const Device::MemoryRange *range) const;
+  virtual uint nbSteps(Task task, const Device::MemoryRange &range) const;
   bool initProgramming(Task task);
 
   virtual bool checkErase();
@@ -89,6 +89,7 @@ private:
   bool preserveCode();
   bool preserveEeprom();
   bool internalEraseRange(Pic::MemoryRangeType type);
+  void prepareMemoryForWriting(Pic::Memory& memory, bool issueWarnings);
 };
 
 } // namespace
