@@ -1,11 +1,12 @@
 /***************************************************************************
- *   Copyright (C) 2005-2007 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  ***************************************************************************/
+#include <map>
 #include <qfile.h>
 #include <qregexp.h>
 
@@ -74,8 +75,8 @@ bool getMemoryRange(MemoryRangeType type, QDomElement element)
   QString wwa = range.attribute("word_write_align");
   QString wea = range.attribute("word_erase_align");
   if ( type==MemoryRangeType::Code ) {
-    data()->_nbWordsCodeWrite = 16; // ### default ?
-    data()->_nbWordsCodeRowErase = 16; // ### default ?
+    data()->_nbWordsCodeWrite = 0; // default
+    data()->_nbWordsCodeRowErase = 0; // default
     if ( !wwa.isEmpty() ) {
       data()->_nbWordsCodeWrite = wwa.toUInt(&ok);
       if ( !ok || data()->_nbWordsCodeWrite==0 || (data()->_nbWordsCodeWrite%4)!=0 ) qFatal("Malformed word write align");
@@ -112,10 +113,10 @@ void processName(const Pic::Config::Mask &cmask, BitValue pmask, Pic::Config::Va
     if ( !cnames.isEmpty() ) qFatal(QString("Config name should be null for protected config mask \"%1\"").arg(cmask.name));
   } else {
     if ( cnames.isEmpty() && cmask.name!="BSSEC" && cmask.name!="BSSIZ" && cmask.name!="SSSEC" && cmask.name!="SSSIZ" ) {
-      // ### FIXME: 18J 24H 30F1010/202X
+      // ### FIXME: missing cnames
       if ( data()->architecture()!=Pic::Architecture::P18J && data()->architecture()!=Pic::Architecture::P24H
            && data()->architecture()!=Pic::Architecture::P24F && data()->architecture()!=Pic::Architecture::P33F
-           && data()->name()!="30F1010" && data()->name()!="30F2020" && data()->name()!="30F2023" )
+           && data()->name()!="30F1010" && data()->name()!="30F2020" && data()->name()!="30F2023")
         qFatal(QString("cname not defined for \"%1\" (%2)").arg(cvalue.name).arg(cmask.name));
     }
     if ( cnames.count()==1 && cnames[0]=="_" ) cnames.clear();
@@ -518,6 +519,7 @@ virtual void processDevice(QDomElement device)
   }
 }
 
+//-----------------------------------------------------------------------------
 void processMirrored(QDomElement element)
 {
   QValueVector<RangeData> mirrored;
@@ -691,12 +693,12 @@ void processRegisters()
   }
 }
 
+//-----------------------------------------------------------------------------
 virtual void checkPins(const QMap<QString, uint> &pinLabels) const
 {
   if ( !pinLabels.contains("VDD") ) qFatal("No VDD pin specified");
   if ( !pinLabels.contains("VSS") ) qFatal("No VSS pin specified");
-  QMap<QString, uint>::const_iterator it;
-  for (it=pinLabels.begin(); it!=pinLabels.end(); ++it) {
+  for (QMap<QString, uint>::const_iterator it = pinLabels.begin(); it != pinLabels.end(); ++it) {
     if ( it.key()=="VDD" || it.key()=="VSS" || it.key().startsWith("CCP") ) continue;
     if ( it.data()!=1 ) qFatal(QString("Duplicated pin \"%1\"").arg(it.key()));
   }
@@ -711,9 +713,130 @@ virtual void checkPins(const QMap<QString, uint> &pinLabels) const
   }
 }
 
+//-----------------------------------------------------------------------------
+struct ConfigNameData
+{
+  QStringList names;
+  typedef std::map<const Device::Data*, QStringList> SpecificNames;
+  SpecificNames specificNames;
+
+  const QStringList& getConfigNames(const Data& device) const {
+    SpecificNames::const_iterator it = specificNames.find(&device);
+    if (it != specificNames.end()) return it->second;
+    return names;
+  }
+};
+
+void processCompilerMacros(Architecture arch, QDomElement root)
+{
+  _data = NULL;
+  typedef std::pair<QString, QString> MaskValuePair;
+  typedef std::map<MaskValuePair, ConfigNameData> ConfigNames;
+  ConfigNames configNames;
+  for (QDomNode child = root.firstChild(); !child.isNull(); child = child.nextSibling()) {
+    if ( child.isComment() ) qDebug("comment: %s", child.toComment().data().latin1());
+    else {
+      if ( !child.isElement() ) qFatal("\"cmacros\" child should be an element");
+      if ( child.nodeName()!="cmacro" ) qFatal("Child should be named \"cmacro\"");
+      QDomElement cmacro = child.toElement();
+      QString mask = cmacro.attribute("mask");
+      if (mask.isEmpty()) qFatal("Empty mask");
+      QString value = cmacro.attribute("value");
+      if (mask.isEmpty()) qFatal("Empty value");
+      QString gpasm = cmacro.attribute("gpasm");
+      QStringList names = QStringList::split(" ", gpasm);
+      if (names.isEmpty()) qFatal("Empty gpasm");
+      MaskValuePair pair(mask, value);
+      QString devices = cmacro.attribute("devices");
+      ConfigNameData& cdata = configNames[pair];
+      if (devices.isNull()) {
+        if (!cdata.names.isEmpty()) qFatal(QString("Duplicated value for %1/%2").arg(mask).arg(value));
+        cdata.names = names;
+      } else {
+        QStringList list = QStringList::split(" ", devices);
+        if (list.isEmpty()) qFatal("Empty devices");
+        for (QStringList::const_iterator it = list.begin(); it != list.end(); ++it) {
+          QMap<QString, Device::Data*>::const_iterator dit = _map.find(*it);
+          if (dit == _map.end()) qFatal(QString("Unknown device %1").arg(*it));
+          QStringList& dnames = cdata.specificNames[dit.data()];
+          if (!dnames.isEmpty()) qFatal(QString("Duplicated specific value for %1/%2").arg(mask).arg(value));
+          dnames = names;
+        }
+      }
+    }
+  }
+
+  if (configNames.empty()) return;
+
+  bool error = false;
+  for (QMap<QString, Device::Data*>::const_iterator it = _map.begin(); it != _map.end(); ++it) {
+    if (error) qFatal("stop");
+    _data = it.data();
+    const Pic::Data& pdata = static_cast<const Pic::Data&>(*_data);
+    if (pdata.architecture() != arch) continue;
+    const Pic::Config& config = pdata.config();
+    for (QValueVector<Pic::Config::Word>::const_iterator wit = config._words.begin(); wit != config._words.end(); ++wit) {
+      const Pic::Config::Word& word = *wit;
+      for (QValueVector<Pic::Config::Mask>::const_iterator mit = word.masks.begin(); mit != word.masks.end(); ++mit) {
+        const Pic::Config::Mask& mask = *mit;
+        for (QValueVector<Pic::Config::Value>::const_iterator vit = mask.values.begin(); vit != mask.values.end(); ++vit) {
+          const Pic::Config::Value& value = *vit;
+          if (!value.isValid()) continue;
+          MaskValuePair pair(mask.name, value.name);
+          ConfigNames::const_iterator cnit = configNames.find(pair);
+          QStringList cnames = value.configNames[Pic::ConfigNameType::Default];
+          cnames += value.configNames[Pic::ConfigNameType::Extra];
+          if (cnit == configNames.end()) {
+            if (!cnames.isEmpty()) {
+              warning(QString("No config name %1 for %2/%3").arg(cnames[0]).arg(mask.name).arg(value.name));
+              error = true;
+            }
+            continue;
+          }
+          const QStringList& configNames = cnit->second.getConfigNames(pdata);
+          if (cnames.size() != configNames.size()) {
+            warning(QString("Different number of config names (%1 != %2) for %3/%4")
+                    .arg(cnames.size()).arg(configNames.size()).arg(mask.name).arg(value.name));
+            error= true;
+            continue;
+          }
+          QStringList::const_iterator cit = cnames.begin();
+          if (cit != cnames.end() && *cit != configNames[0]) {
+            warning(QString("Different first config name %1 for %2/%3").arg(*cit).arg(mask.name).arg(value.name));
+            error = true;
+            continue;
+          }
+          for (++cit; cit != cnames.end(); ++cit) {
+            if (configNames.find(*cit) == configNames.end()) {
+              warning(QString("Config name %1 not found for %2/%3").arg(*cit).arg(mask.name).arg(value.name));
+              error =true;
+              continue;
+            }
+          }
+        }
+      }
+    }
+  }
+}
+
+void processCompilerMacros()
+{
+  _data = NULL;
+  FOR_EACH(Architecture, arch) {
+    QString filepath = "cmacros/cmacros_" + arch.key() + ".xml";
+    QDomDocument doc = parseFile(filepath);
+    QDomElement root = doc.documentElement();
+    if (root.nodeName() != "cmacros" ) qFatal("root node should be \"cmacros\"");
+    if (root.attribute("architecture") != arch.key()) qFatal("root node should have \"architecture\" attribute");
+    processCompilerMacros(arch, root);
+  }
+}
+
+//-----------------------------------------------------------------------------
 virtual void parse()
 {
   Device::XmlToDataBase::parse();
+  processCompilerMacros();
   processRegisters();
 }
 
