@@ -30,7 +30,7 @@
 GlobalConfigWidget::GlobalConfigWidget()
 {
   uint row = numRows();
-  _showDebug = new KeyComboBox<Log::DebugLevel>(this);
+  _showDebug.reset(new KeyComboBox<Log::DebugLevel>(this));
   FOR_EACH(Log::DebugLevel, level) _showDebug->appendItem(level, level.label());
   addWidget(_showDebug->widget(), row,row, 0,0);
   row++;
@@ -54,52 +54,13 @@ QPixmap GlobalConfigWidget::pixmap() const
   return loader.loadIcon("configure", KIcon::Toolbar, KIcon::SizeMedium);
 }
 
-//----------------------------------------------------------------------------
-StandaloneConfigWidget::StandaloneConfigWidget()
-  : ConfigWidget(0)
-{
-  uint row = 0;
-
-  QLabel *label = new QLabel(i18n("Device:"), this);
-  addWidget(label, row,row, 0,0);
-  _device = new DeviceChooser::Button(this);
-  addWidget(_device, row,row, 1,1);
-  row++;
-
-  _tools = new ToolsConfigWidget(0, this);
-  addWidget(_tools, row,row, 0,2);
-  row++;
-
-  setColStretch(2, 1);
-}
-
-void StandaloneConfigWidget::loadConfig()
-{
-  _device->setDevice(Compile::Config::device(0));
-  _tools->loadConfig();
-}
-
-void StandaloneConfigWidget::saveConfig()
-{
-  Compile::Config::setDevice(0, _device->device());
-  _tools->saveConfig();
-}
-
-QPixmap StandaloneConfigWidget::pixmap() const
-{
-  KIconLoader loader;
-  return loader.loadIcon("configure", KIcon::Toolbar, KIcon::SizeMedium);
-}
-
 //----------------------------------------------------------------------------
 ConfigWidget *ConfigCenter::factory(Type type)
 {
   switch (type) {
     case General:      return new GlobalConfigWidget;
-    case ProgSelect:   return new Programmer::SelectConfigWidget;
     case ProgOptions:  return new Programmer::OptionsConfigWidget;
     case DebugOptions: return new Debugger::OptionsConfigWidget;
-    case Standalone:   return new StandaloneConfigWidget;
     case Nb_Types:     break;
   }
   Q_ASSERT(false);
