@@ -50,7 +50,7 @@ void DeviceEditor::init()
   _top->addWidget(_labelWarning);
   _vbox = new QVBoxLayout(_top);
 
-  connect(MainWindow::self(), SIGNAL(deviceChanged()), SLOT(updateDevice()));
+  connect(&MainWindow::self(), SIGNAL(deviceChanged()), SLOT(updateDevice()));
 }
 
 void DeviceEditor::setDevice(bool force)
