@@ -36,7 +36,7 @@ const Programmer::Group *DeviceChooser::Config::programmerGroup()
 {
   Config config;
   QString name = config.readEntry("programmer", QString::null);
-  return Programmer::lister().group(name);
+  return Programmer::Lister::instance().group(name);
 }
 
 void DeviceChooser::Config::writeToolGroup(const Tool::Group *group)
@@ -48,7 +48,7 @@ const Tool::Group *DeviceChooser::Config::toolGroup()
 {
   Config config;
   QString name = config.readEntry("tool", QString::null);
-  return Tool::lister().group(name);
+  return Tool::Lister::instance().group(name);
 }
 
 void DeviceChooser::Config::writePackage(const QString &name)
@@ -120,7 +120,7 @@ DeviceChooser::Dialog::Dialog(const QString &device, QWidget *parent)
   // view
   QHBoxLayout *hbox = new QHBoxLayout(top, 10);
   QVBoxLayout *vbox = new QVBoxLayout(hbox);
-  _listTypeCombo = new EnumComboBox<ListType>("list_type", mainWidget());
+  _listTypeCombo.reset(new EnumComboBox<ListType>("list_type", mainWidget()));
   connect(_listTypeCombo->combo(), SIGNAL(activated(int)), SLOT(updateList()));
   vbox->addWidget(_listTypeCombo->combo());
   QPushButton *button = new KPushButton(KGuiItem(i18n("Reset Filters"), "reload"), mainWidget());
@@ -137,10 +137,11 @@ DeviceChooser::Dialog::Dialog(const QString &device, QWidget *parent)
   container->addWidget(fcontainer, 0,0, 1,1);
 
   // programmer filter
-  _programmerCombo = new KeyComboBox<QString>(fcontainer);
+  _programmerCombo.reset(new KeyComboBox<QString>(fcontainer));
   _programmerCombo->appendItem("<all>", i18n("<Programmer>"));
-  Programmer::Lister::ConstIterator pit;
-  for (pit=Programmer::lister().begin(); pit!=Programmer::lister().end(); ++pit)
+  for (Programmer::Lister::ConstIterator pit = Programmer::Lister::instance().begin();
+       pit != Programmer::Lister::instance().end();
+       ++pit)
     _programmerCombo->appendItem(pit.key(), pit.data()->label());
   const Programmer::Group *pgroup = Config::programmerGroup();
   if (pgroup) _programmerCombo->setCurrentItem(pgroup->name());
@@ -148,10 +149,11 @@ DeviceChooser::Dialog::Dialog(const QString &device, QWidget *parent)
   fcontainer->appendWidget(_programmerCombo->widget());
 
   // tool filter
-  _toolCombo = new KeyComboBox<QString>(fcontainer);
+  _toolCombo.reset(new KeyComboBox<QString>(fcontainer));
   _toolCombo->appendItem("<all>", i18n("<Toolchain>"));
-  Tool::Lister::ConstIterator tit;
-  for (tit=Tool::lister().begin(); tit!=Tool::lister().end(); ++tit) {
+  for (Tool::Lister::ConstIterator tit = Tool::Lister::instance().begin();
+       tit != Tool::Lister::instance().end();
+       ++tit) {
     if ( tit.data()->isCustom() ) continue;
     _toolCombo->appendItem(tit.key(), tit.data()->label());
   }
@@ -161,22 +163,22 @@ DeviceChooser::Dialog::Dialog(const QString &device, QWidget *parent)
   fcontainer->appendWidget(_toolCombo->widget());
 
   // memory filter
-  _memoryCombo = new EnumComboBox<Device::MemoryTechnology>(i18n("<Memory Type>"), "memory_technology", fcontainer);
+  _memoryCombo.reset(new EnumComboBox<Device::MemoryTechnology>(i18n("<Memory Type>"), "memory_technology", fcontainer));
   connect(_memoryCombo->combo(), SIGNAL(activated(int)), SLOT(updateList()));
   fcontainer->appendWidget(_memoryCombo->combo());
 
   // status filter
-  _statusCombo = new EnumComboBox<Device::Status>(i18n("<Status>"), "status", fcontainer);
+  _statusCombo.reset(new EnumComboBox<Device::Status>(i18n("<Status>"), "status", fcontainer));
   connect(_statusCombo->combo(), SIGNAL(activated(int)), SLOT(updateList()));
   fcontainer->appendWidget(_statusCombo->combo());
 
   // features filter
-  _featureCombo = new EnumComboBox<Pic::Feature>(i18n("<Feature>"), "feature", fcontainer);
+  _featureCombo.reset(new EnumComboBox<Pic::Feature>(i18n("<Feature>"), "feature", fcontainer));
   connect(_featureCombo->combo(), SIGNAL(activated(int)), SLOT(updateList()));
   fcontainer->appendWidget(_featureCombo->combo());
 
   // package filter
-  _packageCombo = new KeyComboBox<QString>(fcontainer);
+  _packageCombo.reset(new KeyComboBox<QString>(fcontainer));
   _packageCombo->appendItem("<all>", i18n("<Package>"));
   QStringList names;
   for (uint i=0; Device::Package::TYPE_DATA[i].name; i++) names += Device::Package::TYPE_DATA[i].name;
@@ -187,7 +189,7 @@ DeviceChooser::Dialog::Dialog(const QString &device, QWidget *parent)
   fcontainer->appendWidget(_packageCombo->widget());
 
   // no. of pins filter
-  _pinsCombo = new KeyComboBox<uint>(fcontainer);
+  _pinsCombo.reset(new KeyComboBox<uint>(fcontainer));
   _pinsCombo->appendItem(0, i18n("<No. of Pins>"));
   QValueList<uint> list;
   for (uint i=0; Device::Package::TYPE_DATA[i].name; i++) {
@@ -293,12 +295,12 @@ void DeviceChooser::Dialog::updateList()
 
 const Programmer::Group *DeviceChooser::Dialog::programmerGroup() const
 {
-  return Programmer::lister().group(_programmerCombo->currentItem());
+  return Programmer::Lister::instance().group(_programmerCombo->currentItem());
 }
 
 const Tool::Group *DeviceChooser::Dialog::toolGroup() const
 {
-  return Tool::lister().group(_toolCombo->currentItem());
+  return Tool::Lister::instance().group(_toolCombo->currentItem());
 }
 
 void DeviceChooser::Dialog::updateList(const QString &device)
