@@ -9,6 +9,8 @@
 #ifndef DEVICE_GUI_H
 #define DEVICE_GUI_H
 
+#include <memory>
+
 #include <qpushbutton.h>
 #include <qlayout.h>
 #include <qcombobox.h>
@@ -68,7 +70,9 @@ public:
     Enum type = config.readEnumEntry(key, Enum(Enum::Nb_Types));
     if ( type!=Enum::Nb_Types ) _combo->setCurrentItem(type.type()+1);
   }
-  QComboBox *combo() { return _combo; }
+  ~EnumComboBox() { delete _combo; _combo = NULL; }
+
+  QComboBox *combo() const { return _combo; }
   Enum value() const {
     if ( _combo->count()==Enum::Nb_Types ) return typename Enum::Type(_combo->currentItem());
     if ( _combo->currentItem()==0 ) return Enum::Nb_Types;
@@ -82,7 +86,7 @@ public:
 
 private:
   QString    _key;
-  QComboBox *_combo;
+  QComboBox* _combo;
 };
 
 //-----------------------------------------------------------------------------
@@ -103,14 +107,16 @@ private slots:
   void resetFilters();
 
 private:
-  KeyComboBox<QString> *_programmerCombo, *_toolCombo, *_packageCombo;
-  KeyComboBox<uint>    *_pinsCombo;
-  EnumComboBox<ListType>                 *_listTypeCombo;
-  EnumComboBox<Device::MemoryTechnology> *_memoryCombo;
-  EnumComboBox<Device::Status>           *_statusCombo;
-  EnumComboBox<Pic::Feature>             *_featureCombo;
-  KListView   *_listView;
-  View        *_deviceView;
+  std::auto_ptr<KeyComboBox<QString> > _programmerCombo;
+  std::auto_ptr<KeyComboBox<QString> > _toolCombo;
+  std::auto_ptr<KeyComboBox<QString> > _packageCombo;
+  std::auto_ptr<KeyComboBox<uint> >    _pinsCombo;
+  std::auto_ptr<EnumComboBox<ListType> >                 _listTypeCombo;
+  std::auto_ptr<EnumComboBox<Device::MemoryTechnology> > _memoryCombo;
+  std::auto_ptr<EnumComboBox<Device::Status> >           _statusCombo;
+  std::auto_ptr<EnumComboBox<Pic::Feature> >             _featureCombo;
+  KListView* _listView;
+  View*      _deviceView;
 
   void updateList(const QString &device);
   const Programmer::Group *programmerGroup() const;
