@@ -85,7 +85,7 @@ bool Debugger::GuiManager::internalInit()
 bool Debugger::GuiManager::checkState(bool &first)
 {
   if ( !Debugger::Manager::checkState(first) ) return false;
-  if ( first && !Main::toolGroup().generateCompleteDebugInfo(Main::device()) )
+  if ( first && !Main::toolGroup()->generateCompleteDebugInfo(Main::device()) )
     MessageBox::information(i18n("The toolchain in use does not generate all necessary debugging information with the selected device. This may reduce debugging capabilities."), Log::Show, "doesnt_generate_debug_information");
   return true;
 }
@@ -93,9 +93,9 @@ bool Debugger::GuiManager::checkState(bool &first)
 Breakpoint::Data Debugger::GuiManager::currentBreakpointData()
 {
   const Breakpoint::Data *data = Main::breakpointsView().currentData();
-  if (data) return *data;
+  if (data != NULL) return *data;
   TextEditor *editor = ::qt_cast<TextEditor *>(Main::currentEditor());
-  Q_ASSERT(editor);
+  Q_ASSERT(editor != NULL);
   return Breakpoint::Data(editor->url(), editor->cursorLine());
 }
 
@@ -114,12 +114,12 @@ void Debugger::GuiManager::toggleBreakpoint()
   if ( !checkBreakpoint(data, false, address) ) return;
   Breakpoint::list().append(data);
   Breakpoint::list().setAddress(data, address);
-  if (_coff) toggleEnableBreakpoint();
+  if (_coff != NULL) toggleEnableBreakpoint();
 }
 
 void Debugger::GuiManager::toggleEnableBreakpoint()
 {
-  Q_ASSERT(_coff);
+  Q_ASSERT(_coff != NULL);
   Breakpoint::Data data = currentBreakpointData();
   bool isActive = ( Breakpoint::list().state(data)==Breakpoint::Active );
   if ( !Breakpoint::list().address(data).isValid() ) {
@@ -171,7 +171,7 @@ bool Debugger::GuiManager::update(bool gotoPC)
 
 bool Debugger::GuiManager::checkIfContinueStepping(bool &continueStepping)
 {
-  if ( Main::toolGroup().generateCompleteDebugInfo(Main::device()) )
+  if ( Main::toolGroup()->generateCompleteDebugInfo(Main::device()) )
     return Debugger::Manager::checkIfContinueStepping(continueStepping);
   if ( !update(false) ) return false;
   continueStepping = false;
@@ -185,14 +185,17 @@ void Debugger::GuiManager::internalUpdateView(bool gotoPC)
   QValueList<Editor *>::iterator ite;
   for (ite=_editors.begin(); ite!=_editors.end(); ++ite) {
     TextEditor *e = ::qt_cast<TextEditor *>(*ite);
-    if ( e==0 ) continue;
+    if ( e==NULL ) continue;
     updateEditorMarks(*e);
     if ( !_currentSourceLines.contains(e->url()) ) continue;
     if (gotoPC) e->setCursorPosition(_currentSourceLines[e->url()], 0);
     if ( e==Main::currentEditor() ) currentHasPC = true;
   }
-  MainWindow::self()->updateGUI();
-  if ( programmer()==0 || programmer()->state()!=Programmer::Halted || !pc().isInitialized() || currentHasPC ) return;
+  MainWindow::self().updateGUI();
+  if ( programmer()==NULL
+       || programmer()->state()!=Programmer::Halted
+       || !pc().isInitialized()
+       || currentHasPC ) return;
   // 1: look at files inside project and not generated
   // 2: look at files inside project
   // 3: look at existing files
@@ -205,9 +208,9 @@ void Debugger::GuiManager::internalUpdateView(bool gotoPC)
         case 2: if ( !it.key().exists() ) continue; break;
       }
       TextEditor *e = ::qt_cast<TextEditor *>(Main::editorManager().findEditor(it.key()));
-      if ( e==0 ) {
+      if ( e==NULL ) {
         if (gotoPC) e = ::qt_cast<TextEditor *>(Main::editorManager().openEditor(it.key()));
-        if ( e==0 ) continue;
+        if ( e==NULL ) continue;
       }
       updateEditorMarks(*e);
       if (gotoPC) {
@@ -226,7 +229,7 @@ Register::MainView *Debugger::GuiManager::registerView() const
     Register::MainView *rv = ::qt_cast<Register::MainView *>(*it);
     if (rv) return rv;
   }
-  return 0;
+  return NULL;
 }
 
 bool Debugger::GuiManager::isProjectSource(const PURL::Url &url) const
