@@ -29,7 +29,7 @@ bool Programmer::GuiManager::internalInitProgramming(bool debugging, ProgramActi
     if ( _programmer->isActive() ) return true;
     if ( ::Debugger::manager->coff()==0 && !::Debugger::manager->init() ) {
       if ( !MessageBox::askContinue(i18n("Cannot start debugging without a COFF file."), i18n("Recompile")) ) return false;
-      MainWindow::self()->buildProject(action);
+      MainWindow::self().buildProject(action);
       return false;
     }
     if ( !group().isSoftware() ) {
@@ -37,12 +37,12 @@ bool Programmer::GuiManager::internalInitProgramming(bool debugging, ProgramActi
                                                                i18n("Compile and Program First"), i18n("Continue Anyway"));
       switch (res) {
         case MessageBox::Cancel: return false;
-        case MessageBox::Yes: MainWindow::self()->buildProject(action); return false;
+        case MessageBox::Yes: MainWindow::self().buildProject(action); return false;
         case MessageBox::No: break;
       }
     }
     return true;
-  } else if ( _programmer->isActive() ) {
+  } else if (_programmer->isActive() && action != ProgramAction::Halt) {
     if ( group().isDebugger() && !askContinue(i18n("The selected operation will stop the current debugging session. Continue anyway?")) ) return false;
     if ( !halt() ) return false;
   }
@@ -60,10 +60,11 @@ void Programmer::GuiManager::showAdvancedDialog()
   const ::Programmer::GroupUI *groupui = static_cast<const ::Programmer::GroupUI *>(group().gui());
   const Device::Data *data = Main::deviceData();
   if ( data && !group().isSupported(data->name()) ) data = 0;
-  Programmer::Generic *generic = createProgrammer(data);
-  Q_ASSERT( !(generic->group().properties() & Programmer::Custom) );
-  Programmer::Base *base = static_cast<Programmer::Base *>(generic);
-  ::Programmer::AdvancedDialog *dialog = groupui->createAdvancedDialog(*base, MainWindow::self());
+  ::Programmer::Generic *generic = createProgrammer(data);
+  Q_ASSERT( !(generic->group().properties() & ::Programmer::Custom) );
+  typedef ::Programmer::Base Base; // for g++ 3.3.6
+  Base* base = static_cast<Base*>(generic);
+  ::Programmer::AdvancedDialog *dialog = groupui->createAdvancedDialog(*base, &MainWindow::self());
   Q_ASSERT(dialog);
   dialog->updateDisplay();
   dialog->exec();
