@@ -19,7 +19,7 @@ class GuiManager : public Manager
 Q_OBJECT
 public:
   GuiManager(QObject *parent) : Manager(parent) {}
-  virtual void createProgrammer(const Device::Data *data);
+  virtual ::Programmer::Generic *createProgrammer(const Device::Data *data);
   virtual void setState(State state) { Main::setState(state==Idle ? Main::Idle : Main::Programming); }
 
 public slots:
@@ -28,7 +28,7 @@ public slots:
 
 private:
   virtual const Group &group() const { return Main::programmerGroup(); }
-  virtual bool internalInitProgramming(bool debugging);
+  virtual bool internalInitProgramming(bool debugging, ProgramAction action);
   virtual const Device::Data *device() const { return Main::deviceData(); }
 };
 
