@@ -61,8 +61,8 @@ HexEditor::HexEditor(QWidget *parent)
 void HexEditor::init()
 {
   _modified = false;
-  _memory = 0;
-  _originalMemory = 0;
+  _memory = NULL;
+  _originalMemory = NULL;
   _top->addStretch(1);
   _part = new HexEditorPart(this);
   setReadOnly(false);
@@ -71,19 +71,17 @@ void HexEditor::init()
 void HexEditor::clear()
 {
   delete _memory;
-  _memory = 0;
+  _memory = NULL;
   delete _originalMemory;
-  _originalMemory = 0;
+  _originalMemory = NULL;
 }
 
 QWidget *HexEditor::createView(const Device::Data *data, QWidget *parent)
 {
   clear();
-  if (data) {
-    _originalMemory = data->group().createMemory(*data);
-    _memory = data->group().createMemory(*data);
-  }
-  if ( data==0 ) return new QWidget(parent);
+  if (data == NULL) return new QWidget(parent);
+  _originalMemory = data->group().createMemory(*data);
+  _memory = data->group().createMemory(*data);
   Device::HexView *hv = Device::groupui(*data).createHexView(*this, parent);
   connect(hv, SIGNAL(modified()), SLOT(slotModified()));
   _dirty = true;
@@ -95,7 +93,7 @@ bool HexEditor::simpleLoad()
 {
   if ( !_dirty ) return true;
   _dirty = false;
-  if (_memory) {
+  if (_memory != NULL) {
     QStringList warnings;
     if ( _memory->fromHexBuffer(_hexBuffer, warnings)!=Device::Memory::NoWarning ) {
       _labelWarning->setText(i18n("<b>Warning:</b> hex file seems to be incompatible with the selected device %1:<br>%2")
@@ -115,12 +113,12 @@ void HexEditor::setReadOnlyInternal(bool readOnly)
 
 void HexEditor::addGui()
 {
-  MainWindow::self()->guiFactory()->addClient(_part);
+  MainWindow::self().guiFactory()->addClient(_part);
 }
 
 void HexEditor::removeGui()
 {
-  MainWindow::self()->guiFactory()->removeClient(_part);
+  MainWindow::self().guiFactory()->removeClient(_part);
 }
 
 bool HexEditor::open(const PURL::Url &url)
