@@ -20,8 +20,7 @@ class Widget : public KTextEdit, public View
 {
   Q_OBJECT
 public:
-  Widget(QWidget *parent = 0, const char *name = 0);
-  virtual void appendToLastLine(const QString &text);
+  Widget(QWidget *parent = NULL, const char *name = NULL);
   virtual void clear();
   virtual void sorry(const QString &message, const QString &details);
   virtual bool askContinue(const QString &message);
