@@ -46,10 +46,10 @@ public:
   static const Device::Data *deviceData();
   static Breakpoint::View &breakpointsView() { return *_breakpointsView; }
   static ProjectManager::View &projectManager() { return *_projectManager; }
-  static Project *project();
+  static Project* project();
   static Register::WatchView &watchView() { return *_watchView; }
   static Compile::LogWidget &compileLog() { return *_compileLog; }
-  static const Tool::Group &toolGroup();
+  static const Tool::Group* toolGroup();
 
 private:
   static State                 _state;
