@@ -9,13 +9,22 @@
  ***************************************************************************/
 #include "project.h"
 
+#include <memory>
+
 #include <ksimpleconfig.h>
+#include <kstandarddirs.h>
 
 #include "devices/list/device_list.h"
 #include "progs/base/prog_group.h"
 #include "global_config.h"
 #include "tools/gputils/gputils_config.h"
 
+
+Project::Project(const PURL::Url& url)
+: XmlDataFile(url, "piklab")
+{
+}
+
 bool Project::load(QString &error)
 {
   if ( _url.fileType()==PURL::Project ) return XmlDataFile::load(error);
@@ -27,7 +36,7 @@ bool Project::load(QString &error)
   PURL::Url tmp = _url;
   _url = _url.toFileType(PURL::Project);
   if ( _url.exists() && XmlDataFile::load(error) ) return true;
-  KConfig *config = new KSimpleConfig(tmp.filepath(), false);
+  std::auto_ptr<KConfig> config(new KSimpleConfig(tmp.filepath(), false));
 
   config->setGroup("Files");
   QStringList list = config->readListEntry("inputFiles");
@@ -40,9 +49,9 @@ bool Project::load(QString &error)
 
   config->setGroup("Assembler");
   QString device = config->readEntry("target-device");
-  if ( device=="*" ) device = GlobalConfig::programmerGroup().supportedDevices()[0]; // compatibility
+  if ( device=="*" ) device = Compile::Config::programmerGroup(NULL).supportedDevices()[0]; // compatibility
   Compile::Config::setDevice(this, Device::lister().checkName(device));
-  GPUtils::Config *gconfig = new GPUtils::Config(this);
+  std::auto_ptr<GPUtils::Config> gconfig(new GPUtils::Config(*this));
   gconfig->setGPAsmWarningLevel(QMIN(config->readUnsignedNumEntry("warn-level", 0), uint(GPUtils::Config::Nb_WarningLevels)));
   gconfig->setRawIncludeDirs(Tool::Category::Assembler, config->readEntry("include-dir", QString::null));
   gconfig->setRawCustomOptions(Tool::Category::Assembler, config->readEntry("other-options", QString::null));
@@ -54,8 +63,6 @@ bool Project::load(QString &error)
   gconfig->setRawIncludeDirs(Tool::Category::Linker, config->readEntry("objs-libs-dir", QString::null));
   gconfig->setRawCustomOptions(Tool::Category::Linker, config->readEntry("other-options", QString::null));
 
-  delete gconfig;
-  delete config;
   return true;
 }
 
@@ -63,10 +70,10 @@ PURL::UrlList Project::openedFiles() const
 {
   PURL::UrlList files;
   QStringList list = listValues("general", "opened_files", QStringList());
-  QStringList::const_iterator it = list.begin();
-  for (; it!=list.end(); ++it) {
-    if ( PURL::Url::fromPathOrUrl(*it).isRelative() ) files += PURL::Url(directory(), *it);
-    else files += PURL::Url::fromPathOrUrl(*it);
+  for (QStringList::const_iterator it = list.begin(); it != list.end(); ++it) {
+    PURL::Url url = PURL::fromPathOrUrl(*it, true);
+    if (url.isRelative()) files += PURL::Url(directory(), *it);
+    else files += url;
   }
   return files;
 }
@@ -82,8 +89,8 @@ PURL::UrlList Project::absoluteFiles() const
 {
   PURL::UrlList abs;
   QStringList files = listValues("general", "files", QStringList());
-  QStringList::const_iterator it = files.begin();
-  for (; it!=files.end(); ++it) abs += PURL::Url::fromPathOrUrl(*it).toAbsolute(directory());
+  for (QStringList::const_iterator it = files.begin(); it != files.end(); ++it)
+    abs += PURL::fromPathOrUrl(*it, true).toAbsolute(directory());
   return abs;
 }
 void Project::addFile(const PURL::Url &url)
@@ -161,7 +168,7 @@ void Project::setDescription(const QString &description)
 PURL::Url Project::customLinkerScript() const
 {
   QString s = Compile::Config::globalValue(this, "custom_linker_script", QString::null);
-  return PURL::Url::fromPathOrUrl(s);
+  return PURL::fromPathOrUrl(s, true);
 }
 void Project::setCustomLinkerScript(const PURL::Url &url)
 {
@@ -172,8 +179,7 @@ QValueList<Register::TypeData> Project::watchedRegisters() const
 {
   QValueList<Register::TypeData> watched;
   QStringList list = listValues("general", "watched_registers", QStringList());
-  QStringList::const_iterator it;
-  for (it=list.begin(); it!=list.end(); ++it) {
+  for (QStringList::const_iterator it = list.begin(); it != list.end(); ++it) {
     Register::TypeData rtd = Register::TypeData::fromString(*it);
     if ( rtd.type()!=Register::Invalid ) watched.append(rtd);
   }
