@@ -18,7 +18,7 @@
 class Project : public XmlDataFile
 {
 public:
-  Project(const PURL::Url &url) : XmlDataFile(url, "piklab") {}
+  Project(const PURL::Url &url);
   virtual bool load(QString &error);
 
   PURL::Directory directory() const { return url().directory(); }
