@@ -16,10 +16,12 @@
 #include "project.h"
 #include "tools/list/compile_config.h"
 #include "device_gui.h"
+#include "progs/list/prog_list.h"
 
-ProjectEditor::ProjectEditor(Project &project, QWidget *parent)
-  : Dialog(parent, "project_options", true, i18n("Project Options"), Ok|Cancel, Ok, false),
-    _project(project)
+//----------------------------------------------------------------------------
+ProjectEditor::ProjectEditor(Project &project, PageType type, QWidget *parent)
+: Dialog(parent, "project_options", true, i18n("Project Options"), Ok|Cancel, Ok, false),
+  _project(project)
 {
    QVBoxLayout *top = new QVBoxLayout(mainWidget(), 0, 10);
   TabWidget *tabWidget = new TabWidget(mainWidget());
@@ -48,18 +50,26 @@ ProjectEditor::ProjectEditor(Project &project, QWidget *parent)
   _device = new DeviceChooser::Button(tab);
   _device->setDevice(Compile::Config::device(&_project));
   grid->addWidget(_device, 3, 1);
-  grid->setRowStretch(4, 1);
+  label = new QLabel(i18n("Programmer:"), tab);
+  grid->addWidget(label, 4, 0);
+  _prog.reset(new ListerComboBox<Programmer::Lister>(tab));
+  _prog->setGroup(Compile::Config::programmerGroup(&_project));
+  grid->addWidget(_prog->widget(), 4, 1);
+
+  grid->setRowStretch(5, 1);
   grid->setColStretch(2, 1);
 
 // toochain
   tab = new QWidget(tabWidget);
   tabWidget->addTab(tab, i18n("Toochain"));
   grid = new QGridLayout(tab, 0, 0, 10, 10);
-  _tools = new ToolsConfigWidget(&project, tab);
+  _tools = new ToolsConfigWidget(project, tab);
   _tools->loadConfig();
   grid->addMultiCellWidget(_tools, 0,0, 0,2);
   grid->setRowStretch(1, 1);
   grid->setColStretch(2, 1);
+
+  tabWidget->setCurrentPage(type);
 }
 
 void ProjectEditor::slotOk()
@@ -67,6 +77,7 @@ void ProjectEditor::slotOk()
   _project.setDescription(_description->text());
   _project.setVersion(_version->text());
   Compile::Config::setDevice(&_project, _device->device());
+  Compile::Config::setProgrammerGroup(&_project, _prog->group());
   _tools->saveConfig();
   accept();
 }
