@@ -1,18 +1,11 @@
 /***************************************************************************
-                          ProjectEditorWid.cpp  -  description
-                             -------------------
-    begin                : lun dc 8 2003
-    copyright            : (C) 2003 by Alain Gibaud
-    email                : alain.gibaud@univ-valenciennes.fr
- ***************************************************************************/
-
-/***************************************************************************
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2003 Alain Gibaud <alain.gibaud@free.fr>                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
- *                                                                         *
  ***************************************************************************/
 #ifndef PROJECT_EDITOR_H
 #define PROJECT_EDITOR_H
@@ -24,6 +17,7 @@
 
 #include "tools/list/tools_config_widget.h"
 #include "common/gui/misc_gui.h"
+#include "progs/list/prog_list.h"
 class Project;
 namespace DeviceChooser { class Button; }
 
@@ -31,7 +25,8 @@ class ProjectEditor : public Dialog
 {
 Q_OBJECT
 public:
-  ProjectEditor(Project &project, QWidget *parent);
+  enum PageType { Main = 0, Toolchain };
+  ProjectEditor(Project &project, PageType type, QWidget *parent);
 
 private slots:
   virtual void slotOk();
@@ -41,6 +36,7 @@ private:
   QTextEdit *_description;
   QLineEdit *_version;
   DeviceChooser::Button *_device;
+  std::auto_ptr<ListerComboBox<Programmer::Lister> > _prog;
   ToolsConfigWidget *_tools;
 };
 
