@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2006 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *   Copyright (C) 2003 Alain Gibaud <alain.gibaud@free.fr>                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -33,10 +33,16 @@
 #include "main_global.h"
 #include "common/gui/purl_gui.h"
 #include "device_gui.h"
+#include "progs/manager/debug_manager.h"
+#include "tools/list/tool_list.h"
+#include "progs/list/prog_list.h"
+
+#include <iostream>
 
 //----------------------------------------------------------------------------
 ProjectManager::View::View(QWidget *parent)
-  : ListView(parent, "project_manager"), _project(0), _modified(false)
+: ListView(parent, "project_manager"),
+  _modified(false)
 {
   connect(this, SIGNAL(mouseButtonClicked(int, QListViewItem *, const QPoint &, int)),
           SLOT(clicked(int, QListViewItem *, const QPoint &, int)));
@@ -59,20 +65,31 @@ ProjectManager::View::View(QWidget *parent)
 
 ProjectManager::View::~View()
 {
-  delete _project;
 }
 
 void ProjectManager::View::init()
 {
   clear();
+
   _rootItem  = new RootItem(this);
   setCurrentItem(_rootItem);
-  KListViewItem *item = new RegisterItem(headerItem(DeviceGroup));
+  KListViewItem *item = new RegisterItem(headerItem(Group::Device));
   ensureItemVisible(item);
-  _deviceItem = new DeviceItem(headerItem(DeviceGroup));
+  item = new DeviceInfoItem(headerItem(Group::Device));
+  ensureItemVisible(item);
+  _deviceItem = new DeviceItem(headerItem(Group::Device));
   ensureItemVisible(_deviceItem);
-  _linkerScriptItem = 0;
-  (void)headerItem(SourceGroup);
+  _programmerItem = new ProgrammerItem(headerItem(Group::Programmer));
+  ensureItemVisible(_programmerItem);
+
+  _linkerScriptItem = NULL;
+  if (_project.get() != NULL) {
+    _toolchainItem = new ToolchainItem(headerItem(Group::Toolchain));
+    ensureItemVisible(_toolchainItem);
+    (void)headerItem(Group::Source);
+  } else {
+    _toolchainItem = NULL;
+  }
 }
 
 ProjectManager::HeaderItem *ProjectManager::View::findHeaderItem(Group group) const
@@ -83,28 +100,28 @@ ProjectManager::HeaderItem *ProjectManager::View::findHeaderItem(Group group) co
     HeaderItem *hi = static_cast<HeaderItem *>(it.current());
     if ( hi->group()==group ) return hi;
   }
-  return 0;
+  return NULL;
 }
 
 ProjectManager::HeaderItem *ProjectManager::View::headerItem(Group group)
 {
   HeaderItem *item = findHeaderItem(group);
-  if (item) return item;
+  if (item != NULL) return item;
   item = new HeaderItem(_rootItem, group);
   // reorder groups...
-  HeaderItem *items[Nb_Groups];
-  for (uint i=0; i<Nb_Groups; i++) {
-    items[i] = findHeaderItem(Group(i));
-    if (items[i]) _rootItem->takeItem(items[i]);
+  HeaderItem *items[Group::Nb_Types];
+  FOR_EACH(Group, group) {
+    HeaderItem* item = findHeaderItem(group);
+    items[group.type()] = item;
+    if (item != NULL) _rootItem->takeItem(item);
   }
-  for (int i=Nb_Groups-1; i>=0; i--) {
-    if ( items[i]==0 ) continue;
-    _rootItem->insertItem(items[i]);
+  for (int i=Group::Nb_Types-1; i>=0; i--) {
+    if (items[i] != NULL) _rootItem->insertItem(items[i]);
   }
   return item;
 }
 
-ProjectManager::FileItem *ProjectManager::View::findFileItem(const PURL::Url &url) const
+ProjectManager::FileItem* ProjectManager::View::findFileItem(const PURL::Url &url) const
 {
   QListViewItemIterator it(const_cast<View *>(this));
   for(; it.current(); ++it) {
@@ -112,7 +129,7 @@ ProjectManager::FileItem *ProjectManager::View::findFileItem(const PURL::Url &ur
     FileItem *fi = static_cast<FileItem *>(it.current());
     if ( fi->url()==url ) return fi;
   }
-  return 0;
+  return NULL;
 }
 
 ProjectManager::FileItem *ProjectManager::View::findFileItem(PURL::FileType type) const
@@ -123,29 +140,24 @@ ProjectManager::FileItem *ProjectManager::View::findFileItem(PURL::FileType type
     FileItem *fi = static_cast<FileItem *>(it.current());
     if ( fi->ftype()==type ) return fi;
   }
-  return 0;
+  return NULL;
 }
 
 QListViewItem *ProjectManager::View::findItem(const QString &tag) const
 {
-  QListViewItemIterator it(const_cast<View *>(this));
-  for(; it.current(); ++it) {
-    switch (Rtti(it.current()->rtti())) {
-      case RootRtti:
-      case FileRtti:
-      case LinkerScriptRtti:
-      case DeviceRtti: continue;
-      case HeaderRtti:
-      case RegisterRtti: break;
-    }
-    if ( it.current()->text(0)==tag ) return it.current();
+  for(QListViewItemIterator it(const_cast<View *>(this)); it.current() != NULL; ++it) {
+    Rtti rtti = static_cast<Rtti>(it.current()->rtti());
+    if (rtti == RegisterRtti
+        && tag == SpecialEditorType(SpecialEditorType::Registers).key()) return it.current();
+    if (rtti == DeviceInfoRtti
+        && tag == SpecialEditorType(SpecialEditorType::DeviceInfos).key()) return it.current();
   }
-  return 0;
+  return NULL;
 }
 
 void ProjectManager::View::select(const Editor *e)
 {
-  QListViewItem *item = 0;
+  QListViewItem *item = NULL;
   if ( e->url().isEmpty() ) item = findItem(e->tag());
   else item = findFileItem(e->url());
   if (item) setSelected(item, true);
@@ -154,20 +166,20 @@ void ProjectManager::View::select(const Editor *e)
 
 void ProjectManager::View::contextMenu(QListViewItem *item, const QPoint &p, int)
 {
-  if ( item==0 ) return;
+  if ( item==NULL ) return;
 
   PopupMenu pop;
-  Group group = Nb_Groups;
-  if ( item->rtti()==HeaderRtti) group = static_cast<const HeaderItem *>(item)->group();
+  Group group;
+  if ( item->rtti()==HeaderRtti ) group = static_cast<const HeaderItem *>(item)->group();
 
-  if ( item->rtti()==LinkerScriptRtti || group==LinkerScriptGroup ) {
-    if ( _project==0 || Main::toolGroup().linkerScriptType()==PURL::Nb_FileTypes ) return;
+  if ( item->rtti()==LinkerScriptRtti || group==Group::LinkerScript ) {
+    if ( Main::toolGroup()->linkerScriptType()==PURL::Nb_FileTypes ) return;
     pop.insertTitle(i18n("Linker Script"));
     pop.insertItem("piklab_addfile", i18n("Set Custom..."));
     if ( !_project->customLinkerScript().isEmpty() ) pop.insertItem("editdelete", i18n("Set Default"));
     switch( pop.exec(p) ) {
       case 1: {
-        PURL::Url url = PURL::getOpenUrl(":custom_linker_script", PURL::filter(Main::toolGroup().linkerScriptType()), this, i18n("Select Linker Script"));
+        PURL::Url url = PURL::getOpenUrl(":custom_linker_script", PURL::filter(Main::toolGroup()->linkerScriptType()), this, i18n("Select Linker Script"));
         if ( !url.isEmpty() ) _project->setCustomLinkerScript(url);
         break;
       }
@@ -175,130 +187,111 @@ void ProjectManager::View::contextMenu(QListViewItem *item, const QPoint &p, int
     }
     _linkerScriptItem->init();
   } else if ( item->rtti()==RootRtti ) {
-    RootItem *ri = static_cast<RootItem *>(item);
-    if ( _project==0 ) {
-      if ( ri->url().isEmpty() ) {
-        pop.insertItem("piklab_createproject", i18n("New Project..."), MainWindow::self(), SLOT(newProject()));
-        pop.insertItem("piklab_openproject", i18n("Open Project..."), MainWindow::self(), SLOT(openProject()));
-        pop.exec(p);
-      } else {
-        pop.insertTitle(i18n("Standalone File"));
-        pop.insertItem("configure", i18n("Configure..."));
-        if ( pop.exec(p)==1 ) MainWindow::self()->configure(ConfigCenter::Standalone);
-      }
-    } else {
+    if (_project.get() != NULL) {
       pop.insertTitle(i18n("Project"));
-      pop.insertItem("configure", i18n("Options..."), MainWindow::self(), SLOT(configureProject()));
-      pop.insertItem("find", i18n("Find Files..."),   MainWindow::self(), SLOT(runKfind()));
+      pop.insertItem("configure", i18n("Options..."), &MainWindow::self(), SLOT(configureProject()));
+      pop.insertItem("find", i18n("Find Files..."),   &MainWindow::self(), SLOT(runKfind()));
       pop.insertSeparator();
-      pop.insertItem("piklab_compile", i18n("Build Project"), MainWindow::self(), SLOT(buildProject()));
-      pop.insertItem("trashcan_empty", i18n("Clean Project"), MainWindow::self(), SLOT(cleanBuild()));
+      pop.insertItem("piklab_compile", i18n("Build Project"), &MainWindow::self(), SLOT(buildProject()));
+      pop.insertItem("trashcan_empty", i18n("Clean Project"), &MainWindow::self(), SLOT(cleanBuild()));
       pop.insertSeparator();
-      pop.insertItem("filenew", i18n("New Source File..."), MainWindow::self(), SLOT(newSourceFile()));
+      pop.insertItem("filenew", i18n("New Source File..."), &MainWindow::self(), SLOT(newSourceFile()));
       pop.insertItem("piklab_addfile", i18n("Add Source Files..."), this, SLOT(insertSourceFiles()));
       pop.insertItem("piklab_addfile", i18n("Add Object Files..."), this, SLOT(insertObjectFiles()));
-      if ( Main::currentEditor() ) pop.insertItem("piklab_addcurrentfile", i18n("Add Current File"), this, SLOT(insertCurrentFile()));
+      if (Main::currentEditor() != NULL) pop.insertItem("piklab_addcurrentfile", i18n("Add Current File"), this, SLOT(insertCurrentFile()));
       pop.exec(p);
     }
   } else if ( item->rtti()==FileRtti ) {
-    if ( _project==0 ) return;
     FileItem *fi = static_cast<FileItem *>(item);
     if ( isExternalFile(fi->url()) ) return;
     pop.insertTitle(item->text(0));
     pop.insertItem("editdelete", i18n("Remove From Project"));
     if ( pop.exec(p)==1 ) removeFile(fi->url());
   } else if ( item->rtti()==HeaderRtti ) {
-    if ( _project==0 ) return;
-    if ( group==LinkerObjectGroup ) {
-      pop.insertTitle(i18n("Objects"));
-      pop.insertItem("piklab_addfile", i18n("Add Object Files..."), this, SLOT(insertObjectFiles()));
-      pop.exec(p);
-    } else if ( group==SourceGroup || group==HeaderGroup ) {
-      pop.insertTitle(i18n("Sources"));
-      pop.insertItem("filenew", i18n("New File..."), MainWindow::self(), SLOT(newSourceFile()));
-      pop.insertItem("piklab_addfile", i18n("Add Source Files..."), this, SLOT(insertSourceFiles()));
-      pop.exec(p);
-    } else if ( group==DeviceGroup ) {
-      pop.insertItem("filenew", i18n("Select Device..."), MainWindow::self(), SLOT(showDeviceInfo()));
-      pop.exec(p);
+    switch (group.type()) {
+      case Group::LinkerObject:
+        pop.insertTitle(i18n("Objects"));
+        pop.insertItem("piklab_addfile", i18n("Add Object Files..."), this, SLOT(insertObjectFiles()));
+        pop.exec(p);
+        break;
+      case Group::Source:
+      case Group::Header:
+        pop.insertTitle(i18n("Sources"));
+        pop.insertItem("filenew", i18n("New File..."), &MainWindow::self(), SLOT(newSourceFile()));
+        pop.insertItem("piklab_addfile", i18n("Add Source Files..."), this, SLOT(insertSourceFiles()));
+        pop.exec(p);
+        break;
+      case Group::Device:
+        pop.insertTitle(i18n("Device"));
+        pop.insertItem("piklab_chip", i18n("Select..."), &MainWindow::self(), SLOT(showDeviceInfo()));
+        pop.exec(p);
+        break;
+      case Group::Toolchain:
+        pop.insertTitle(i18n("Toolchain"));
+        pop.insertItem("configure", i18n("Options..."), &MainWindow::self(), SLOT(configureProjectToolchain()));
+        pop.insertItem("exec", i18n("Configure Toolchains..."), &MainWindow::self(), SLOT(configureToolchains()));
+        pop.exec(p);
+        break;
+      case Group::Programmer:
+        pop.insertTitle(i18n("Programmer"));
+        pop.insertItem("piklab_config_programmer", i18n("Configure Programmers..."), &MainWindow::self(), SLOT(configureProgrammers()));
+        pop.exec(p);
+        break;
+      case Group::LinkerScript:
+      case Group::Generated:
+      case Group::Included:
+      case Group::Nb_Types:
+        break;
     }
   }
 }
 
+void ProjectManager::View::saveProject()
+{
+  if (_project.get() == NULL) return;
+  PURL::UrlList opened;
+  PURL::UrlList files = Main::editorManager().files();
+  for (PURL::UrlList::const_iterator it = files.begin(); it!=files.end(); ++it) {
+    if ( !isExternalFile(*it) ) opened += *it;
+  }
+  _project->setOpenedFiles(opened);
+  _project->setWatchedRegisters(Register::list().watched());
+  QString error;
+  if ( !_project->save(error) ) {
+    MessageBox::detailedSorry(i18n("Could not save project file \"%1\".").arg(_project->url().pretty()), error, Log::Show);
+  }
+}
+
 void ProjectManager::View::closeProject()
 {
-  if ( _project==0 && projectUrl().isEmpty() ) return;
-  if (_project) {
-    // save opened files
-    PURL::UrlList files = Main::editorManager().files();
-    PURL::UrlList::const_iterator it = files.begin();
-    PURL::UrlList opened;
-    for (; it!=files.end(); ++it) {
-      if ( !isExternalFile(*it) ) opened += *it;
-      Main::editorManager().closeEditor(*it);
-    }
-    _project->setOpenedFiles(opened);
-    // save watched registers
-    _project->setWatchedRegisters(Register::list().watched());
-    QString error;
-    if ( !_project->save(error) )
-      MessageBox::detailedSorry(i18n("Could not save project file \"%1\".").arg(_project->url().pretty()), error, Log::Show);
-    delete _project;
-    _project = 0;
-  }
-  _modified = false;
+  if (_project.get() == NULL) return;
+  saveProject();
+  Main::editorManager().closeAllEditors();
+  _project.reset(NULL);
   init();
 }
 
 void ProjectManager::View::addExternalFiles()
 {
   const QMap<PURL::Url, FileOrigin> &ext = projectData().externals;
-  QMap<PURL::Url, FileOrigin>::const_iterator it;
-  for (it=ext.begin(); it!=ext.end(); ++it) {
+  for (QMap<PURL::Url, FileOrigin>::const_iterator it=ext.begin(); it!=ext.end(); ++it) {
     if ( !it.key().exists() ) continue;
     addFile(it.key(), it.key().fileType(), it.data());
   }
 }
 
-void ProjectManager::View::setStandalone(const PURL::Url &url, PURL::FileType type)
-{
-  if ( projectUrl()==url ) return;
-  closeProject();
-  _rootItem->set(url, true);
-  addFile(url, type, Intrinsic);
-  _standaloneData[url].type = type;
-  addExternalFiles();
-}
-
-PURL::Url ProjectManager::View::standaloneGenerator(const PURL::Url &url, PURL::FileType &type) const
-{
-  QMap<PURL::Url, ProjectData>::const_iterator it;
-  for (it=_standaloneData.begin(); it!=_standaloneData.end(); ++it) {
-    if ( !it.data().externals.contains(url) ) continue;
-    if ( !it.key().exists() ) continue;
-    type = it.data().type;
-    return it.key();
-  }
-  type = PURL::Nb_FileTypes;
-  return url;
-}
-
 void ProjectManager::View::insertSourceFiles()
 {
-  Q_ASSERT(_project);
   PURL::UrlList list = PURL::getOpenUrls(":<sources>", PURL::sourceFilter(PURL::CompleteFilter), this, i18n("Select Source File"));
   if ( list.isEmpty() ) return;
-  PURL::UrlList::const_iterator it;
-  for (it=list.begin(); it!=list.end(); ++it) insertFile(*it);
+  for (PURL::UrlList::const_iterator it=list.begin(); it!=list.end(); ++it) insertFile(*it);
 }
 
 void ProjectManager::View::insertObjectFiles()
 {
-  Q_ASSERT(_project);
   PURL::UrlList list = PURL::getOpenUrls(":<objects>", PURL::objectFilter(PURL::CompleteFilter), this, i18n("Select Object File"));
   if ( list.isEmpty() ) return;
-  PURL::UrlList::const_iterator it;
-  for (it=list.begin(); it!=list.end(); ++it) insertFile(*it);
+  for (PURL::UrlList::const_iterator it=list.begin(); it!=list.end(); ++it) insertFile(*it);
 }
 
 void ProjectManager::View::insertFile(const PURL::Url &url)
@@ -342,18 +335,6 @@ void ProjectManager::View::addExternalFile(const PURL::Url &url, FileOrigin orig
   addFile(url, url.fileType(), origin);
 }
 
-const ProjectManager::View::ProjectData &ProjectManager::View::projectData() const
-{
-  if ( _project==0 ) return _standaloneData[projectUrl()];
-  return _projectData;
-}
-
-ProjectManager::View::ProjectData &ProjectManager::View::projectData()
-{
-  if ( _project==0 ) return _standaloneData[projectUrl()];
-  return _projectData;
-}
-
 void ProjectManager::View::addFile(const PURL::Url &url, PURL::FileType type, FileOrigin origin)
 {
   if ( contains(url) ) return;
@@ -364,26 +345,18 @@ void ProjectManager::View::addFile(const PURL::Url &url, PURL::FileType type, Fi
     return;
   }
   PURL::FileProperties properties = type.data().properties;
-  Group grp = Nb_Groups;
+  Group grp;
   switch (origin) {
     case Intrinsic: grp = group(type); break;
-    case Generated: grp = GeneratedGroup; break;
-    case Included:  grp = IncludedGroup; break;
+    case Generated: grp = Group::Generated; break;
+    case Included:  grp = Group::Included; break;
   }
   HeaderItem *hitem = headerItem(grp);
   QListViewItem *item = new FileItem(hitem, type, url, origin!=Intrinsic);
   item->moveItem(hitem->lastChild());
   ensureItemVisible(item);
   if ( origin!=Intrinsic ) ext[url] = origin;
-  if ( type==PURL::Hex && _project==0 ) {
-    QString extension = PURL::extension(PURL::AsmGPAsm);
-    PURL::Url durl = PURL::Url::fromPathOrUrl("<" + (url.isEmpty() ? i18n("Disassembly") : url.appendExtension(extension).filename()) + ">");
-    if ( findFileItem(durl)==0 ) {
-      (void)new FileItem(headerItem(ViewGroup), PURL::Coff, durl, true);
-      ext[durl] = Generated;
-    }
-  }
-  if ( _project && origin==Intrinsic ) _modified = true;
+  if ( origin==Intrinsic ) _modified = true;
 }
 
 void ProjectManager::View::removeExternalFiles()
@@ -400,11 +373,12 @@ void ProjectManager::View::removeExternalFiles()
 
 void ProjectManager::View::removeFile(const PURL::Url &url)
 {
-  if ( _project && !isExternalFile(url) ) _project->removeFile(url);
+  if ( !isExternalFile(url) ) _project->removeFile(url);
   FileItem *item = findFileItem(url);
-  if ( item==0 ) return;
+  if ( item==NULL ) return;
   HeaderItem *group = static_cast<HeaderItem *>(item->parent());
   delete item;
+  item = NULL;
   if ( group->childCount()==0 ) delete group;
   _modified = true;
   emit guiChanged();
@@ -412,40 +386,41 @@ void ProjectManager::View::removeFile(const PURL::Url &url)
 
 void ProjectManager::View::clicked(int button, QListViewItem *item, const QPoint &, int)
 {
-  if ( item==0 ) return;
+  if ( item==NULL ) return;
   if ( button!=LeftButton ) return;
   const Device::Data *data = Main::deviceData();
   Rtti rtti = Rtti(item->rtti());
-  if ( data==0 && rtti!=DeviceRtti && rtti!=RootRtti ) {
+  if ( data==NULL && rtti!=DeviceRtti && rtti!=RootRtti ) {
     MessageBox::sorry(i18n("Cannot open without device specified."), Log::Show);
     return;
   }
-  Editor *e = 0;
+  Editor *e = NULL;
   ::BusyCursor bc;
   switch (rtti) {
     case RootRtti:
-      MainWindow::self()->configureProject();
+      MainWindow::self().configureProject();
       break;
-    case HeaderRtti: {
-      if ( static_cast<HeaderItem *>(item)->group()!=DeviceGroup ) break;
-      e = Main::editorManager().openEditor(EditorManager::DeviceEditor);
+    case HeaderRtti: break;
+    case DeviceInfoRtti:
+      e = Main::editorManager().openEditor(SpecialEditorType::DeviceInfos);
       break;
-    }
     case RegisterRtti:
-      e = Main::editorManager().openEditor(EditorManager::RegisterEditor);
+      e = Main::editorManager().openEditor(SpecialEditorType::Registers);
       break;
+    case ToolchainRtti:
+    case ProgrammerRtti:
     case DeviceRtti: return;
     case LinkerScriptRtti: {
       PURL::Url url = Main::projectManager().linkerScriptUrl();
       if ( url.isEmpty() ) break;
       e = Main::editorManager().findEditor(url);
-      if ( e==0 ) {
+      if ( e==NULL ) {
         e = Main::editorManager().createEditor(url.fileType(), url);
         if ( !e->open(url) ) {
-	  delete e;
-	  break;
-	}
-        if ( e && isExternalFile(url) ) e->setReadOnly(true);
+          delete e;
+          break;
+        }
+        if ( e != NULL && isExternalFile(url) ) e->setReadOnly(true);
         Main::editorManager().addEditor(e);
       } else Main::editorManager().showEditor(e);
       break;
@@ -454,21 +429,17 @@ void ProjectManager::View::clicked(int button, QListViewItem *item, const QPoint
       FileItem *fi = static_cast<FileItem *>(item);
       if ( !(fi->ftype().data().properties & PURL::Editable) ) break;
       e = Main::editorManager().findEditor(fi->url());
-      if ( e==0 ) {
-        if ( fi->ftype()==PURL::Coff && _project==0 && !fi->url().exists() ) {
-          PURL::Url url = findFileItem(PURL::Hex)->url();
-          if ( url.isEmpty() ) {
-            HexEditor *he = ::qt_cast<HexEditor *>(Main::currentEditor());
-            if ( he==0 ) break;
-            e = new DisassemblyEditor(*he, *data, this);
-          } else e = new DisassemblyEditor(url, *data, this);
-          addExternalFile(fi->url(), Generated);
-        } else e = Main::editorManager().createEditor(fi->url().fileType(), fi->url());
-        if ( e==0 ) break;
+      if ( e==NULL ) {
+        if ( fi->ftype()==PURL::Coff
+             && !Debugger::manager->isInited() ) {
+           MainWindow::self().initDebugger();
+        }
+        e = Main::editorManager().createEditor(fi->url().fileType(), fi->url());
+        if ( e==NULL ) break;
         if ( !e->open(fi->url()) ) {
-	  delete e;
-	  break;
-	}
+          delete e;
+          break;
+        }
         if ( isExternalFile(fi->url()) ) e->setReadOnly(true);
         Main::editorManager().addEditor(e);
       } else Main::editorManager().showEditor(e);
@@ -484,9 +455,9 @@ void ProjectManager::View::insertCurrentFile()
   insertFile(Main::editorManager().currentEditor()->url());
 }
 
-bool ProjectManager::View::editProject()
+bool ProjectManager::View::configureProject(ProjectEditor::PageType type)
 {
-  ProjectEditor dialog(*_project, this);
+  ProjectEditor dialog(*_project, type, this);
   if ( dialog.exec()!=QDialog::Accepted ) return false;
   _modified = true;
   if (_linkerScriptItem) _linkerScriptItem->init();
@@ -507,44 +478,49 @@ bool ProjectManager::View::newProject()
   return true;
 }
 
-void ProjectManager::View::setProject(Project *project)
+bool ProjectManager::View::openProject(const PURL::Url& url)
 {
-  closeProject();
-  Main::editorManager().closeAllEditors();
-  _project = project;
-  _rootItem->set(project->url(), false);
-  if ( project && Main::toolGroup().linkerScriptType()!=PURL::Nb_FileTypes ) {
-    _linkerScriptItem = new LinkerScriptItem(headerItem(LinkerScriptGroup));
-    ensureItemVisible(_linkerScriptItem);
-  }
-}
-
-bool ProjectManager::View::openProject(const PURL::Url &url)
-{
-  if ( url.isEmpty() ) return false;
-  bool reload = ( _project && _project->url()==url );
-  if ( reload && !MessageBox::askContinue(i18n("Project already loaded. Reload?"), i18n("Reload")) ) return false;
-  static_cast< KRecentFilesAction *>(Main::action("project_open_recent"))->removeURL(url.kurl());
-  Project *p = new Project(url);
-  QString error;
-  if ( !p->load(error) ) {
-    MessageBox::detailedSorry(i18n("Could not open project file."), error, Log::Show);
-    delete p;
+  if (url.isEmpty()) return false;
+  static_cast<KRecentFilesAction *>(Main::action("project_open_recent"))->removeURL(url.kurl());
+  bool reload = (_project.get() != NULL && _project->url()==url);
+  if (reload
+      && !MessageBox::askContinue(i18n("Project already loaded. Reload?"), i18n("Reload"))) {
+    static_cast<KRecentFilesAction *>(Main::action("project_open_recent"))->addURL(url.kurl());
     return false;
   }
-  setProject(p);
+  Project *p = new Project(url);
+  QString error;
+  if (!p->load(error)) {
+    MessageBox::detailedSorry(i18n("Could not open project file."), error, Log::Show);
+    delete p;
+    p = NULL;
+    return false;
+  }
+
+  if (_project.get() != NULL && !reload) saveProject();
+  Main::editorManager().closeAllEditors();
+  _project.reset(p);
+  init();
+
+  _rootItem->set(p->url());
+  if ( Main::toolGroup()->linkerScriptType()!=PURL::Nb_FileTypes ) {
+      _linkerScriptItem = new LinkerScriptItem(headerItem(Group::LinkerScript));
+      ensureItemVisible(_linkerScriptItem);
+  }
   PURL::UrlList files = _project->absoluteFiles();
-  PURL::UrlList::const_iterator it;
-  for(it=files.begin(); it!=files.end(); ++it) addFile(*it, (*it).fileType(), Intrinsic);
+  for(PURL::UrlList::const_iterator it=files.begin(); it!=files.end(); ++it)
+      addFile(*it, (*it).fileType(), Intrinsic);
   _projectData.type = PURL::Project;
   _projectData.externals.clear();
   static_cast<KRecentFilesAction *>(Main::action("project_open_recent"))->addURL(url.kurl());
   files = _project->openedFiles();
-  for(it = files.begin(); it!=files.end(); ++it) Main::editorManager().openFile(*it);
+  for(PURL::UrlList::const_iterator it = files.begin(); it!=files.end(); ++it)
+      Main::editorManager().openFile(*it);
   Register::list().init();
   QValueList<Register::TypeData> watched = _project->watchedRegisters();
-  QValueList<Register::TypeData>::const_iterator wit;
-  for (wit=watched.begin(); wit!=watched.end(); ++wit) Register::list().setWatched(*wit, true);
+  for (QValueList<Register::TypeData>::const_iterator wit=watched.begin(); wit!=watched.end(); ++wit)
+      Register::list().setWatched(*wit, true);
+  _modified = false;
   return true;
 }
 
@@ -557,26 +533,55 @@ bool ProjectManager::View::isExternalFile(const PURL::Url &url) const
 void ProjectManager::View::modified(const PURL::Url &url)
 {
   FileItem *item = findFileItem(url);
-  if ( item && !isExternalFile(url) ) _modified = true;
+  if ( item != NULL && !isExternalFile(url) ) _modified = true;
 }
 
 void ProjectManager::View::renamed(QListViewItem *item, int, const QString &text)
 {
-  Q_ASSERT ( item->rtti()==DeviceRtti );
-  MainWindow::self()->setDevice(text);
+  switch (item->rtti()) {
+    case DeviceRtti:
+      if (text != Main::device()) {
+        MainWindow::self().setDevice(text);
+        _modified = true;
+      }
+      break;
+    case ToolchainRtti: {
+      const Tool::Group *group = _toolchainItem->group();
+      if (group != NULL
+          && group != Main::toolGroup()) {
+        MainWindow::self().selectTool(*group);
+        _modified = true;
+      }
+      break;
+    }
+    case ProgrammerRtti: {
+      const Programmer::Group* group = _programmerItem->group();
+      if (group != NULL
+          && group != &Main::programmerGroup()) {
+        MainWindow::self().selectProgrammer(*group);
+        _modified = true;
+      }
+      break;
+    }
+    default:
+      ASSERT(false);
+      break;
+  }
 }
 
 void ProjectManager::View::updateGUI()
 {
   _deviceItem->updateText();
+  _programmerItem->updateText();
+  if (_toolchainItem != NULL) _toolchainItem->updateText();
 }
 
-QDragObject *ProjectManager::View::dragObject()
+QDragObject* ProjectManager::View::dragObject()
 {
-  if ( currentItem()==0 || currentItem()->rtti()!=FileRtti ) return 0;
+  if ( currentItem()==NULL || currentItem()->rtti()!=FileRtti ) return NULL;
   const FileItem *item = static_cast<const FileItem *>(currentItem());
   const HeaderItem *hitem = static_cast<const HeaderItem *>(item->parent());
-  if ( hitem->group()!=SourceGroup ) return 0;
+  if ( hitem->group()!=Group::Source ) return NULL;
   QStrList uris;
   uris.append(QUriDrag::localFileToUri(item->url().filepath()));
   return new QUriDrag(uris, viewport());
@@ -586,16 +591,15 @@ bool ProjectManager::View::acceptDrag(QDropEvent* e) const
 {
   if ( e->source()!=viewport() ) return false;
   const QListViewItem *item = itemAt(e->pos());
-  if ( item==0 || item->rtti()!=FileRtti ) return false;
+  if ( item==NULL || item->rtti()!=FileRtti ) return false;
   const HeaderItem *hitem = static_cast<const HeaderItem *>(item->parent());
-  return ( hitem->group()==SourceGroup );
+  return ( hitem->group()==Group::Source );
 }
 
 void ProjectManager::View::filesReordered()
 {
-  if ( _project==0 ) return;
   _project->clearFiles();
-  QListViewItem *item = headerItem(SourceGroup)->firstChild();
+  QListViewItem *item = headerItem(Group::Source)->firstChild();
   for (;item; item=item->nextSibling())
     _project->addFile(static_cast<FileItem *>(item)->url());
 }
@@ -606,7 +610,10 @@ QString ProjectManager::View::tooltip(QListViewItem *item, int) const
     case RootRtti:
     case FileRtti:
     case LinkerScriptRtti: return static_cast<const UrlItem *>(item)->url().filepath();
+    case ToolchainRtti:
+    case ProgrammerRtti:
     case DeviceRtti:
+    case DeviceInfoRtti:
     case RegisterRtti:
     case HeaderRtti: break;
   }
@@ -629,11 +636,8 @@ bool ProjectManager::View::needsRecompile() const
   PURL::Url output = projectUrl().toFileType(PURL::Hex);
   QDateTime outputLastModified;
   if ( !output.exists(&outputLastModified) ) return true;
-  PURL::UrlList files;
-  if ( Main::project() ) files = Main::project()->absoluteFiles();
-  else files.append(projectUrl());
-  PURL::UrlList::const_iterator it;
-  for (it=files.begin(); it!=files.end(); ++it) {
+  PURL::UrlList files = _project->absoluteFiles();
+  for (PURL::UrlList::const_iterator it=files.begin(); it!=files.end(); ++it) {
     QDateTime lastModified;
     if ( !(*it).exists(&lastModified) ) continue;
     if ( lastModified>outputLastModified ) return true;
