@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2006 Nicolas Hadacek <hadacek@kde.org>             *
+ *   Copyright (C) 2005-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *   Copyright (C) 2003 Alain Gibaud <alain.gibaud@free.fr>                *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -17,6 +17,8 @@
 #include "main_global.h"
 #include "common/gui/purl_gui.h"
 #include "device_gui.h"
+#include "tools/list/tool_list.h"
+#include "progs/list/prog_list.h"
 
 //----------------------------------------------------------------------------
 void PopupMenu::insertItem(const QString &icon, const QString &label, QObject *receiver, const char *slot)
@@ -29,22 +31,34 @@ void PopupMenu::insertItem(const QString &icon, const QString &label, QObject *r
 }
 
 //----------------------------------------------------------------------------
-const char *ProjectManager::HeaderItem::GROUP_LABELS[Nb_Groups] = {
-  I18N_NOOP("Device"), I18N_NOOP("Headers"), I18N_NOOP("Linker Script"),
-  I18N_NOOP("Sources"), I18N_NOOP("Objects"), I18N_NOOP("Views"),
-  I18N_NOOP("Generated"), I18N_NOOP("Included")
+const ProjectManager::Group::Data ProjectManager::Group::DATA[Nb_Types] = {
+  { I18N_NOOP("Device"),        "piklab_chip" },
+  { I18N_NOOP("Toolchain"),     "exec" },
+  { I18N_NOOP("Programmer"),    "piklab_burnchip" },
+  { I18N_NOOP("Headers"),       NULL },
+  { I18N_NOOP("Linker Script"), NULL },
+  { I18N_NOOP("Sources"),       NULL },
+  { I18N_NOOP("Objects"),       NULL },
+  { I18N_NOOP("Generated"),     NULL },
+  { I18N_NOOP("Included"),      NULL }
 };
 
+const ProjectManager::SpecialEditorType::Data ProjectManager::SpecialEditorType::DATA[Nb_Types] = {
+    { "device",    I18N_NOOP("Device") },
+    { "registers", I18N_NOOP("Registers") }
+};
+
+//----------------------------------------------------------------------------
 ProjectManager::Group ProjectManager::group(PURL::FileType type)
 {
   switch (type.data().group) {
-    case PURL::Source: return SourceGroup;
-    case PURL::Header: return HeaderGroup;
-    case PURL::LinkerScript: return LinkerScriptGroup;
-    case PURL::LinkerObject: return LinkerObjectGroup;
+    case PURL::Source:        return Group::Source;
+    case PURL::Header:        return Group::Header;
+    case PURL::LinkerScript:  return Group::LinkerScript;
+    case PURL::LinkerObject:  return Group::LinkerObject;
     case PURL::Nb_FileGroups: break;
   }
-  return ViewGroup;
+  return Group::Nb_Types;
 }
 
 ProjectManager::RootItem::RootItem(KListView *listview)
@@ -52,23 +66,37 @@ ProjectManager::RootItem::RootItem(KListView *listview)
 {
   setSelectable(false);
   setPixmap(0, PURL::icon(PURL::Project));
-  set(PURL::Url(), true);
+  set(PURL::Url());
 }
 
-void ProjectManager::RootItem::set(const PURL::Url &url, bool standalone)
+void ProjectManager::RootItem::set(const PURL::Url &url)
 {
   _url = url;
-  _standalone = standalone;
   if ( _url.isEmpty() ) setText(0, i18n("<no project>"));
-  else if (_standalone) setText(0, i18n("Standalone File"));
   else setText(0, _url.basename());
 }
 
+void ProjectManager::RootItem::paintCell(QPainter *p, const QColorGroup &cg,
+                                         int column, int width, int align)
+{
+    QFont f = p->font();
+    f.setItalic(_url.isEmpty());
+    p->setFont(f);
+    UrlItem::paintCell(p, cg, column, width, align);
+}
+
+//----------------------------------------------------------------------------
 ProjectManager::HeaderItem::HeaderItem(RootItem *item, Group group)
   : KListViewItem(item), _group(group)
 {
-  if ( group!=DeviceGroup) setSelectable(false);
-  setText(0, i18n(GROUP_LABELS[group]));
+  setSelectable(false);
+  setText(0, i18n(group.data()._label));
+  const char* icon = group.data()._icon;
+  if (icon != NULL) {
+    KIconLoader loader;
+    QPixmap chip = loader.loadIcon(icon, KIcon::Small);
+    setPixmap(0, chip);
+  }
 }
 
 QListViewItem *ProjectManager::HeaderItem::lastChild() const
@@ -82,6 +110,7 @@ QListViewItem *ProjectManager::HeaderItem::lastChild() const
   return item;
 }
 
+//----------------------------------------------------------------------------
 ProjectManager::FileItem::FileItem(HeaderItem *item, PURL::FileType ftype,
                                    const PURL::Url &url, bool external)
   : UrlItem(item), _ftype(ftype), _external(external)
@@ -102,7 +131,7 @@ void ProjectManager::FileItem::set(const PURL::Url &url)
     case PURL::Nb_FileTypes: Q_ASSERT(false); break;
     default: {
       QString s = url.filename();
-      if ( _external && group(_ftype)==LinkerScriptGroup )
+      if ( _external && group(_ftype)==Group::LinkerScript )
         s += i18n(" (default)");
       setText(0, s); break;
     }
@@ -113,27 +142,33 @@ void ProjectManager::FileItem::paintCell(QPainter *p, const QColorGroup &cg,
                                          int column, int width, int align)
 {
   QFont f = p->font();
-  f.setItalic(group(_ftype)!=ViewGroup && _external);
+  f.setItalic(_external);
   p->setFont(f);
-  KListViewItem::paintCell(p, cg, column, width, align);
+  UrlItem::paintCell(p, cg, column, width, align);
 }
 
+//----------------------------------------------------------------------------
+ProjectManager::DeviceInfoItem::DeviceInfoItem(HeaderItem *item)
+    : KListViewItem(item)
+{
+  setText(0, i18n("Infos"));
+}
+
+//----------------------------------------------------------------------------
 ProjectManager::RegisterItem::RegisterItem(HeaderItem *item)
   : KListViewItem(item)
 {
-  KIconLoader loader;
-  QPixmap chip = loader.loadIcon("piklab_chip", KIcon::Small);
-  setPixmap(0, chip);
   setText(0, i18n("Registers"));
 }
 
+//----------------------------------------------------------------------------
 ProjectManager::DeviceItem::DeviceItem(HeaderItem *item)
-  : EditListViewItem(item)
+: EditListViewItem(item)
 {}
 
 QWidget *ProjectManager::DeviceItem::editWidgetFactory(int) const
 {
-  QComboBox *combo = new DeviceChooser::ComboBox(0);
+  QComboBox *combo = new DeviceChooser::ComboBox(NULL);
   combo->setCurrentText(Main::device());
   QObject::connect(combo, SIGNAL(activated(int)), listView(), SLOT(finishRenaming()));
   return combo;
@@ -144,6 +179,70 @@ void ProjectManager::DeviceItem::updateText()
   setText(0, Main::device());
 }
 
+//----------------------------------------------------------------------------
+ProjectManager::ToolchainItem::ToolchainItem(HeaderItem *item)
+: EditListViewItem(item),
+  _group(NULL)
+{
+}
+
+QWidget *ProjectManager::ToolchainItem::editWidgetFactory(int) const
+{
+  _combo.reset(new ListerComboBox<Tool::Lister>(NULL));
+  _combo->setGroup(*Main::toolGroup());
+  QObject::connect(_combo->widget(), SIGNAL(activated(int)), listView(), SLOT(finishRenaming()));
+  return _combo->widget();
+}
+
+void ProjectManager::ToolchainItem::editWidgetDeleted(int) const
+{
+  _combo.reset(NULL);
+}
+
+void ProjectManager::ToolchainItem::editDone(int col, const QWidget* widget)
+{
+  _group = &_combo->group();
+  EditListViewItem::editDone(col, widget);
+}
+
+void ProjectManager::ToolchainItem::updateText()
+{
+  _group = Main::toolGroup();
+  setText(0, Main::toolGroup()->label());
+}
+
+//----------------------------------------------------------------------------
+ProjectManager::ProgrammerItem::ProgrammerItem(HeaderItem *item)
+: EditListViewItem(item),
+  _group(NULL)
+{}
+
+QWidget *ProjectManager::ProgrammerItem::editWidgetFactory(int) const
+{
+  _combo.reset(new ListerComboBox<Programmer::Lister>(NULL));
+  _combo->setGroup(Main::programmerGroup());
+  QObject::connect(_combo->widget(), SIGNAL(activated(int)), listView(), SLOT(finishRenaming()));
+  return _combo->widget();
+}
+
+void ProjectManager::ProgrammerItem::editWidgetDeleted(int) const
+{
+  _combo.reset(NULL);
+}
+
+void ProjectManager::ProgrammerItem::editDone(int col, const QWidget* widget)
+{
+  _group = &_combo->group();
+  EditListViewItem::editDone(col, widget);
+}
+
+void ProjectManager::ProgrammerItem::updateText()
+{
+  _group = &Main::programmerGroup();
+  setText(0, Main::programmerGroup().label());
+}
+
+//----------------------------------------------------------------------------
 ProjectManager::LinkerScriptItem::LinkerScriptItem(HeaderItem *item)
   : UrlItem(item)
 {
@@ -154,7 +253,7 @@ void ProjectManager::LinkerScriptItem::init()
 {
   _url = PURL::Url();
   PURL::Url lkr;
-  if ( Main::project() ) lkr = Main::project()->customLinkerScript();
+  lkr = Main::project()->customLinkerScript();
   setText(0, lkr.isEmpty() ? i18n("<default>") : lkr.filename());
   setPixmap(0, lkr.isEmpty() ? QPixmap() : PURL::icon(PURL::Lkr));
 }
@@ -164,7 +263,7 @@ void ProjectManager::LinkerScriptItem::set(const PURL::Url &url)
   _url = url;
   QString s = url.filename();
   PURL::Url lkr;
-  if ( Main::project() ) lkr = Main::project()->customLinkerScript();
+  lkr = Main::project()->customLinkerScript();
   if ( lkr.isEmpty() ) s += i18n(" (default)");
   setText(0, s);
   setPixmap(0, PURL::icon(PURL::Lkr));
@@ -173,6 +272,5 @@ void ProjectManager::LinkerScriptItem::set(const PURL::Url &url)
 PURL::Url ProjectManager::LinkerScriptItem::url() const
 {
   if ( !_url.isEmpty() ) return _url;
-  if ( Main::project() ) return Main::project()->customLinkerScript();
-  return PURL::Url();
+  return Main::project()->customLinkerScript();
 }
