@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 Nicolas Hadacek <hadacek@kde.org>                  *
+ *   Copyright (C) 2007-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -41,8 +41,8 @@ void FileListItem::toggle()
 
 PURL::FileGroup FileListItem::fileGroup() const
 {
-  if ( _group==0 ) return PURL::Nb_FileGroups;
-  PURL::Url url = PURL::Url::fromPathOrUrl(text(1));
+  if (_group == NULL) return PURL::Nb_FileGroups;
+  PURL::Url url = PURL::fromPathOrUrl(text(1), true);
   switch (url.data().group) {
   case PURL::Source: {
     FOR_EACH(PURL::ToolType, type)
@@ -133,12 +133,13 @@ ProjectWizard::ProjectWizard(QWidget *parent)
   grid->addWidget(_device, 2, 1);
   label = new QLabel(i18n("Toolchain:"), _first);
   grid->addWidget(label, 3, 0);
-  _toolchain = new KeyComboBox<QString>(_first);
-  Tool::Lister::ConstIterator it;
-  for (it=Tool::lister().begin(); it!=Tool::lister().end(); ++it)
-    _toolchain->appendItem(it.key(), it.data()->label());
-  _toolchain->setCurrentItem(Main::toolGroup().name());
-  grid->addWidget(_toolchain->widget(), 3, 1);
+  _tool.reset(new ListerComboBox<Tool::Lister>(_first));
+  grid->addWidget(_tool->widget(), 3, 1);
+  label = new QLabel(i18n("Programmer:"), _first);
+  grid->addWidget(label, 4, 0);
+  _prog.reset(new ListerComboBox<Programmer::Lister>(_first));
+  grid->addWidget(_prog->widget(), 4, 1);
+
   grid->setColStretch(2, 1);
   grid->setRowStretch(4, 1);
 
@@ -186,10 +187,10 @@ void ProjectWizard::next()
     } else if ( url().exists() ) {
       if ( !MessageBox::askContinue(i18n("Project \"%1\"already exists. Overwrite it?").arg(url().filename())) ) return;
     }
-    if ( !toolchain().check(device(), &Main::compileLog()) ) return;
+    if ( !_tool->group().check(device(), &Main::compileLog()) ) return;
     _files->setDirectory(_directory->directory());
-    _files->setToolGroup(toolchain());
-    if ( toolchain().name()=="custom" ) {
+    _files->setToolGroup(_tool->group());
+    if ( _tool->group().name()=="custom" ) {
       _templateButton->hide();
       _addButton->setChecked(true);
     } else {
@@ -202,7 +203,7 @@ void ProjectWizard::next()
     uint nb = 0;
     for (uint i=0; i<_files->count(); i++)
       if ( static_cast<const FileListItem *>(_files->item(i))->fileGroup()==PURL::Source ) nb++;
-    if ( toolchain().compileFileType()==Tool::CompileFileType::Single && nb>1 ) {
+    if ( _tool->group().compileFileType()==Tool::CompileFileType::Single && nb>1 ) {
       if ( !MessageBox::askContinue(i18n("The selected toolchain can only compile a single source file and you have selected %1 source files. Continue anyway? ").arg(nb)) ) return;
     }
   }
@@ -215,14 +216,15 @@ void ProjectWizard::done(int r)
     PURL::UrlList files;
     _project = new Project(url());
     Compile::Config::setDevice(_project, device());
-    Compile::Config::setToolGroup(_project, toolchain());
+    Compile::Config::setToolGroup(_project, _tool->group());
+    Compile::Config::setProgrammerGroup(_project, _prog->group());
     Compile::Config::setCustomCommands(_project, Compile::Config::customCommands(0));
 
     if ( _bgroup->selectedId()==0 ) {
       PURL::ToolType ttype = PURL::ToolType::Compiler;
       PURL::FileType ftype = PURL::Nb_FileTypes;
       FOR_EACH(PURL::ToolType, i) {
-        PURL::FileType type = toolchain().implementationType(i);
+        PURL::FileType type = _tool->group().implementationType(i);
         if ( type==PURL::Nb_FileTypes ) continue;
         ftype = type;
         ttype = i;
@@ -230,7 +232,7 @@ void ProjectWizard::done(int r)
       Q_ASSERT( ftype!=PURL::Nb_FileTypes );
       PURL::Url turl = url().toFileType(ftype);
       QString text;
-      const Tool::SourceGenerator *generator = toolchain().sourceGenerator();
+      const Tool::SourceGenerator *generator = _tool->group().sourceGenerator();
       if ( generator==0 ) text = i18n("Template source file generation not implemented yet for this toolchain...");
       else {
         bool ok = true;
@@ -248,7 +250,7 @@ void ProjectWizard::done(int r)
     } else {
       Log::StringView sview;
       for (uint i=0; i<_files->count(); i++) {
-        PURL::Url furl = PURL::Url::fromPathOrUrl(_files->text(i));
+        PURL::Url furl = PURL::fromPathOrUrl(_files->text(i), true);
         if ( static_cast<const FileListItem *>(_files->item(i))->copy() ) {
           PURL::Url to(url().directory(), furl.filename());
           if ( furl==to || furl.copyTo(to, sview) ) files += to;
@@ -266,11 +268,6 @@ PURL::Url ProjectWizard::url() const
   return PURL::Url(PURL::Directory(_directory->directory()), _name->text(), PURL::Project);
 }
 
-const Tool::Group &ProjectWizard::toolchain() const
-{
-  return *Tool::lister().group(_toolchain->currentItem());
-}
-
 QString ProjectWizard::device() const
 {
   return _device->device();
