@@ -42,11 +42,24 @@ QPixmap TextEditor::pixmap(Breakpoint::MarkType type)
   return SmallIcon(MARK_TYPE_DATA[type].pixmap);
 }
 
+TextEditor::TextEditor(const QString& title, const QString& tag, QWidget *parent, const char *name)
+: Editor(title, tag, parent, name),
+  _view(NULL)
+{
+  init(false);
+}
+
 TextEditor::TextEditor(bool withDebugger, QWidget *parent, const char *name)
-  : Editor(parent, name), _view(0)
+: Editor(parent, name),
+  _view(NULL)
+{
+  init(withDebugger);
+}
+
+void TextEditor::init(bool withDebugger)
 {
   KLibFactory *factory = KLibLoader::self()->factory("libkatepart");
-  if ( factory==0 ) qFatal("Could not find katepart");
+  if ( factory==NULL ) qFatal("Could not find katepart");
   _document = static_cast<Kate::Document *>(factory->create(this, "kate", "KTextEditor::Document"));
   _oldModified = _document->isModified();
   _oldReadOnly = !_document->isReadWrite();
@@ -91,7 +104,7 @@ bool TextEditor::eventFilter(QObject *, QEvent *e)
 void TextEditor::addView()
 {
     KTextEditor::View *v = _document->createView(_split);
-    if ( _view==0 ) _view = static_cast<Kate::View *>(v);
+    if ( _view==NULL ) _view = static_cast<Kate::View *>(v);
     Q_ASSERT(v);
     connect(v, SIGNAL(gotFocus(Kate::View *)), SLOT(gotFocus(Kate::View *)));
     connect(v, SIGNAL(cursorPositionChanged()), SLOT(statusChanged()));
@@ -125,12 +138,12 @@ void TextEditor::gotFocus(Kate::View *v)
 
 void TextEditor::addGui()
 {
-  MainWindow::self()->guiFactory()->addClient(_view);
+  MainWindow::self().guiFactory()->addClient(_view);
 }
 
 void TextEditor::removeGui()
 {
-  MainWindow::self()->guiFactory()->removeClient(_view);
+  MainWindow::self().guiFactory()->removeClient(_view);
 }
 
 void TextEditor::removeCurrentView()
@@ -321,12 +334,16 @@ void TextEditor::populateList()
 #endif
 
 //-----------------------------------------------------------------------------
-SimpleTextEditor::SimpleTextEditor(bool withDebugger, PURL::FileType type, QWidget *parent, const char *name)
-  : TextEditor(withDebugger, parent, name), _type(type), _file(_sview)
+SimpleTextEditor::SimpleTextEditor(const QString& title, const QString& tag, QWidget *parent, const char *name)
+: TextEditor(title, tag, parent, name),
+  _type(PURL::Nb_FileTypes),
+  _file(_sview)
 {}
 
 SimpleTextEditor::SimpleTextEditor(bool withDebugger, QWidget *parent, const char *name)
-  : TextEditor(withDebugger, parent, name), _type(PURL::Nb_FileTypes), _file(_sview)
+: TextEditor(withDebugger, parent, name),
+  _type(PURL::Nb_FileTypes),
+  _file(_sview)
 {}
 
 bool SimpleTextEditor::open(const PURL::Url &url)
