@@ -26,7 +26,8 @@ class TextEditor : public Editor
 {
 Q_OBJECT
 public:
-  TextEditor(bool withDebugger, QWidget *parent, const char *name = 0);
+  TextEditor(const QString& title, const QString& tag, QWidget* parent, const char* name = NULL);
+  TextEditor(bool withDebugger, QWidget *parent, const char *name = NULL);
   virtual PURL::FileType fileType() const { return url().fileType(); }
   virtual PURL::Url url() const { return _document->url(); }
   virtual bool isModified() const;
@@ -40,6 +41,7 @@ public:
   void setCursorPosition(uint line, uint column) { _view->setCursorPosition(line, column); }
   uint cursorLine() const;
   virtual bool open(const PURL::Url &url);
+  virtual bool save() { return Editor::save(); }
   virtual bool save(const PURL::Url &url) { return _document->saveAs(url.kurl()); }
   virtual bool eventFilter(QObject *o, QEvent *e);
   virtual QValueList<uint> bookmarkLines() const;
@@ -77,6 +79,7 @@ private:
   virtual void setReadOnlyInternal(bool readOnly);
   uint highlightMode(const QString &name) const;
   void clearMarks(uint type);
+  void init(bool withDebugger);
 };
 
 //-----------------------------------------------------------------------------
@@ -84,16 +87,13 @@ class SimpleTextEditor : public TextEditor
 {
 Q_OBJECT
 public:
-  SimpleTextEditor(bool withDebugger, PURL::FileType type, QWidget *parent, const char *name = 0);
-  SimpleTextEditor(bool withDebugger, QWidget *parent, const char *name = 0);
+  SimpleTextEditor(const QString& title, const QString& tb, QWidget* parent, const char* name = NULL);
+  SimpleTextEditor(bool withDebugger, QWidget *parent, const char *name = NULL);
   void setFileType(PURL::FileType type) { _type = type; }
   virtual PURL::FileType fileType() const { return _type; }
   bool setText(const QString &text);
   virtual bool open(const PURL::Url &url);
 
-protected:
-  virtual bool load() { return false; }
-
 private:
   Log::StringView _sview;
   PURL::FileType  _type;
