@@ -24,13 +24,24 @@ class ConfigGenerator;
 class HexEditor;
 namespace Process { class Base; }
 
+struct ExternalToolTypeData
+{
+  const char* key;
+  const char* label;
+  const char* icon;
+  const char* url;
+};
+BEGIN_DECLARE_ENUM(ExternalToolType)
+  Pikloops = 0, KFind, KHexTerm
+END_DECLARE_ENUM(ExternalToolType, ExternalToolTypeData)
+
 class MainWindow : public KDockMainWindow
 {
 Q_OBJECT
 public:
-  static MainWindow *self();
+  static MainWindow &self();
   virtual ~MainWindow();
-  void setDevice(const QString &device);
+  void initDebugger();
 
 public slots:
   void newSourceFile();
@@ -40,13 +51,16 @@ public slots:
   void cleanBuild();
   void configure(ConfigCenter::Type showType = ConfigCenter::General);
   void configureProject();
+  void configureProjectToolchain();
   void showDeviceInfo();
-  void runPikloops();
-  void runKfind();
   void configGenerator();
   void templateGenerator();
   void updateGUI();
 
+  void setDevice(const QString &device);
+  void selectTool(const Tool::Group &group);
+  void selectProgrammer(const Programmer::Group &group);
+
 private slots:
   void newHexFile();
   bool openFile();
@@ -57,6 +71,7 @@ private slots:
   void compileFailure();
   void updateFile(const Compile::FileData &data);
   void stopBuild();
+  void disassembleFile();
 
   void erase();
   void blankCheck();
@@ -70,18 +85,16 @@ private slots:
   void applyToolbarSettings();
   void configureToolbar();
   void configureToolchains();
-  void configureProgrammer() { configure(ConfigCenter::ProgSelect); }
+  void configureProgrammers();
   void showProgrammerSettings() { configure(ConfigCenter::ProgOptions); }
   void showDebuggerSettings() { configure(ConfigCenter::DebugOptions); }
-  void selectProgrammer(const Programmer::Group &group);
-  void selectTool(const Tool::Group &group);
 
   void updateToolViewsActions();
   void resetDockLayout();
   void toggleToolView(QWidget *widget);
 
-  void pikloopsDone();
-  void kfindDone();
+  void runExternalTool();
+  void externalToolDone();
 
   void openRecentProject(const KURL &url);
   void closeProject();
@@ -92,15 +105,12 @@ signals:
   void deviceChanged();
 
 private:
-  static MainWindow      *_self;
   Log::Widget            *_programLog;
   QLabel                 *_actionStatus, *_debugStatus, *_editorStatus;
   VoltageStatusWidget    *_vddStatus, *_vppStatus;
-  ProgrammerStatusWidget *_programmerStatus;
-  ToolStatusWidget       *_toolStatus;
   QProgressBar           *_actionProgress;
   ConfigGenerator        *_configGenerator;
-  ::Process::Base        *_pikloopsProcess, *_kfindProcess;
+  std::auto_ptr< ::Process::Base> _externalToolProcesses[ExternalToolType::Nb_Types];
   Programmer::ProgramAction _actionAfterBuild;
 
   class DockPosition {
