@@ -14,41 +14,7 @@
 #include <kdockwidget.h>
 #include <kaction.h>
 
-#include "common/gui/key_gui.h"
 #include "devices/base/generic_device.h"
-namespace Programmer { class Group; }
-namespace Tool { class Group; }
-
-//----------------------------------------------------------------------------
-class ProgrammerStatusWidget : public QObject, public KeyPopupButton<QString>
-{
-Q_OBJECT
-public:
-  ProgrammerStatusWidget(QWidget *parent);
-
-signals:
-  void configure();
-  void selected(const Programmer::Group &group);
-
-private slots:
-  void activatedSlot(int id);
-};
-
-//----------------------------------------------------------------------------
-class ToolStatusWidget : public QObject, public KeyPopupButton<QString>
-{
-Q_OBJECT
-public:
-  ToolStatusWidget(QWidget *parent);
-
-signals:
-  void configureToolchain();
-  void configure();
-  void selected(const Tool::Group &group);
-
-private slots:
-  void activatedSlot(int id);
-};
 
 //----------------------------------------------------------------------------
 class VoltageStatusWidget : public QLabel
