@@ -67,7 +67,7 @@ void Register::RegisterListView::updateView()
 void Register::RegisterListView::itemClicked(int button, QListViewItem *item, const QPoint &, int)
 {
   if ( item==0 || button!=LeftButton ) return;
-  if ( item==firstChild() ) Main::editorManager().openEditor(EditorManager::RegisterEditor);
+  if ( item==firstChild() ) Main::editorManager().openEditor(ProjectManager::SpecialEditorType::Registers);
   int id = _root->id(item);
   if ( id==-1 || _ids[id].type()==Invalid ) return;
   bool watched = Register::list().isWatched(_ids[id]);
