@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2007 Nicolas Hadacek <hadacek@kde.org>                  *
+ *   Copyright (C) 2007-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,63 +17,48 @@
 #include "coff/base/coff_archive.h"
 
 //-----------------------------------------------------------------------------
-const KCmdLineOptions OPTIONS[] = {
-  KCmdLineLastOption
+const CLI::CommandData COMMAND_DATA[] = {
+  { "info",      CLI::NeedInput, 0, 0, I18N_NOOP("Return general informations.") },
+  { "variables", CLI::NeedInput, 0, 0, I18N_NOOP("Return informations about variables (for object).") },
+  { "symbols",   CLI::NeedInput, 0, 0, I18N_NOOP("Return informations about symbols.") },
+  { "sections",  CLI::NeedInput, 0, 0, I18N_NOOP("Return informations about sections (for object).") },
+  { "lines",     CLI::NeedInput, 0, 0, I18N_NOOP("Return informations about code lines (for object).") },
+  { "files",     CLI::NeedInput, 0, 0, I18N_NOOP("Return informations about files.") },
+  CLI::NullCommandData
 };
 
-const CLI::CommandData CLI::NORMAL_COMMAND_DATA[] = {
-  { "info",      NeedSource, I18N_NOOP("Return general informations.") },
-  { "variables", NeedSource, I18N_NOOP("Return informations about variables (for object).") },
-  { "symbols",   NeedSource, I18N_NOOP("Return informations about symbols.") },
-  { "sections",  NeedSource, I18N_NOOP("Return informations about sections (for object).") },
-  { "lines",     NeedSource, I18N_NOOP("Return informations about code lines (for object).") },
-  { "files",     NeedSource, I18N_NOOP("Return informations about files.") },
-  { 0, NoCommandProperty, 0 }
-};
-const CLI::CommandData CLI::INTERACTIVE_COMMAND_DATA[] = {
-  { 0, NoCommandProperty, 0 }
-};
-
-const CLI::PropertyData CLI::PROPERTY_DATA[] = {
+const CLI::PropertyData PROPERTY_DATA[] = {
+  { "input",  "input <file>",  0,   I18N_NOOP("Input COFF filepath."), 0, 0 },
   { "device", "device <name>", "d", I18N_NOOP("Target device."), "device-list", I18N_NOOP("Return the list of supported devices.") },
-  { 0, 0, 0, 0, 0, 0 }
-};
-
-const KCmdLineOptions CLI::OPTIONS[] = {
-  KCmdLineLastOption
+  CLI::NullPropertyData
 };
 
 //-----------------------------------------------------------------------------
 CLI::Main::Main()
- : MainBase(HasForce), _device(0)
-{}
-
-CLI::Main::~Main()
-{}
-
-CLI::ExitCode CLI::Main::prepareCommand(const QString &command)
+: MainBase("piklab-coff", I18N_NOOP("Piklab COFF Utility"),
+           I18N_NOOP("Command-line utility to view COFF files.")),
+  _device(NULL)
 {
-  const CommandData *data = findCommandData(command);
-  CommandProperties properties = static_cast<CommandProperties>(data->properties);
-  int nbArgs = 0;
-  if ( properties & NeedSource ) nbArgs++;
-  if ( properties & NeedDestination ) nbArgs++;
-  if ( _args->count()<nbArgs ) return errorExit(i18n("Too few arguments."), ARG_ERROR);
-  if ( _args->count()>nbArgs ) return errorExit(i18n("Too many arguments."), ARG_ERROR);
-  uint argIndex = 0;
-  if ( properties & NeedSource ) {
-    _source = PURL::Url(_args->url(argIndex));
-    argIndex++;
-    PURL::File file(_source, *_view);
-    if ( !file.openForRead() ) return FILE_ERROR;
+}
+
+const CLI::CommandData& CLI::Main::commandData(uint i) const
+{
+  return COMMAND_DATA[i];
+}
+
+const CLI::PropertyData& CLI::Main::propertyData(uint i) const
+{
+  return PROPERTY_DATA[i];
+}
+
+CLI::ExitCode CLI::Main::prepareCommand(const CommandProperties& properties)
+{
+  ExitCode code = MainBase::prepareCommand(properties);
+  if (code == OK) {
+    if (_device == NULL
+        && (properties & NeedDevice) ) return errorExit(i18n("Device not specified."), ARG_ERROR);
   }
-  if ( properties & NeedDestination ) {
-    _dest = PURL::Url(_args->url(argIndex));
-    argIndex++;
-    if ( !_force && _dest.exists() ) return errorExit(i18n("Destination file already exists."), FILE_ERROR);
-  }
-  if ( _device==0 && (properties & NeedDevice) ) return errorExit(i18n("Device not specified."), ARG_ERROR);
-  return OK;
+  return code;
 }
 
 QString CLI::Main::prettyAuxSymbol(const Coff::AuxSymbol &aux)
@@ -106,7 +91,7 @@ QString CLI::Main::prettySymbol(const Coff::Symbol &sym)
 
 CLI::ExitCode CLI::Main::executeCommandArchive(const QString &command, Log::KeyList &keys)
 {
-  Coff::Archive coff(_source);
+  Coff::Archive coff(input());
   if ( !coff.parse(*this) ) return ARG_ERROR;
 
   if ( command=="info" ) {
@@ -130,7 +115,7 @@ CLI::ExitCode CLI::Main::executeCommandArchive(const QString &command, Log::KeyL
 
 CLI::ExitCode CLI::Main::executeCommandObject(const QString &command, Log::KeyList &keys)
 {
-  Coff::TextObject coff(_device, _source);
+  Coff::TextObject coff(_device, input());
   if ( !coff.parse(*this) ) return ARG_ERROR;
   Q_ASSERT( coff.device()==0 || coff.device()->group().name()=="pic" );
   const Pic::Data *pdata = static_cast<const Pic::Data *>(coff.device());
@@ -206,7 +191,7 @@ CLI::ExitCode CLI::Main::executeCommandObject(const QString &command, Log::KeyLi
 
 CLI::ExitCode CLI::Main::executeCommand(const QString &command)
 {
-  CoffType type = Coff::identify(_source, *this);
+  CoffType type = Coff::identify(input(), *this);
   if ( type==CoffType::Nb_Types ) return ARG_ERROR;
   Log::KeyList keys;
   if ( command=="info" ) keys.append(i18n("COFF type:"), type.label());
@@ -216,47 +201,47 @@ CLI::ExitCode CLI::Main::executeCommand(const QString &command)
     case CoffType::Object: code = executeCommandObject(command, keys); break;
     case CoffType::Nb_Types: Q_ASSERT(false); break;
   }
-  if ( code==OK ) keys.display(*_view);
+  if ( code==OK ) keys.display(view());
   return code;
 }
 
-CLI::ExitCode CLI::Main::prepareRun(bool &interactive)
+CLI::ExitCode CLI::Main::doExecuteSetCommand(const QString &property, const QString &value)
 {
-  interactive = false;
-  return OK;
-}
+  ExitCode code = MainBase::doExecuteSetCommand(property, value);
+  if (code != NOT_PROCESSED) return code;
 
-CLI::ExitCode CLI::Main::executeSetCommand(const QString &property, const QString &value)
-{
-  if ( property=="device" || property=="processor" ) {
-    if ( value.isEmpty() ) {
-      _device = 0;
+  if (property == "device") {
+    if (value.isEmpty()) {
+      _device = NULL;
       return OK;
     }
     QString s = value.upper();
     _device = Device::lister().data(s);
-    if ( _device==0 ) return errorExit(i18n("Unknown device \"%1\".").arg(s), ARG_ERROR);
+    if (_device == NULL) return errorExit(i18n("Unknown device \"%1\".").arg(s), ARG_ERROR);
     return OK;
   }
-  return errorExit(i18n("Unknown property \"%1\".").arg(property), ARG_ERROR);
+  return NOT_PROCESSED;
 }
 
-QString CLI::Main::executeGetCommand(const QString &property)
+CLI::ExitCode CLI::Main::doExecuteGetCommand(const QString &property, QString& value)
 {
-  if ( property=="device" || property=="processor" ) {
-    if ( _device==0 ) return i18n("<not set>");
-    return _device->name();
+  ExitCode code = MainBase::doExecuteGetCommand(property, value);
+  if (code != NOT_PROCESSED) return code;
+
+  if (property == "device") {
+    if (_device != NULL) value = _device->name();
+    return OK;
   }
-  log(Log::LineType::SoftError, i18n("Unknown property \"%1\".").arg(property));
-  return QString::null;
+  return NOT_PROCESSED;
 }
 
 CLI::ExitCode CLI::Main::list(const QString &command)
 {
-  if ( MainBase::list(command)==OK ) return OK;
-  if ( command=="device-list" ) return deviceList();
-  Q_ASSERT(false);
-  return OK;
+  ExitCode code = MainBase::list(command);
+  if (code != NOT_PROCESSED) return code;
+  if (command == "device-list") return deviceList();
+  ASSERT(false);
+  return NOT_PROCESSED;
 }
 
 CLI::ExitCode CLI::Main::deviceList()
@@ -275,8 +260,6 @@ CLI::ExitCode CLI::Main::deviceList()
 int main(int argc, char **argv)
 {
   CLI::Main main;
-  Piklab::AboutData *about = new Piklab::AboutData("piklab-coff", I18N_NOOP("Piklab COFF Utility"), I18N_NOOP("Command-line utility to view COFF files."));
-  CLI::OptionList list = main.optionList(I18N_NOOP("COFF filename."));
-  Piklab::init(about, argc, argv, false, list.ptr());
-  return main.doRun();
+  main.initArgs(argc, argv, I18N_NOOP("COFF filepath."));
+  return main.run();
 }
