@@ -20,7 +20,7 @@ Port::Description Programmer::CliManager::portDescription() const
   Log::Base *log = const_cast<Log::Base *>(static_cast<const Log::Base *>(this));
   if ( CLI::_port.isEmpty() ) {
     log->log(Log::LineType::Information, i18n("Using port from configuration file."));
-    return Programmer::GroupConfig::portDescription(group());
+    return ::Programmer::GroupConfig::portDescription(group());
   }
   if ( CLI::_port=="usb" ) return Port::Description(PortType::USB, QString::null);
   PortType type = Port::findType(CLI::_port);
@@ -43,14 +43,18 @@ Programmer::Generic *Programmer::CliManager::createProgrammer(const Device::Data
   HardwareDescription hd;
   hd.port = portDescription();
   ::Hardware::Config *config = CLI::_progGroup->hardwareConfig();
-  if (config) {
+  if (config != NULL) {
     if ( CLI::_hardware.isEmpty() ) hd.name = config->currentHardware(hd.port.type);
     else hd.name = CLI::_hardware;
   }
   delete config;
+  config = NULL;
   internalCreateProgrammer(data, hd);
-  if ( !CLI::_firmwareDir.isEmpty() && !(_programmer->group().properties() & Programmer::Custom) )
-    static_cast<Programmer::Base *>(_programmer)->setFirmwareDirectory(CLI::_firmwareDir.path());
+  if (!CLI::_firmwareDir.isEmpty()
+      && !(_programmer->group().properties() & ::Programmer::Custom)) {
+    typedef ::Programmer::Base Base; // for G++ 3.3.6
+    static_cast<Base*>(_programmer)->setFirmwareDirectory(CLI::_firmwareDir.path());
+  }
   return _programmer;
 }
 
@@ -60,7 +64,7 @@ bool Programmer::CliManager::internalInitProgramming(bool debugging, ProgramActi
   if ( _programmer->isActive() ) {
     if ( !halt() ) return false;
   } else if (debugging) {
-    if ( ::Debugger::manager->coff()==0 && !::Debugger::manager->init() ) log(Log::LineType::Warning, i18n("Starting debug session without COFF file (no source file information)."));
+    if ( ::Debugger::manager->coff()==NULL && !::Debugger::manager->init() ) log(Log::LineType::Warning, i18n("Starting debug session without COFF file (no source file information)."));
     if ( !group().isSoftware() ) log(Log::LineType::Warning, i18n("Starting debugging session with device memory in an unknown state. You may want to reprogram the device."));
   }
   return true;
