@@ -20,7 +20,7 @@ void DeviceTest::checkArguments()
   }
 }
 
-bool DeviceTest::execute()
+void DeviceTest::execute()
 {
   Device::Lister::ConstIterator it;
   for (it=Device::lister().begin(); it!=Device::lister().end(); ++it) {
@@ -42,7 +42,6 @@ bool DeviceTest::execute()
       fflush(stdout);
     }
   }
-  return true;
 }
 
 Piklab::OptionList DeviceTest::optionList() const
