@@ -18,7 +18,7 @@ public:
   virtual Piklab::OptionList optionList() const;
 
 protected:
-  virtual bool execute();
+  virtual void execute();
   virtual bool skip(const Device::Data &) const { return false; }
   virtual bool init(const Device::Data &) { return true; } // returns false if skipped or failed
   virtual bool executeDevice(const Device::Data &data) = 0; // returns false if skipped or failed
