@@ -47,19 +47,19 @@ GeneratorCheck::~GeneratorCheck()
   delete _helper;
 }
 
-void GeneratorCheck::runTest()
+int GeneratorCheck::runTest()
 {
   _helper->initSupported();
-  DeviceTest::runTest();
+  return DeviceTest::runTest();
 }
 
 bool GeneratorCheck::init(const Device::Data &data)
 {
-  PURL::Url dest(PURL::Directory::current(), "test.xxx");
+  PURL::Url dest(PURL::currentDirectory(), "test.xxx");
   dest = dest.toFileType(_helper->sourceFileType());
   _fdest = new PURL::File(dest, *_view);
   _helper->init(data);
-  PURL::Url hex(PURL::Directory::current(), "test.hex");
+  PURL::Url hex(PURL::currentDirectory(), "test.hex");
   _fhex = new PURL::File(hex, *_view);
   _memory1 = static_cast<Pic::Memory *>(data.group().createMemory(data));
   return true;
@@ -249,7 +249,7 @@ SDCCGeneratorCheckHelper::SDCCGeneratorCheckHelper()
 
 void SDCCGeneratorCheckHelper::initSupported()
 {
-  PURL::Url url(PURL::Directory::current(), "test.c");
+  PURL::Url url(PURL::currentDirectory(), "test.c");
   Log::StringView view;
   PURL::File file(url, view);
   if ( file.openForWrite() ) file.appendText("void main(void) {}\n");
