@@ -44,7 +44,7 @@ public:
   GeneratorCheck(GeneratorCheckHelper *helper);
   virtual ~GeneratorCheck();
   virtual bool skip(const Device::Data &data) const;
-  virtual void runTest();
+  virtual int runTest();
   virtual bool init(const Device::Data &data);
   virtual bool executeDevice(const Device::Data &data);
   virtual void cleanup(const Device::Data &data);
