@@ -10,10 +10,12 @@
 
 //----------------------------------------------------------------------------
 Test::Test()
-  : _nbPassed(0), _nbFailed(0), _nbSkipped(0)
+: _nbPassed(0),
+  _nbFailed(0),
+  _nbSkipped(0)
 {}
 
-void Test::runTest()
+int Test::runTest()
 {
   _args = KCmdLineArgs::parsedArgs();
   checkArguments();
@@ -21,6 +23,7 @@ void Test::runTest()
   execute();
   printf("\n");
   printf("RESULTS: %i PASSED / %i FAILED / %i SKIPPED \n", _nbPassed, _nbFailed, _nbSkipped);
+  return (_nbFailed == 0 ? 0 : 1);
 }
 
 void Test::failed(const QString &message, const char *file, int line)
