@@ -11,20 +11,20 @@
 #include "common/global/purl.h"
 
 //----------------------------------------------------------------------------
-bool MiscCheck::execute()
+void MiscCheck::execute()
 {
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl(QString::null);
+    PURL::Url url = PURL::fromPathOrUrl(QString::null, false);
     if ( !url.isEmpty() ) TEST_FAILED("isEmpty");
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("");
+    PURL::Url url = PURL::fromPathOrUrl("", false);
     if ( !url.isEmpty() ) TEST_FAILED("isEmpty");
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("/");
+    PURL::Url url = PURL::fromPathOrUrl("/", false);
     if ( url.isEmpty() ) TEST_FAILED("isEmpty");
     if ( url.isRelative() ) TEST_FAILED("isRelative");
     if ( !url.isLocal() ) TEST_FAILED("isLocal");
@@ -35,7 +35,7 @@ bool MiscCheck::execute()
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("test");
+    PURL::Url url = PURL::fromPathOrUrl("test", true);
     if ( url.isEmpty() ) TEST_FAILED("isEmpty");
     if ( !url.isRelative() ) TEST_FAILED("isRelative");
     if ( !url.isLocal() ) TEST_FAILED("isLocal");
@@ -43,7 +43,15 @@ bool MiscCheck::execute()
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("/test");
+    PURL::Url url = PURL::fromPathOrUrl("test", false);
+    if ( url.isEmpty() ) TEST_FAILED("isEmpty");
+    if ( url.isRelative() ) TEST_FAILED("isRelative");
+    if ( !url.isLocal() ) TEST_FAILED("isLocal");
+    if ( url.filename()!="test" ) TEST_FAILED(url.filename());
+    TEST_PASSED;
+  }
+  {
+    PURL::Url url = PURL::fromPathOrUrl("/test", false);
     if ( url.isEmpty() ) TEST_FAILED("isEmpty");
     if ( url.isRelative() ) TEST_FAILED("isRelative");
     if ( !url.isLocal() ) TEST_FAILED("isLocal");
@@ -54,7 +62,7 @@ bool MiscCheck::execute()
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("/test/");
+    PURL::Url url = PURL::fromPathOrUrl("/test/", false);
     if ( url.isEmpty() ) TEST_FAILED("isEmpty");
     if ( url.isRelative() ) TEST_FAILED("isRelative");
     if ( !url.isLocal() ) TEST_FAILED("isLocal");
@@ -65,18 +73,18 @@ bool MiscCheck::execute()
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("c:/test");
+    PURL::Url url = PURL::fromPathOrUrl("c:/test", false);
     if ( url.isEmpty() ) TEST_FAILED("isEmpty");
     if ( url.isRelative() ) TEST_FAILED("isRelative");
     if ( !url.isLocal() ) TEST_FAILED("isLocal");
-    PURL::Url url2 = PURL::Url::fromPathOrUrl("c:/");
+    PURL::Url url2 = PURL::fromPathOrUrl("c:/", false);
     if ( url.path()!=url2.path() ) TEST_FAILED(url.path());
     if ( url==url2 ) TEST_FAILED(url.path());
     if ( url.filename()!="test" ) TEST_FAILED(url.filename());
     TEST_PASSED;
   }
   {
-    PURL::Url url = PURL::Url::fromPathOrUrl("d:/test/");
+    PURL::Url url = PURL::fromPathOrUrl("d:/test/", false);
     if ( url.isEmpty() ) TEST_FAILED("isEmpty");
     if ( url.isRelative() ) TEST_FAILED("isRelative");
     if ( !url.isLocal() ) TEST_FAILED("isLocal");
@@ -91,8 +99,6 @@ bool MiscCheck::execute()
     if ( url.filename()!="test" ) TEST_FAILED(url.filename());
     TEST_PASSED;
   }
-
-  return true;
 }
 
 //----------------------------------------------------------------------------
