@@ -12,18 +12,21 @@
 #include "libgui/likeback.h"
 
 const KCmdLineOptions OPTIONS[] = {
-  { "+[file]", I18N_NOOP("Optional filenames to be opened upon startup."), 0 },
-  { 0, 0, 0}
+  { "+[file]", I18N_NOOP("Optional filenames to be opened upon startup."), NULL },
+  { NULL, NULL, NULL}
 };
 
 int main(int argc, char **argv)
 {
-  Piklab::AboutData *about = new Piklab::AboutData("piklab", I18N_NOOP("Piklab"), I18N_NOOP( "Graphical development environment for applications based on PIC and dsPIC microcontrollers."));
-  Piklab::init(about, argc, argv, true, OPTIONS);
+  Piklab::AboutData about("piklab", I18N_NOOP("Piklab"),
+                          I18N_NOOP( "Graphical development environment for applications based on PIC and dsPIC microcontrollers."));
+  Piklab::initArgs(about, argc, argv, *OPTIONS);
+  const bool gui = true;
+  Piklab::createApplication(about.appName(), argc, argv, gui, NULL);
   LikeBack::init(true);
   LikeBack::setServer("piklab.sourceforge.net", "/likeback/send.php");
   LikeBack::setAllowFeatureWishes(true);
-  if ( kapp->isRestored() && KMainWindow::canBeRestored(1) ) MainWindow::self()->restore(1);
-  else MainWindow::self()->show();
+  if ( kapp->isRestored() && KMainWindow::canBeRestored(1) ) MainWindow::self().restore(1);
+  else MainWindow::self().show();
   return kapp->exec();
 }
