@@ -16,20 +16,27 @@
 
 //----------------------------------------------------------------------------
 Debugger::Base::Base(Programmer::Base &programmer)
-  : Log::Base(&programmer), _programmer(programmer), _deviceSpecific(0),
-    _specific(0), _inputType(PURL::Nb_FileTypes), _coff(0)
+: Log::Base(&programmer), _programmer(programmer),
+  _deviceSpecific(NULL),
+  _specific(NULL),
+  _inputType(PURL::Nb_FileTypes),
+  _coff(NULL)
 {}
 
 void Debugger::Base::init(DeviceSpecific *deviceSpecific, Specific *specific)
 {
+  delete _deviceSpecific;
   _deviceSpecific = deviceSpecific;
+  delete _specific;
   _specific = specific;
 }
 
 Debugger::Base::~Base()
 {
   delete _deviceSpecific;
+  _deviceSpecific = NULL;
   delete _specific;
+  _specific = NULL;
 }
 
 const Device::Data *Debugger::Base::device() const
