@@ -68,7 +68,7 @@ protected:
 class DeviceSpecific : public Log::Base
 {
 public:
-  DeviceSpecific(Debugger::Base &base) : Log::Base(base), _base(base) {}
+  DeviceSpecific(Debugger::Base &base) : Log::Base(&base), _base(base) {}
   virtual bool updateStatus() = 0;
   virtual QString statusString() const = 0;
 
@@ -80,7 +80,7 @@ protected:
 class Specific : public Log::Base
 {
 public:
-  Specific(Debugger::Base &base) : Log::Base(base), _base(base) {}
+  Specific(Debugger::Base &base) : Log::Base(&base), _base(base) {}
 
 protected:
   Debugger::Base &_base;
