@@ -33,6 +33,28 @@ const Programmer::Task::Data Programmer::Task::DATA[Nb_Types] = {
   { I18N_NOOP("Blank Checking...") }
 };
 
+//-----------------------------------------------------------------------------
+Programmer::VerifyData::VerifyData(VerifyActions pactions, const Device::Memory &memory)
+: actions(pactions)
+{
+  _memory.reset(memory.clone());
+}
+
+Programmer::VerifyData::VerifyData(const VerifyData& vdata)
+{
+  *this = vdata;
+}
+
+Programmer::VerifyData& Programmer::VerifyData::operator=(const VerifyData& vdata)
+{
+  if (this != &vdata) {
+    actions = vdata.actions;
+    protectedRanges = vdata.protectedRanges;
+    _memory.reset(vdata.memory().clone());
+  }
+  return *this;
+}
+
 //-----------------------------------------------------------------------------
 Programmer::Generic::Generic(const Group &group, const Device::Data *device)
   : _device(device), _state(NotConnected), _group(group)
@@ -229,7 +251,7 @@ bool Programmer::Base::setTargetPowerOn(bool on)
   return _specific->setTargetPowerOn(on);
 }
 
-void Programmer::Base::appendTask(Task task, const Device::MemoryRange *range)
+void Programmer::Base::appendTask(Task task, const Device::MemoryRange& range)
 {
   _progressMonitor.appendTask(task.label(), nbSteps(task, range));
 }
@@ -267,6 +289,7 @@ bool Programmer::Base::run()
 
 bool Programmer::Base::stop()
 {
+  if ( !doConnectDevice() ) return false;
   _progressMonitor.setActionMessage(i18n("Breaking..."));
   _state = ::Programmer::Stopped;
   return hardware()->setTargetReset(Device::ResetMode::Held);
@@ -312,8 +335,8 @@ bool Programmer::Base::doUploadFirmware(PURL::File &file)
 bool Programmer::Base::erase(const Device::MemoryRange &range)
 {
   _progressMonitor.clear();
-  appendTask(Task::Erase, &range);
-  if ( readConfigEntry(Config::BlankCheckAfterErase).toBool() ) appendTask(Task::BlankCheck);
+  appendTask(Task::Erase, range);
+  if ( readConfigEntry(Config::BlankCheckAfterErase).toBool() ) appendTask(Task::BlankCheck, range);
   bool ok = doErase(range);
   endProgramming();
   return ok;
@@ -350,7 +373,7 @@ bool Programmer::Base::read(Device::Memory &memory, const Device::MemoryRange &r
 {
   if ( !checkCanRead() ) return false;
   _progressMonitor.clear();
-  appendTask(Task::Read, &range);
+  appendTask(Task::Read, range);
   bool ok = doRead(memory, range);
   endProgramming();
   return ok;
@@ -372,7 +395,7 @@ bool Programmer::Base::doRead(Device::Memory &memory, const Device::MemoryRange
 bool Programmer::Base::program(const Device::Memory &memory, const Device::MemoryRange &range)
 {
   _progressMonitor.clear();
-  appendTask(Task::Write, &range);
+  appendTask(Task::Write, range);
   bool ok = doProgram(memory, range);
   endProgramming();
   return ok;
@@ -395,7 +418,7 @@ bool Programmer::Base::verify(const Device::Memory &memory, const Device::Memory
 {
   if ( !checkCanRead() ) return false;
   _progressMonitor.clear();
-  appendTask(Task::Verify, &range);
+  appendTask(Task::Verify, range);
   bool ok = doVerify(memory, range);
   endProgramming();
   return ok;
@@ -404,13 +427,16 @@ bool Programmer::Base::verify(const Device::Memory &memory, const Device::Memory
 bool Programmer::Base::doVerify(VerifyAction action, const Device::MemoryRange &range, const Device::Memory *memory)
 {
   const Device::Memory *vmemory = memory;
-  if ( memory==0 ) {
-    Q_ASSERT( action & BlankCheckVerify );
+  if (memory == NULL) {
+    ASSERT(action & BlankCheckVerify);
     vmemory = _device->group().createMemory(*_device);
   }
   VerifyData vdata(action, *vmemory);
   bool ok = internalRead(0, range, &vdata);
-  if ( memory==0 ) delete vmemory;
+  if (memory == NULL) {
+    delete vmemory;
+    vmemory = NULL;
+  }
   return ok;
 }
 
@@ -429,7 +455,7 @@ bool Programmer::Base::blankCheck(const Device::MemoryRange &range)
 {
   if ( !checkCanRead() ) return false;
   _progressMonitor.clear();
-  appendTask(Task::BlankCheck, &range);
+  appendTask(Task::BlankCheck, range);
   bool ok = doBlankCheck(range);
   endProgramming();
   return ok;
