@@ -35,10 +35,17 @@ Q_DECLARE_FLAGS(VerifyActions, VerifyAction)
 Q_DECLARE_OPERATORS_FOR_FLAGS(VerifyActions)
 class VerifyData {
 public:
-  VerifyData(VerifyActions pactions, const Device::Memory &pmemory) : actions(pactions), memory(pmemory) {}
+  VerifyData(VerifyActions pactions, const Device::Memory &memory);
+  VerifyData(const VerifyData& vdata);
+  VerifyData& operator=(const VerifyData& vdata);
+
   VerifyActions actions;
   AddressRangeVector protectedRanges;
-  const Device::Memory &memory;
+  const Device::Memory& memory() const { return *_memory; }
+  Device::Memory& memory() { return *_memory; }
+
+private:
+  std::auto_ptr<Device::Memory> _memory;
 };
 
 BEGIN_DECLARE_ENUM(ResultType)
@@ -126,7 +133,7 @@ public:
   bool readVoltages();
   const Device::VoltageValue &voltage(Device::VoltageType type) const { return _voltages[type.type()]; }
   virtual bool selfTest(bool ask) { Q_UNUSED(ask); return true; }
-  void appendTask(Task task, const Device::MemoryRange *range = 0);
+  void appendTask(Task task, const Device::MemoryRange &range);
 
   virtual bool erase(const Device::MemoryRange &range);
   virtual bool read(Device::Memory &memory, const Device::MemoryRange &range);
@@ -160,7 +167,7 @@ protected:
   virtual bool internalSetupHardware() { return initProgramming(); }
   virtual bool initProgramming();
   virtual bool verifyDeviceId() = 0;
-  virtual uint nbSteps(Task task, const Device::MemoryRange *range) const = 0;
+  virtual uint nbSteps(Task task, const Device::MemoryRange &range) const = 0;
   virtual bool doUploadFirmware(PURL::File &);
   virtual bool internalUploadFirmware(PURL::File &) { return false; }
   virtual bool internalEnterMode(Mode) { return false; }
