@@ -31,9 +31,10 @@ Programmer::Generic *Programmer::Group::createProgrammer(bool targetSelfPowered,
 {
   Generic *generic = createBase(data);
   if ( !(generic->group().properties() & Custom) ) {
-    Programmer::Base *base = static_cast<Programmer::Base *>(generic);
+    typedef ::Programmer::Base Base; // for G++ 3.3.6
+    Base *base = static_cast<Base*>(generic);
     Hardware *hardware = createHardware(*base, hd);
-    DeviceSpecific *ds = (data ? createDeviceSpecific(*base) : 0);
+    DeviceSpecific *ds = (data != NULL ? createDeviceSpecific(*base) : NULL);
     base->init(targetSelfPowered, hardware, ds);
   }
   return generic;
@@ -42,7 +43,7 @@ Programmer::Generic *Programmer::Group::createProgrammer(bool targetSelfPowered,
 Debugger::Base *Programmer::Group::createDebugger(::Programmer::Base &base) const
 {
   ::Debugger::Base *dbase = createDebuggerBase(base);
-  if (dbase) {
+  if (dbase != NULL) {
     ::Debugger::DeviceSpecific *dspecific = createDebuggerDeviceSpecific(*dbase);
     ::Debugger::Specific *specific = createDebuggerSpecific(*dbase);
     dbase->init(dspecific, specific);
@@ -53,7 +54,9 @@ Debugger::Base *Programmer::Group::createDebugger(::Programmer::Base &base) cons
 bool Programmer::Group::checkConnection(const HardwareDescription &hd) const
 {
   Generic *generic = createProgrammer(false, 0, hd);
-  bool ok = (generic->group().properties() & Custom ? true : static_cast<Programmer::Base *>(generic)->simpleConnectHardware());
+  typedef ::Programmer::Base Base; // for G++ 3.3.6
+  bool ok = (generic->group().properties() & Custom
+             ? true : static_cast<Base*>(generic)->simpleConnectHardware());
   delete generic;
   return ok;
 }
