@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2006 Nicolas Hadacek <hadacek@kde.org>                  *
+ *   Copyright (C) 2006-2009 Nicolas Hadacek <hadacek@kde.org>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -10,7 +10,7 @@
 #define GPSIM_H
 
 #include "common/common/version_data.h"
-#include "progs/base/prog_specific.h"
+#include "devices/pic/prog/pic_prog_specific.h"
 #include "common/global/process.h"
 #include "common/global/purl.h"
 
@@ -44,6 +44,7 @@ public:
   Process &process() { return _process; }
   bool isReady() const { return _process._ready; }
   bool start();
+  bool start(const PURL::Directory& execDir);
   bool runSynchronously();
   bool sendCommand(const QString &cmd, bool synchronous);
   bool sendSignal(uint n, bool synchronous);
@@ -76,13 +77,23 @@ private:
 };
 
 //-----------------------------------------------------------------------------
-class DeviceSpecific : public ::Programmer::DeviceSpecific
+class DeviceSpecific : public ::Programmer::PicDeviceSpecific
 {
 public:
-  DeviceSpecific(::Programmer::Base &base) : ::Programmer::DeviceSpecific(base) {}
+  DeviceSpecific(::Programmer::Base &base) : ::Programmer::PicDeviceSpecific(base) {}
   virtual bool setPowerOff() { return false; }
   virtual bool setPowerOn() { return false; }
   virtual bool setTargetPowerOn(bool) { return true; }
+  virtual ::Programmer::Capabilities capabilities() const { return ::Programmer::NoCapability; }
+  virtual bool canEraseRange(Pic::MemoryRangeType) const { return false; }
+  virtual bool canReadRange(Pic::MemoryRangeType) const { return false; }
+  virtual bool canWriteRange(Pic::MemoryRangeType) const { return false; }
+
+protected:
+  virtual bool doErase(bool) { return false; }
+  virtual bool doEraseRange(Pic::MemoryRangeType) { return false; }
+  virtual bool doRead(Pic::MemoryRangeType, uint, Device::Array &, const ::Programmer::VerifyData*) { return false; }
+  virtual bool doWrite(Pic::MemoryRangeType, uint, const Device::Array &, bool) { return false; }
 };
 
 } // namespace
