@@ -16,17 +16,35 @@
 #include "coff/base/text_coff.h"
 #include "progs/manager/debug_manager.h"
 
+//----------------------------------------------------------------------------
+PURL::Directory GPSim::Config::executableDirectory()
+{
+    Config config;
+    return config.readEntry("exec_dir", QString::null);
+}
+
+void GPSim::Config::writeExecutableDirectory(const PURL::Directory& dir)
+{
+    Config config;
+    config.writeEntry("exec_dir", dir.path());
+}
+
 //----------------------------------------------------------------------------
 GPSim::Debugger::Debugger(Programmer &programmer)
-  : ::Debugger::PicBase(programmer), _nbBreakpoints(0)
+: ::Debugger::PicBase(programmer),
+  _nbBreakpoints(0)
 {}
 
 bool GPSim::Debugger::internalInit()
 {
-  if ( !hardware()->execute("processor pic" + device()->name().lower(), true) ) return false;
-  if ( _inputType==PURL::Cod ) return hardware()->execute("load s " + _filename, true);
-  Q_ASSERT( _inputType==PURL::Hex );
-  return hardware()->execute("load h " + _filename, true);
+  if (hardware()->version() < VersionData(0, 22, 0)) {
+    if ( !hardware()->execute("processor pic" + device()->name().lower(), true) ) return false;
+    if ( _inputType==PURL::Cod ) return hardware()->execute("load s " + _filename, true);
+    else return hardware()->execute("load h " + _filename, true);
+  } else {
+      return hardware()->execute("load pic" + device()->name().lower()
+                                 + " " + _filename, true);
+  }
 }
 
 bool GPSim::Debugger::internalRun()
