@@ -15,6 +15,15 @@
 
 namespace GPSim
 {
+//-----------------------------------------------------------------------------
+class Config : public GenericConfig
+{
+public:
+  Config() : GenericConfig("gpsim") {}
+  static PURL::Directory executableDirectory();
+  static void writeExecutableDirectory(const PURL::Directory& dir);
+};
+
 //-----------------------------------------------------------------------------
 class Programmer : public ::Programmer::PicBase
 {
@@ -88,7 +97,7 @@ protected:
   virtual ::Programmer::Hardware *createHardware(::Programmer::Base &base, const ::Programmer::HardwareDescription &hd) const;
   virtual ::Programmer::DeviceSpecific *createDeviceSpecific(::Programmer::Base &base) const;
   virtual ::Debugger::Base *createDebuggerBase(::Programmer::Base &base) const { return new Debugger(static_cast<Programmer &>(base)); }
-  virtual ::Debugger::Specific *createDebuggerSpecific(::Debugger::Base &) const { return 0; }
+  virtual ::Debugger::Specific *createDebuggerSpecific(::Debugger::Base &) const { return NULL; }
 };
 
 } // namespace
