@@ -13,14 +13,22 @@
 
 #include "common/gui/misc_gui.h"
 #include "progs/base/prog_group.h"
-#include "progs/gpsim/base/gpsim.h"
+#include "progs/gpsim/base/gpsim_debug.h"
 
 //----------------------------------------------------------------------------
 GPSim::ConfigWidget::ConfigWidget(const ::Programmer::Group &group, QWidget *parent)
-  : ::Programmer::ConfigWidget(group, parent)
+: ::Programmer::ConfigWidget(group, parent)
 {
   uint row = numRows();
-  QLabel *label = new QLabel(i18n("Status:"), this);
+
+  QLabel* label = new QLabel(i18n("Executable directory:"), this);
+  addWidget(label, row,row, 0,0);
+  _dir = new PURL::DirectoryWidget(this);
+  connect(_dir, SIGNAL(changed()), SLOT(updateStatus()));
+  addWidget(_dir, row,row, 1,2);
+  ++row;
+
+  label = new QLabel(i18n("Status:"), this);
   addWidget(label, row,row, 0,0);
   _status = new QLabel(this);
   addWidget(_status, row,row, 1,1);
@@ -37,17 +45,33 @@ GPSim::ConfigWidget::ConfigWidget(const ::Programmer::Group &group, QWidget *par
   addWidget(button, row,row, 2,2);
   connect(button, SIGNAL(clicked()), SLOT(showDevicesDetails()));
   ++row;
+}
 
-  QTimer::singleShot(0, this, SLOT(updateStatus()));
+void GPSim::ConfigWidget::loadConfig()
+{
+    ::Programmer::ConfigWidget::loadConfig();
+    _dir->blockSignals(true);
+    _dir->setDirectory(GPSim::Config::executableDirectory());
+    _dir->blockSignals(false);
+
+    QTimer::singleShot(0, this, SLOT(updateStatus()));
+}
+
+void GPSim::ConfigWidget::saveConfig()
+{
+    ::Programmer::ConfigWidget::saveConfig();
+    GPSim::Config::writeExecutableDirectory(_dir->directory());
 }
 
 void GPSim::ConfigWidget::updateStatus()
 {
+  _status->setText("Detecting \"gpsim\"...");
   _versionLines.clear();
   _devicesLines.clear();
+  _devicesLabel->setText("");
 
   ProcessManager manager(0);
-  bool ok = manager.start();
+  bool ok = manager.start(_dir->directory());
   _arguments = manager.process().arguments();
   _versionLines = manager.outputLines();
   if (!ok) {
@@ -75,7 +99,7 @@ void GPSim::ConfigWidget::updateStatus()
 
 void GPSim::ConfigWidget::showVersionDetails()
 {
-  QString s = "<qt" + i18n("<b>Command: </b>%1<br>").arg(_arguments.join(" "));
+  QString s = "<qt>" + i18n("<b>Command: </b>%1<br>").arg(_arguments.join(" "));
   s += _versionLines.join("<br>");
   MessageBox::text(s, Log::Show);
 }
