@@ -9,46 +9,67 @@
 #ifndef PROG_CONFIG_CENTER_H
 #define PROG_CONFIG_CENTER_H
 
+#include <map>
+#include <memory>
+
 #include <qcheckbox.h>
 
+#include "common/gui/dialog.h"
 #include "common/gui/config_widget.h"
 #include "common/gui/key_gui.h"
 #include "common/gui/container.h"
 #include "progs/base/prog_config.h"
+#include "progs/list/prog_list.h"
 class PortSelector;
 
 namespace Programmer
 {
+class ProgConfigWidget;
+
 BEGIN_DECLARE_CONFIG_WIDGET(Config, OptionsConfigWidget)
   virtual QString header() const { return i18n("Programmer Options"); }
   virtual QString title() const { return i18n("Programmer Options"); }
   virtual QPixmap pixmap() const;
 END_DECLARE_CONFIG_WIDGET
 
-//----------------------------------------------------------------------------
-class SelectConfigWidget : public ::ConfigWidget
+//-----------------------------------------------------------------------------
+class ConfigCenter : public TreeListDialog
 {
 Q_OBJECT
 public:
-  SelectConfigWidget();
-  virtual void loadConfig() {}
-  virtual QString header() const { return i18n("Programmer Selection"); }
-  virtual QString title() const { return i18n("Programmer Selection"); }
-  virtual QPixmap pixmap() const;
+  ConfigCenter(const Programmer::Group &group, QWidget *parent);
+
+public slots:
+  virtual void slotOk();
+  virtual void slotApply();
+  virtual void slotUser1();
+
+private slots:
+  void aboutToShowPageSlot(QWidget* page);
+
+private:
+  typedef std::map<QWidget *, ProgConfigWidget *> Pages;
+  Pages _pages;
+
+  ProgConfigWidget* current() const;
+};
+
+//----------------------------------------------------------------------------
+class ProgConfigWidget : public ::ConfigWidget
+{
+Q_OBJECT
+public:
+  ProgConfigWidget(const Programmer::Group& group, QWidget* parent);
+  virtual void loadConfig();
 
 public slots:
   virtual void saveConfig();
-
-private slots:
-  void programmerChanged();
-  void portChanged();
+  void detect();
 
 private:
-  KeyComboBox<QString> *_combo;
-  PortSelector *_portSelector;
-  KeyWidgetStack<QString> *_stack;
-  Container::Grid *_portSelectorContainer;
-  QTabWidget *_tabWidget;
+  const Programmer::Group&    _group;
+  PortSelector*               _portSelector;
+  ::Programmer::ConfigWidget* _specific;
 };
 
 } // namespace
