@@ -89,49 +89,53 @@ const Icd2::Hardware::WRITE_MODE_VALUES::Data Icd2::Hardware::WRITE_MODE_VALUES:
 const char *Icd2::Hardware::readCommand(Pic::MemoryRangeType type) const
 {
   switch (type.type()) {
-    case Pic::MemoryRangeType::Code:             return "47";
-    case Pic::MemoryRangeType::Eeprom:           return "48";
+    case Pic::MemoryRangeType::Code:                          return "47";
+    case Pic::MemoryRangeType::Eeprom:                        return "48";
     case Pic::MemoryRangeType::Config:
       if ( device().architecture()==Pic::Architecture::P18J ) return "47";
-      return "49";
-    case Pic::MemoryRangeType::UserId:           return "4A";
+      else                                                    return "49";
+    case Pic::MemoryRangeType::UserId:
+      if (device().architecture() == Pic::Architecture::P33F) return "49";
+      else                                                    return "4A";
     case Pic::MemoryRangeType::DeviceId:
-      if ( device().architecture()==Pic::Architecture::P30F ) return "49";
-      return "4A";
+      if ( device().is16bitFamily() )                         return "49";
+      else                                                    return "4A";
     case Pic::MemoryRangeType::Cal:
     case Pic::MemoryRangeType::CalBackup:
       if ( device().architecture()==Pic::Architecture::P16X ) return "49"; // ?
-      return "47"; // for baseline only ?
-    case Pic::MemoryRangeType::DebugVector:      return "40";
+      else                                                    return "47"; // for baseline only ?
+    case Pic::MemoryRangeType::DebugVector:                   return "40";
     case Pic::MemoryRangeType::ProgramExecutive:
     case Pic::MemoryRangeType::HardwareStack:
-    case Pic::MemoryRangeType::Nb_Types:    break;
+    case Pic::MemoryRangeType::Nb_Types:                      break;
   }
-  Q_ASSERT(false);
-  return 0;
+  ASSERT(false);
+  return NULL;
 }
 
 const char *Icd2::Hardware::writeCommand(Pic::MemoryRangeType type) const
 {
   switch (type.type()) {
-    case Pic::MemoryRangeType::Code:             return "43";
-    case Pic::MemoryRangeType::Eeprom:           return "44";
+    case Pic::MemoryRangeType::Code:                          return "43";
+    case Pic::MemoryRangeType::Eeprom:                        return "44";
     case Pic::MemoryRangeType::Config:
       if ( device().architecture()==Pic::Architecture::P18J ) return "43";
-      return "45";
-    case Pic::MemoryRangeType::UserId:           return "46";
-    case Pic::MemoryRangeType::DeviceId:         break;
+      else                                                    return "45";
+    case Pic::MemoryRangeType::UserId:
+      if (device().architecture() == Pic::Architecture::P33F) return "45";
+      else                                                    return "46";
+    case Pic::MemoryRangeType::DeviceId:                      break;
     case Pic::MemoryRangeType::Cal:
     case Pic::MemoryRangeType::CalBackup:
       if ( device().architecture()==Pic::Architecture::P16X ) return "45"; // ?
-      return "43"; // for baseline only ?
-    case Pic::MemoryRangeType::DebugVector:      return "41";
+      else                                                    return "43"; // for baseline only ?
+    case Pic::MemoryRangeType::DebugVector:                   return "41";
     case Pic::MemoryRangeType::ProgramExecutive:
     case Pic::MemoryRangeType::HardwareStack:
-    case Pic::MemoryRangeType::Nb_Types:    break;
+    case Pic::MemoryRangeType::Nb_Types:                      break;
   }
-  Q_ASSERT(false);
-  return 0;
+  ASSERT(false);
+  return NULL;
 }
 
 bool Icd2::Hardware::uploadFirmware(const Pic::Memory &memory)
@@ -332,11 +336,11 @@ bool Icd2::Hardware::readBlock(uint nbBytesWord, uint nbWords, Device::Array &da
   }
 
   // treat data
+  log(Log::DebugLevel::Max, QString("received %1 * %2: %2").arg(nbBytesWord).arg(nbWords).arg(s));
   if ( s[0]!='{' || s[s.length()-1]!='}' ) {
     log(Log::LineType::Error, i18n("Invalid begin or end character for read block."));
     return false;
   }
-  log(Log::DebugLevel::Max, "received: " + s);
   data.resize(nbWords);
   Q_UINT8 chk = 0;
   for (uint i=0; i<nbWords; i++) {
@@ -466,6 +470,9 @@ bool Icd2::Hardware::eraseAll()
   if ( hasError() ) return false;
   if ( !sendCommand("29") ) return false;
   if ( !receiveResponse("29", 0, true) ) return false; // poll
+  if (device().architecture() == Pic::Architecture::P33F) {
+    if (!command("25", 0)) return false;
+  }
   return true;
 }
 
