@@ -198,10 +198,9 @@ bool Icd2::DebugProgrammer::internalSetupHardware()
   return Icd2::ProgrammerBase::internalSetupHardware();
 }
 
-Pic::Memory Icd2::DebugProgrammer::toDebugMemory(const Pic::Memory &mem, bool withDebugExecutive)
+void Icd2::DebugProgrammer::toDebugMemory(Pic::Memory &memory, bool withDebugExecutive)
 {
-  Pic::Memory memory = mem;
-  memory.setDebugOn(true);
+  // debug bit should have already been put to ON in internalProgram()
   if ( memory.hasWatchdogTimerOn() ) {
     log(Log::LineType::Warning, i18n("Disabling watchdog timer for debugging"));
     memory.setWatchdogTimerOn(false);
@@ -231,7 +230,6 @@ Pic::Memory Icd2::DebugProgrammer::toDebugMemory(const Pic::Memory &mem, bool wi
     }
     if ( !ok ) log(Log::LineType::Warning, i18n("Memory area for debug executive was not empty. Overwrite it and continue anyway..."));
   }
-  return memory;
 }
 
 bool Icd2::DebugProgrammer::writeDebugExecutive()
@@ -277,27 +275,28 @@ bool Icd2::DebugProgrammer::doProgram(const Device::Memory &memory, const Device
 
 bool Icd2::DebugProgrammer::programAll(const Pic::Memory &mem)
 {
-  Pic::Memory memory = toDebugMemory(mem, false);
-  if ( !programAndVerifyRange(Pic::MemoryRangeType::Code, memory) ) return false;
+  std::auto_ptr<Pic::Memory> memory(static_cast<Pic::Memory*>(mem.clone()));
+  toDebugMemory(*memory, false);
+  if ( !programAndVerifyRange(Pic::MemoryRangeType::Code, *memory) ) return false;
   if ( !writeDebugExecutive() ) return false;
-  if ( !programAndVerifyRange(Pic::MemoryRangeType::DebugVector, memory) ) return false;
-  if ( !programAndVerifyRange(Pic::MemoryRangeType::Eeprom, memory) ) return false;
-  if ( !programAndVerifyRange(Pic::MemoryRangeType::UserId, memory) ) return false;
+  if ( !programAndVerifyRange(Pic::MemoryRangeType::DebugVector, *memory) ) return false;
+  if ( !programAndVerifyRange(Pic::MemoryRangeType::Eeprom, *memory) ) return false;
+  if ( !programAndVerifyRange(Pic::MemoryRangeType::UserId, *memory) ) return false;
   if ( device()->is18Family() ) {
     if ( !hardware()->command("0C00", 0) ) return false; // #### ??
     QString com = "42" + toHex(0xFB5, 8) + toHex(1, 8); // write RSBUG (?)
     if ( !hardware()->command(com, 0) ) return false;
     if ( !hardware()->command("0C01", 0) ) return false; // #### ??
   }
-  if ( !programAndVerifyRange(Pic::MemoryRangeType::Config, memory) ) return false;
+  if ( !programAndVerifyRange(Pic::MemoryRangeType::Config, *memory) ) return false;
   return true;
 }
 
 bool Icd2::DebugProgrammer::internalRead(Device::Memory *mem, const Device::MemoryRange &range, const ::Programmer::VerifyData *vd)
 {
   if ( vd==0 || (vd->actions & ::Programmer::BlankCheckVerify) ) return Icd2::ProgrammerBase::internalRead(mem, range, vd);
-  Pic::Memory memory = toDebugMemory(static_cast<const Pic::Memory &>(vd->memory), true);
-  ::Programmer::VerifyData vdata(vd->actions, memory);
+  ::Programmer::VerifyData vdata(*vd);
+  toDebugMemory(static_cast<Pic::Memory&>(vdata.memory()), true);
   if ( !Icd2::ProgrammerBase::internalRead(0, range, &vdata) ) return false;
   if ( range.all() && !readRange(Pic::MemoryRangeType::DebugVector, 0, &vdata) ) return false;
   return true;
