@@ -37,7 +37,7 @@ private:
 
   bool getDebugExecutive();
   bool writeDebugExecutive();
-  Pic::Memory toDebugMemory(const Pic::Memory &memory, bool withDebugExecutive);
+  void toDebugMemory(Pic::Memory &memory, bool withDebugExecutive);
 };
 
 //-----------------------------------------------------------------------------
