@@ -41,7 +41,7 @@ Programmer::Lister::Lister()
   addGroup(new Icd2::DebuggerGroup, new Icd2::GroupUI);
   addGroup(new Icd1::Group, new Icd1::GroupUI);
   addGroup(new Pickit2::Group, new Pickit2::GroupUI);
-  addGroup(new Pickit2V2::Group, new Pickit2V2::GroupUI);
+  //addGroup(new Pickit2V2::Group, new Pickit2V2::GroupUI);
   addGroup(new Pickit1::Group, new Pickit1::GroupUI);
   addGroup(new Psp::Group, new Psp::GroupUI);
   addGroup(new GPSim::Group, new GPSim::GroupUI);
