@@ -20,11 +20,15 @@
 #include "progs/base/debug_config.h"
 #include "prog_manager.h"
 
-Debugger::Manager *Debugger::manager = 0;
+Debugger::Manager *Debugger::manager = NULL;
 
 Debugger::Manager::Manager()
-  :  QObject(Programmer::manager, "debug_manager"), Log::Base(Programmer::manager), GenericView(Breakpoint::list()),
-    _coff(0), _data(0)
+: QObject(Programmer::manager, "debug_manager"),
+  Log::Base(Programmer::manager),
+  GenericView(Breakpoint::list()),
+  _coff(NULL),
+  _inited(false),
+  _data(NULL)
 {
   connect(&_runTimer, SIGNAL(timeout()), SLOT(slotRunTimeout()));
   connect(&_stepTimer, SIGNAL(timeout()), SLOT(doStep()));
@@ -33,6 +37,7 @@ Debugger::Manager::Manager()
 Debugger::Manager::~Manager()
 {
   delete _coff;
+  _coff = NULL;
 }
 
 bool Debugger::Manager::isStepping() const
@@ -42,7 +47,7 @@ bool Debugger::Manager::isStepping() const
 
 Debugger::Base *Debugger::Manager::debugger() const
 {
-  return (programmer() ? programmer()->debugger() : 0);
+  return (programmer() ? programmer()->debugger() : NULL);
 }
 
 void Debugger::Manager::updateDevice()
@@ -78,6 +83,7 @@ bool Debugger::Manager::init()
 bool Debugger::Manager::internalInit()
 {
   clear();
+  _inited = true;
   if ( !coffUrl().exists() ) return false;
   Log::Base log;
   log.setView(compileView());
@@ -85,7 +91,7 @@ bool Debugger::Manager::internalInit()
   _coff = new Coff::TextObject(_data, coffUrl());
   if ( !_coff->parse(log) ) {
     delete _coff;
-    _coff = 0;
+    _coff = NULL;
     return false;
   }
 /*
@@ -133,7 +139,7 @@ BitValue Debugger::Manager::pc() const
 
 Breakpoint::MarkType Debugger::Manager::breakpointType(const Breakpoint::Data &data) const
 {
-  if ( _coff==0 ) return Breakpoint::BreakpointDisabled;
+  if ( _coff==NULL ) return Breakpoint::BreakpointDisabled;
   Address address = Breakpoint::list().address(data);
   if ( !address.isValid() ) return Breakpoint::BreakpointInvalid;
   if ( Breakpoint::list().state(data)!=Breakpoint::Active ) return Breakpoint::BreakpointDisabled;
@@ -147,7 +153,7 @@ Breakpoint::MarkType Debugger::Manager::breakpointType(const Breakpoint::Data &d
 bool Debugger::Manager::checkBreakpoint(const Breakpoint::Data &bdata, bool onlyWarn, Address &address)
 {
   address = Address();
-  if ( _coff==0 ) return true;
+  if ( _coff==NULL ) return true;
   QValueVector<Address> addresses = _coff->addresses(bdata.url, bdata.line);
   if ( addresses.isEmpty() ) {
     QString s = i18n("Breakpoint at non-code line.");
@@ -162,14 +168,14 @@ bool Debugger::Manager::checkBreakpoint(const Breakpoint::Data &bdata, bool only
 
 void Debugger::Manager::computeBreakpointAddresses()
 {
-  if ( programmerGroup()==0 ) return;
+  if ( programmerGroup()==NULL ) return;
   int nb = programmerGroup()->maxNbBreakpoints(deviceData());
   for (int i=Breakpoint::list().count()-1; i>=0; i--) {
     const Breakpoint::Data &data = Breakpoint::list().data(i);
     Address address;
     checkBreakpoint(data, true, address);
     Breakpoint::list().setAddress(data, address);
-    if ( _coff==0 ) Breakpoint::list().setState(data, Breakpoint::Unknown);
+    if ( _coff==NULL ) Breakpoint::list().setState(data, Breakpoint::Unknown);
     else if ( Breakpoint::list().address(data).isValid() && nb>0 ) {
       Breakpoint::list().setState(data, Breakpoint::Active);
       nb--;
@@ -191,9 +197,10 @@ void Debugger::Manager::clear()
 {
   _runTimer.stop();
   _stepTimer.stop();
-  if ( programmer() ) programmer()->clear();
+  if ( programmer() != NULL ) programmer()->clear();
   delete _coff;
-  _coff = 0;
+  _coff = NULL;
+  _inited = false;
   _currentSourceLines.clear();
   computeBreakpointAddresses();
   update(true);
@@ -233,7 +240,7 @@ bool Debugger::Manager::updateRegister(const Register::TypeData &data)
 
 bool Debugger::Manager::updateRegisters()
 {
-  if ( programmer()==0 || programmer()->state()!=Programmer::Halted ) return true;
+  if ( programmer()==NULL || programmer()->state()!=Programmer::Halted ) return true;
   QValueList<Register::TypeData> watched = Register::list().watched();
   for (uint i=0; i<uint(watched.count()); i++)
     if ( !updateRegister(watched[i]) ) return false;
