@@ -30,6 +30,7 @@ Q_OBJECT
 public:
   Manager();
   virtual ~Manager();
+  bool isInited() const { return _inited; }
   virtual PURL::Url coffUrl() const = 0;
   virtual const Programmer::Group *programmerGroup() const = 0;
   Programmer::Generic *programmer() const { return Programmer::manager->programmer(); }
@@ -80,8 +81,10 @@ private slots:
   bool doStep(bool first = false, bool continued = true);
 
 private:
+  bool                _inited;
   const Device::Data *_data;
-  QTimer _runTimer, _stepTimer;
+  QTimer              _runTimer;
+  QTimer              _stepTimer;
   QValueList<Register::TypeData> _readRegisters;
 
   void computeBreakpointAddresses();
