@@ -25,17 +25,18 @@ Programmer::Manager::Manager(QObject *parent)
 Programmer::Manager::~Manager()
 {
   delete _programmer;
+  _programmer = NULL;
 }
 
 void Programmer::Manager::clear()
 {
   delete _programmer;
-  _programmer = 0;
+  _programmer = NULL;
 }
 
 void Programmer::Manager::internalCreateProgrammer(const Device::Data *data, const HardwareDescription &hd)
 {
-  if ( _programmer && _programmer->device()==data && !hasError() ) return;
+  if (_programmer != NULL && _programmer->device() == data && !hasError()) return;
   delete _programmer;
   _programmer = group().createProgrammer(isTargetSelfPowered(), data, hd);
   _programmer->Log::Base::setParent(this);
@@ -54,7 +55,7 @@ bool Programmer::Manager::initProgramming(bool debugging, ProgramAction action)
 
 bool Programmer::Manager::internalInitProgramming(bool, ProgramAction)
 {
-  if ( device()==0 ) {
+  if ( device()==NULL ) {
     sorry(i18n("You need to specify the device for programming."));
     return false;
   }
@@ -166,8 +167,10 @@ bool Programmer::Manager::run()
 
 bool Programmer::Manager::halt()
 {
+  bool debugging = group().isDebugger();
+  if ( !initProgramming(debugging, ProgramAction::Halt) ) return false;
   bool ok;
-  if ( group().isDebugger() ) {
+  if (debugging) {
     ok = ::Debugger::manager->halt();
     setState(Idle);
   } else {
