@@ -21,7 +21,7 @@ class Group;
 class HardwareDescription;
 
 BEGIN_DECLARE_ENUM(ProgramAction)
-  ProgramOnly = 0, Run, Step
+  ProgramOnly = 0, Run, Step, Halt
 END_DECLARE_ENUM_NO_DATA(ProgramAction)
 
 class Manager : public QObject, public Log::Base
