@@ -109,7 +109,7 @@ bool Pickit2::USBPort::uploadFirmware(const Pic::Memory &memory, ProgressMonitor
 }
 
 //-----------------------------------------------------------------------------
-bool Pickit2::Hardware::readVoltages(VoltagesData &voltages)
+bool Pickit2::Hardware::readVoltages(Device::VoltageValues &voltages)
 {
   log(Log::DebugLevel::Extra, QString("readVoltages: Firmware is %1").arg(_base.firmwareVersion().pretty()));
   if ( _base.firmwareVersion()<VersionData(1, 20, 0) ) {
@@ -119,10 +119,8 @@ bool Pickit2::Hardware::readVoltages(VoltagesData &voltages)
   if ( !port().command('M') ) return false;
   Array a;
   if ( !port().receive(a) ) return false;
-  voltages[Pic::TargetVdd].value = double(a[1] + a[2]*256) * 5.0 / 65535;
-  voltages[Pic::TargetVpp].value = double(a[3] + a[4]*256) * (5.0 /65535) * (7.4 / 2.7);
-  voltages[Pic::TargetVdd].error = ( a[0] & 0x08 );
-  voltages[Pic::TargetVpp].error = ( a[0] & 0x10 );
+  voltages[Device::VoltageType::TargetVdd] = Device::VoltageValue(a[0] & 0x08 ? Device::VoltageValue::Error : Device::VoltageValue::Normal, double(a[1] + a[2]*256) * 5.0 / 65535);
+  voltages[Device::VoltageType::TargetVpp] = Device::VoltageValue(a[0] & 0x10 ? Device::VoltageValue::Error : Device::VoltageValue::Normal, double(a[3] + a[4]*256) * (5.0 /65535) * (7.4 / 2.7));
   return true;
 }
 
@@ -146,9 +144,9 @@ bool Pickit2::Hardware::setVddVpp(double vdd, double vpp)
   // wait until vpp is stabilized
   for (uint i=0; i<30; i++) {
     Port::usleep(50000);
-    VoltagesData voltages;
+    Device::VoltageValues voltages;
     if ( !readVoltages(voltages) ) return false;
-    if ( voltages[Pic::TargetVpp].value<(vpp+0.5) ) break;
+    if ( voltages[Device::VoltageType::TargetVpp].value()<(vpp+0.5) ) break;
   }
   return true;
 }
@@ -309,10 +307,11 @@ bool Pickit2::P18F::doEraseRange(Pic::MemoryRangeType type)
   return true;
 }
 
-bool Pickit2::P18F::doRead(Pic::MemoryRangeType type, Device::Array &data, const ::Programmer::VerifyData *vdata)
+bool Pickit2::P18F::doRead(Pic::MemoryRangeType type, uint wordOffset, Device::Array &data, const ::Programmer::VerifyData *vdata)
 {
+  Q_ASSERT( wordOffset==0 );
+  Q_ASSERT( data.count()==device().nbWords(type) );
   USBPort &port = static_cast<USBPort &>(hardware().port());
-  data.resize(device().nbWords(type));
   QValueVector<uint> words;
   switch (type.type()) {
     case Pic::MemoryRangeType::DeviceId:
@@ -367,13 +366,15 @@ bool Pickit2::P18F::doRead(Pic::MemoryRangeType type, Device::Array &data, const
   return false;
 }
 
-bool Pickit2::P18F::doWrite(Pic::MemoryRangeType type, const Device::Array &data, bool force)
+bool Pickit2::P18F::doWrite(Pic::MemoryRangeType type, uint wordOffset, const Device::Array &data, bool force)
 {
+  Q_ASSERT( wordOffset==0 );
+  Q_ASSERT( data.count()==device().nbWords(type) );
   Q_UNUSED(force);
   USBPort &port = static_cast<USBPort &>(hardware().port());
   switch (type.type()) {
     case Pic::MemoryRangeType::UserId: {
-      Pickit::Array cmd = port.createCommand(0x82, data.count() / 2, device().range(type).start.toUInt());
+      Pickit::Array cmd = port.createCommand(0x82, data.count()/2, device().range(type).start.toUInt());
       for (uint i=0; i<data.count(); i++) cmd[i + 5] = data[i].byte(0);
       return port.command(cmd);
     }
