@@ -32,10 +32,21 @@ bool Pickit2V2::Hardware::internalConnectHardware()
   return port().open();
 }
 
+bool Pickit2V2::Hardware::setVoltages(double vdd, const FamilyData &fdata)
+{
+  if ( !setVddOn(false) ) return false;
+  if ( !setVddVoltage(vdd, 0.85) ) return false;
+  double vpp = fdata.vpp;
+  if ( vpp==0.0 ) vpp = vdd;
+  if ( !setVppVoltage(vpp, 0.7) ) return false;
+  if ( !setVddOn(true) ) return false;
+  return true;
+}
+
 bool Pickit2V2::Hardware::setTarget()
 {
   //setIcspSpeed(0); // #### ??
-  _fastProgramming = true; // #### ??
+  //_fastProgramming = true; // #### ??
   uint checksum;
   if ( !getScriptBufferChecksum(checksum) ) return false;
   if ( !_deviceSet || _scriptBufferChecksum!=checksum ) {
@@ -93,6 +104,7 @@ bool Pickit2V2::Hardware::downloadScript(ScriptType type, uint i)
   cmd[1] = type;
   cmd[2] = sdata.length;
   for (uint k=0; k<sdata.length; k++) {
+/* ### not needed ???
     if ( !_fastProgramming && sdata.data[k]==0xAAE7 ) {
       ushort next = sdata.data[k+1];
       if ( (next & 0xFF)<170 && next!=0 ) {
@@ -113,7 +125,9 @@ bool Pickit2V2::Hardware::downloadScript(ScriptType type, uint i)
         cmd[3+k+1] = 0;
       }
       k++;
-    } else cmd[3+k] = sdata.data[k];
+    } else
+*/
+    cmd[3+k] = sdata.data[k];
   }
   return port().command(cmd);
 }
@@ -126,19 +140,19 @@ bool Pickit2V2::Hardware::downloadScripts()
   log(Log::DebugLevel::Extra, "download scripts");
   const Data &d = data(device().name());
   for (uint i=0; i<Nb_ScriptTypes; i++) {
-    if ( i==TestMemoryRead || i==ConfigErase ) continue; // ### to get same checksum as pk2cmd
+//    if ( i==TestMemoryRead || i==ConfigErase ) continue; // ### to get same checksum as pk2cmd
     if ( !downloadScript(ScriptType(i), d.scriptIndexes[i]) ) return false;
   }
   return getScriptBufferChecksum(_scriptBufferChecksum);
 }
 
-bool Pickit2V2::Hardware::setTargetReset(Pic::ResetMode mode)
+bool Pickit2V2::Hardware::setTargetReset(Device::ResetMode mode)
 {
   ushort script[1];
-  switch (mode) {
-    case Pic::ResetHeld: script[0] = MclrGroundOn; break;
-    case Pic::ResetReleased: script[0] = MclrGroundOff; break;
-    case Pic::Nb_ResetModes: Q_ASSERT(false); return false;
+  switch (mode.type()) {
+    case Device::ResetMode::Held: script[0] = MclrGroundOn; break;
+    case Device::ResetMode::Released: script[0] = MclrGroundOff; break;
+    case Device::ResetMode::Nb_Types: Q_ASSERT(false); return false;
   }
   return sendScript(script, 1);
 }
@@ -199,17 +213,15 @@ bool Pickit2V2::Hardware::getMode(VersionData &version, ::Programmer::Mode &mode
   return true;
 }
 
-bool Pickit2V2::Hardware::readVoltages(VoltagesData &voltagesData)
+bool Pickit2V2::Hardware::readVoltages(Device::VoltageValues &voltages)
 {
   if ( !port().command(ReadVoltages) ) return false;
   Array array;
   if ( !port().receive(array) ) return false;
   double vadc = 256 * array[1] + array[0];
-  voltagesData[Pic::TargetVdd].value = 5.0 * (vadc / 65536);
-  voltagesData[Pic::TargetVdd].error = false;
+  voltages[Device::VoltageType::TargetVdd] = Device::VoltageValue(Device::VoltageValue::Normal, 5.0 * (vadc / 65536));
   vadc = 256 * array[3] + array[2];
-  voltagesData[Pic::TargetVpp].value = 13.7 * (vadc / 65536);
-  voltagesData[Pic::TargetVpp].error = false;
+  voltages[Device::VoltageType::TargetVpp] = Device::VoltageValue(Device::VoltageValue::Normal, 13.7 * (vadc / 65536));
   return true;
 }
 
@@ -248,24 +260,24 @@ bool Pickit2V2::Hardware::runScript(ScriptType stype, uint repetitions, uint nbN
   for (uint i=0; i<nbNoLens; i++) cmd[4+i] = UploadDataNoLen;
   if ( !port().command(cmd) ) return false;
 #endif
-  if ( stype==ProgExit && !setTargetReset(Pic::ResetReleased) ) return false;
+  //if ( stype==ProgExit && !setTargetReset(Pic::ResetMode::Released) ) return false;
   return true;
 }
 
-bool Pickit2V2::Hardware::prepareRead(Pic::MemoryRangeType type, uint wordIndex)
+bool Pickit2V2::Hardware::prepareRead(Pic::MemoryRangeType type, uint wordOffset)
 {
   ScriptType stype = prepareReadScript(type);
   if ( type!=Pic::MemoryRangeType::Cal && (stype==Nb_ScriptTypes || data(device().name()).scriptIndexes[stype]==0) ) return true;
   switch (type.type()) {
   case Pic::MemoryRangeType::Code:
-    if ( !device().architecture().data().hasAddressAccess ) return true;
-    if ( !downloadAddress(0x10000 * (wordIndex / 0x8000)) ) return false;
+    if ( !device().architecture().data().properties & Pic::RandomMemoryAccess ) return true;
+    if ( !downloadAddress(0x10000 * (wordOffset / 0x8000)) ) return false;
     break;
-  case Pic::MemoryRangeType::Eeprom:
-    if ( device().nbBytesWord(Pic::MemoryRangeType::Eeprom)==4 ) {
-      if ( !downloadAddress(device().range(Pic::MemoryRangeType::Eeprom).start.toUInt()) ) return false; // #### correct ?
-    } else if ( !downloadAddress(0x0) ) return false;
+  case Pic::MemoryRangeType::Eeprom: {
+    Address address = (device().nbBytesWord(Pic::MemoryRangeType::Eeprom)==4 ? device().range(Pic::MemoryRangeType::Eeprom).start : 0x000000);
+    if ( !downloadAddress(address) ) return false;
     break;
+  }
   case Pic::MemoryRangeType::Config: return true; // ConfigPrepareRead unused (?)
   case Pic::MemoryRangeType::UserId: break;
   case Pic::MemoryRangeType::Cal: {
@@ -279,15 +291,15 @@ bool Pickit2V2::Hardware::prepareRead(Pic::MemoryRangeType type, uint wordIndex)
   return runScript(stype);
 }
 
-bool Pickit2V2::Hardware::readMemory(Pic::MemoryRangeType otype, Device::Array &data, const ::Programmer::VerifyData *vdata)
+bool Pickit2V2::Hardware::readMemory(Pic::MemoryRangeType otype, uint wordOffset, Device::Array &data, const ::Programmer::VerifyData *vdata)
 {
+  Q_ASSERT( wordOffset==0 );
+  Q_ASSERT( data.count()==device().nbWords(otype) );
   uint nbWords = device().nbWords(otype);
-  data.resize(nbWords);
   log(Log::DebugLevel::Max, QString("read %1 nbWords=%2").arg(otype.label()).arg(nbWords));
   uint nbBytesWord = device().nbBytesWord(otype);
   // EEPROM is read like regular program memory in midrange
   if ( !device().is18Family() && !device().is16bitFamily() && otype==Pic::MemoryRangeType::Eeprom ) nbBytesWord = 2;
-  uint wordOffset = 0;
   Pic::MemoryRangeType type = otype;
   if ( otype==Pic::MemoryRangeType::Config && device().range(Pic::MemoryRangeType::Config).start==device().range(Pic::MemoryRangeType::Code).end+1 ) {  // config in code memory
     wordOffset = device().range(Pic::MemoryRangeType::Config).start.toUInt();
@@ -301,18 +313,18 @@ bool Pickit2V2::Hardware::readMemory(Pic::MemoryRangeType otype, Device::Array &
   uint nbRuns = 1;
   uint nbReceive = (nbRunWords*nbBytesWord + 63) / 64;
   switch (type.type()) {
-    case Pic::MemoryRangeType::Code:   nbRuns = nbRunWords / Pickit2V2::data(device().name()).codeMemoryNbReadWords; break;
-    case Pic::MemoryRangeType::Eeprom: nbRuns = nbRunWords / Pickit2V2::data(device().name()).eepromMemoryNbReadWords; break;
+    case Pic::MemoryRangeType::Code:   nbRuns = nbRunWords / Pickit2V2::data(device().name()).codeReadNbWords; break;
+    case Pic::MemoryRangeType::Eeprom: nbRuns = nbRunWords / Pickit2V2::data(device().name()).eepromReadNbWords; break;
     default: break;
   }
 
   if ( !runScript(ProgEntry) ) return false;
+  QValueVector<uint> words;
   for (uint i=0; i<nbWords; ) {
     if (setAddress) {
       setAddress = false;
       if ( !prepareRead(type, wordOffset + i) ) return false;
     }
-    QValueVector<uint> words;
     if ( type==Pic::MemoryRangeType::Config || type==Pic::MemoryRangeType::Cal ) {
       if ( !runScript(stype, 1, 0) ) return false;
       if ( !port().command(UploadData) ) return false;
@@ -323,7 +335,7 @@ bool Pickit2V2::Hardware::readMemory(Pic::MemoryRangeType otype, Device::Array &
       if ( !port().receiveWords(nbBytesWord, nbReceive, words) ) return false;
     }
     log(Log::DebugLevel::Max, QString("nbRunWords=%1 readNbWords=%2 index=%3/%4").arg(nbRunWords).arg(words.count()).arg(i).arg(nbWords));
-    for (uint k=0; k<words.count(); k++) {
+    for (uint k=0; k<uint(words.count()); k++) {
       if ( i>=nbWords ) break;
       data[i] = words[k];
       if (fdata->progMemShift) data[i] >>= 1;
@@ -340,7 +352,7 @@ bool Pickit2V2::Hardware::readMemory(Pic::MemoryRangeType otype, Device::Array &
 bool Pickit2V2::Hardware::eraseAll()
 {
   const Data &d = data(device().name());
-  if ( d.scriptIndexes[ConfigErase]!=0 ) {
+  if ( d.scriptIndexes[ConfigErase]!=0 && d.rowEraseNbWords==0 ) {
     if ( !runScript(ProgEntry) ) return false;
     if ( d.scriptIndexes[ConfigWritePrepare]!=0 ) {
       if ( !downloadAddress(0) ) return false;
@@ -374,15 +386,29 @@ bool Pickit2V2::Hardware::eraseRange(Pic::MemoryRangeType type)
   return false;
 }
 
-bool Pickit2V2::Hardware::prepareWrite(Pic::MemoryRangeType type, uint wordIndex)
+bool Pickit2V2::Hardware::downloadData(const QValueVector<uint> &data, uint &index, bool clearBuffer)
+{
+  Q_ASSERT( index<data.count() );
+  Array cmd;
+  uint i = 0;
+  if (clearBuffer) { cmd[i] = ClearDownloadBuffer; i++; }
+  cmd[i] = DownloadData; i++;
+  uint length = QMIN(data.count()-index, 63-i);
+  cmd[i] = length; i++;
+  for (uint k=0; k<length; k++) cmd[i+k] = data[index+k];
+  index += length;
+  return port().command(cmd);
+}
+
+bool Pickit2V2::Hardware::prepareWrite(Pic::MemoryRangeType type, uint wordOffset)
 {
   ScriptType stype = prepareWriteScript(type);
   if ( stype==Nb_ScriptTypes || data(device().name()).scriptIndexes[stype]==0 ) return true;
   switch (type.type()) {
   case Pic::MemoryRangeType::Code:
   case Pic::MemoryRangeType::Config:
-    if ( !device().architecture().data().hasAddressAccess ) return true;
-    if ( !downloadAddress(0x10000 * (wordIndex / 0x8000)) ) return false;
+    if ( !device().architecture().data().properties & Pic::RandomMemoryAccess ) return true;
+    if ( !downloadAddress(0x10000 * (wordOffset / 0x8000)) ) return false;
     break;
   case Pic::MemoryRangeType::Eeprom: {
     Address address = (device().nbBytesWord(Pic::MemoryRangeType::Eeprom)==4 ? device().range(Pic::MemoryRangeType::Eeprom).start : 0x000000);
@@ -396,10 +422,80 @@ bool Pickit2V2::Hardware::prepareWrite(Pic::MemoryRangeType type, uint wordIndex
   return runScript(stype);
 }
 
-bool Pickit2V2::Hardware::writeMemory(Pic::MemoryRangeType otype, const Device::Array &data, bool force)
+bool Pickit2V2::Hardware::writeMemory(Pic::MemoryRangeType otype, uint wordOffset, const Device::Array &data, bool force)
 {
+  // ### FIXME: need to be fixed for 18J family (and for speed)
+  Q_ASSERT( wordOffset==0 );
+  Q_ASSERT( data.count()==device().nbWords(otype) );
   Q_UNUSED(force);
-  return false; // ### TODO
+
+  uint nbWords = device().nbWords(otype);
+  log(Log::DebugLevel::Max, QString("write %1 nbWords=%2").arg(otype.label()).arg(nbWords));
+  uint nbBytesWord = device().nbBytesWord(otype);
+  // EEPROM is read like regular program memory in midrange
+  if ( !device().is18Family() && !device().is16bitFamily() && otype==Pic::MemoryRangeType::Eeprom ) nbBytesWord = 2;
+  Pic::MemoryRangeType type = otype;
+  if ( otype==Pic::MemoryRangeType::Config && device().range(Pic::MemoryRangeType::Config).start==device().range(Pic::MemoryRangeType::Code).end+1 ) {  // config in code memory
+    wordOffset = device().range(Pic::MemoryRangeType::Config).start.toUInt();
+    type = Pic::MemoryRangeType::Code;
+  }
+  ScriptType stype = readScript(type);
+  Q_ASSERT( stype!=Nb_ScriptTypes );
+  bool setAddress = true;
+  const FamilyData *fdata = familyData(device());
+  uint nbWordsPerWrite = 1;
+  uint nbRuns = 1;
+  uint nbWordsDownload = nbWords;
+  switch (type.type()) {
+    case Pic::MemoryRangeType::Code:
+      nbWordsPerWrite = Pickit2V2::data(device().name()).codeWriteNbWords;
+      nbWordsDownload = DownloadBufferNbBytes / nbWordsPerWrite;
+      nbRuns = nbWordsDownload / nbBytesWord;
+      break;
+    case Pic::MemoryRangeType::Eeprom:
+      nbWordsPerWrite = Pickit2V2::data(device().name()).eepromWriteNbWords;
+      nbWordsDownload = QMAX(uint(16), nbWordsPerWrite);
+      nbRuns = nbWordsDownload / nbWordsPerWrite;
+      break;
+    default: break;
+  }
+  QValueVector<uint> ddata(nbWordsDownload * nbBytesWord);
+
+  if ( !runScript(ProgEntry) ) return false;
+  for (uint i=0; i<nbWords; ) {
+    if (setAddress) {
+      setAddress = false;
+      if ( !prepareWrite(type, i) ) return false;
+    }
+    uint di = 0;
+    for (uint j=0; j<nbWordsDownload; j++) {
+      if ( i>=nbWords ) break;
+      BitValue word = data[i];
+      if (fdata->progMemShift) word <<= 1;
+      for (uint k=0; k<nbBytesWord; k++) {
+        ddata[di] = word.byte(k);
+        di++;
+      }
+      if ( type==Pic::MemoryRangeType::Code && i!=0x0 && i%0x8000==0 ) setAddress = true;
+      i++;
+    }
+    if ( type==Pic::MemoryRangeType::Cal ) {
+      Q_ASSERT( ddata.count()==2 ); // calibration has 2 bytes
+      ddata.resize(5);
+      ddata[3] = ddata[0];
+      ddata[4] = ddata[1];
+      Address address = device().range(type).start;
+      ddata[0] = address.byte(0);
+      ddata[1] = address.byte(1);
+      ddata[2] = address.byte(2);
+    }
+    uint ri = 0;
+    while ( ri<di ) if ( !downloadData(ddata, ri, ri==0) ) return false;
+    if ( !runScript(stype, nbRuns) ) return false;
+  }
+
+  if ( !runScript(ProgExit) ) return false;
+  return true;
 }
 
 //-----------------------------------------------------------------------------
@@ -424,9 +520,3 @@ bool Pickit2V2::DeviceSpecific::canWriteRange(Pic::MemoryRangeType type) const
   if ( type==Pic::MemoryRangeType::Cal ) return d.scriptIndexes[OsccalWrite];
   return true;
 }
-
-bool Pickit2V2::DeviceSpecific::doWrite(Pic::MemoryRangeType type, const Device::Array &data, bool force)
-{
-  Q_ASSERT( data.size()==device().nbWords(type) );
-  return hardware().writeMemory(type, data, force);
-}
