@@ -28,11 +28,11 @@ void Tool::Group::init()
   delete _sourceGenerator;
   _sourceGenerator = sourceGeneratorFactory();
   FOR_EACH(Category, i) {
-    delete _bases[i].base;
+    delete _bases[i];
     _bases[i] = baseFactory(i);
-    if (_bases[i].base) {
-      _bases[i].base->_category = i;
-      _bases[i].base->_group = this;
+    if (_bases[i] != NULL) {
+      _bases[i]->_category = i;
+      _bases[i]->_group = this;
     }
   }
   ::Group::Base::init();
@@ -47,7 +47,7 @@ Compile::Process *Tool::Group::createCompileProcess(const Compile::Data &data, C
   return p;
 }
 
-Compile::Config *Tool::Group::createConfig(::Project *project) const
+Compile::Config *Tool::Group::createConfig(::Project& project) const
 {
   Compile::Config *c = configFactory(project);
   if (c) c->_group = this;
@@ -67,15 +67,15 @@ QString Tool::Group::defaultLinkerScriptFilename(Compile::LinkingType type, cons
   return basename + '.' + PURL::extension(PURL::Lkr);
 }
 
-bool Tool::Group::hasCustomLinkerScript(const ::Project *project) const
+bool Tool::Group::hasCustomLinkerScript(const ::Project& project) const
 {
-  return ( project && !project->customLinkerScript().isEmpty() );
+  return ( !project.customLinkerScript().isEmpty() );
 }
 
-PURL::Url Tool::Group::linkerScript(const ::Project *project, Compile::LinkingType type) const
+PURL::Url Tool::Group::linkerScript(const ::Project& project, Compile::LinkingType type) const
 {
-  if ( hasCustomLinkerScript(project) ) return project->customLinkerScript();
-  QString filename = defaultLinkerScriptFilename(type, Compile::Config::device(project));
+  if ( hasCustomLinkerScript(project) ) return project.customLinkerScript();
+  QString filename = defaultLinkerScriptFilename(type, Compile::Config::device(&project));
   return PURL::Url(Compile::Config::directory(*this, Compile::DirectoryType::LinkerScript), filename);
 }
 
@@ -93,11 +93,11 @@ bool Tool::Group::checkExecutable(Tool::Category category, QStringList &lines)
   PURL::Directory dir = Compile::Config::directory(*this, Compile::DirectoryType::Executable);
   ExecutableType execType = Compile::Config::executableType(*this);
   Tool::OutputExecutableType outputType = Compile::Config::outputExecutableType(*this);
-  ::Process::LineOutput * process = _bases[category].base->checkExecutableProcess(dir, execType, outputType);
+  ::Process::LineOutput * process = _bases[category]->checkExecutableProcess(dir, execType, outputType);
   ::Process::State state = ::Process::runSynchronously(*process, ::Process::Start, 10000);
   if ( state!=::Process::Exited ) return false;
   lines = process->allOutputs();
-  return _bases[category].base->checkExecutableResult(execType, lines);
+  return _bases[category]->checkExecutableResult(execType, lines);
 }
 
 void Tool::Group::initSupported()
@@ -133,10 +133,7 @@ bool Tool::Group::check(const QString &device, Log::Generic *log) const
   return true;
 }
 
-bool Tool::Group::needs(bool withProject, Tool::Category category) const
+bool Tool::Group::needs(Tool::Category category) const
 {
-  if ( _bases[category].base==0 ) return false;
-  if ( withProject && _bases[category].type==StandaloneOnly ) return false;
-  if ( !withProject && _bases[category].type==ProjectOnly ) return false;
-  return true;
+  return (_bases[category] != NULL);
 }
