@@ -48,7 +48,7 @@ public:
   bool isCustom() const { return ( name()==CUSTOM_NAME ); }
   virtual QString comment() const { return QString::null; }
   virtual void init();
-  virtual const ::Tool::Base *base(Category category) const { return _bases[category].base; }
+  virtual const ::Tool::Base *base(Category category) const { return _bases[category]; }
   virtual QString informationText() const = 0;
   virtual ExecutableType preferedExecutableType() const = 0;
   virtual bool hasDirectory(Compile::DirectoryType) const { return false; }
@@ -62,11 +62,11 @@ public:
   ::Process::LineOutput *checkDevicesProcess(uint i, const PURL::Directory &execDir, Tool::ExecutableType execType) const;
   virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const = 0;
   virtual CompileFileType compileFileType() const = 0;
-  virtual bool needs(bool withProject, Category category) const;
+  virtual bool needs(Category category) const;
   Compile::Process *createCompileProcess(const Compile::Data &data, Compile::Manager *manager) const;
-  Compile::Config *createConfig(::Project *project) const;
-  bool hasCustomLinkerScript(const ::Project *project) const;
-  virtual PURL::Url linkerScript(const ::Project *project, Compile::LinkingType type) const;
+  Compile::Config *createConfig(::Project& project) const;
+  bool hasCustomLinkerScript(const ::Project& project) const;
+  virtual PURL::Url linkerScript(const ::Project& project, Compile::LinkingType type) const;
   virtual PURL::FileType implementationType(PURL::ToolType type) const = 0;
   virtual Compile::Process *processFactory(const Compile::Data &data) const = 0;
   const SourceGenerator *sourceGenerator() const { return _sourceGenerator; }
@@ -74,28 +74,20 @@ public:
   const VersionData &version() const { return _version; }
   virtual bool generateCompleteDebugInfo(const QString &device) const { Q_UNUSED(device); return true; }
   virtual QString auxiliaryDebugInfoGenerator() const { return QString::null; }
+  virtual VersionData getToolchainVersion() { return VersionData(); }
 
 protected:
-  enum NeedType { StandaloneOnly, ProjectOnly, Both };
-  class BaseData {
-  public:
-    BaseData() : base(0), type(Both) {}
-    BaseData(::Tool::Base *b, NeedType t) : base(b), type(t) {}
-    ::Tool::Base *base;
-    NeedType type;
-  };
   virtual void initSupported();
-  virtual BaseData baseFactory(Category category) const = 0;
+  virtual ::Tool::Base* baseFactory(Category category) const = 0;
   virtual QString defaultLinkerScriptFilename(Compile::LinkingType type, const QString &device) const;
-  virtual Compile::Config *configFactory(::Project *project) const = 0;
+  virtual Compile::Config *configFactory(::Project& project) const = 0;
   virtual SourceGenerator *sourceGeneratorFactory() const = 0;
   bool checkExecutable(Tool::Category category, QStringList &lines);
-  virtual VersionData getToolchainVersion() { return VersionData(); }
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType type, const PURL::Directory &execDir, Tool::ExecutableType execType) const = 0;
 
 private:
   SourceGenerator *_sourceGenerator;
-  QMap<Category, BaseData> _bases;
+  QMap<Category, ::Tool::Base*> _bases;
   mutable QMap<Compile::DirectoryType, PURL::Directory> _dirs;
   bool _checkDevicesError;
   VersionData _version;
