@@ -8,12 +8,27 @@
  ***************************************************************************/
 #include "boost.h"
 
+#include <qregexp.h>
+
 #include "boostc_compile.h"
 #include "boost_config.h"
 #include "devices/pic/pic/pic_memory.h"
 #include "devices/list/device_list.h"
 #include "devices/base/device_group.h"
 
+//----------------------------------------------------------------------------
+QString Boost::Base::baseExecutable(Tool::ExecutableType, Tool::OutputExecutableType) const
+{
+  QString exec = execName();
+  if (static_cast<const Group*>(_group)->newExecutableNames()) {
+      int i = exec.find('.');
+      if (i !=-1) {
+          exec.replace(i, 1, "_");
+      }
+   }
+   return exec;
+}
+
 //----------------------------------------------------------------------------
 bool Boost::Linker::checkExecutableResult(Tool::ExecutableType, QStringList &lines) const
 {
@@ -57,7 +72,8 @@ PURL::Directory Boost::Compiler::checkExecutableWorkingDirectory() const
 
 //----------------------------------------------------------------------------
 Boost::Group::Group(const QString &extension, const QString &text)
-  : _checkExecTmp(_sview, extension)
+: _checkExecTmp(_sview, extension),
+  _newExecutableNames(false)
 {
   if ( _checkExecTmp.openForWrite() ) _checkExecTmp.appendText(text);
   _checkExecTmp.close();
@@ -85,7 +101,7 @@ Compile::Process *Boost::Group::processFactory(const Compile::Data &data) const
   return 0;
 }
 
-Compile::Config *Boost::Group::configFactory(::Project *project) const
+Compile::Config *Boost::Group::configFactory(::Project& project) const
 {
   return new Boost::Config(project);
 }
@@ -101,3 +117,20 @@ QValueList<const Device::Data *> Boost::Group::getSupportedDevices(const QString
   }
   return list;
 }
+
+VersionData Boost::Group::getToolchainVersion()
+{
+    QStringList lines;
+    for (uint i=0; i<2; ++i) {
+        _newExecutableNames = (i == 0);
+        if (checkExecutable(Tool::Category::Linker, lines)) {
+            QRegExp regexp("Boost.*Version\\s+([0-9]+)\\.([0-9]+).*");
+            for (uint i=0; i<lines.count(); ++i) {
+                if (regexp.exactMatch(lines[i])) {
+                    return VersionData(regexp.cap(1).toUInt(), regexp.cap(2).toUInt(), 0);
+                }
+            }
+        }
+    }
+    return VersionData(0, 0, 0);
+}
