@@ -16,10 +16,17 @@
 namespace Boost
 {
 //----------------------------------------------------------------------------
-class Linker : public Tool::Base
+class Base : public Tool::Base
 {
 private:
-  virtual QString baseExecutable(Tool::ExecutableType, Tool::OutputExecutableType) const { return "boostlink.pic.exe"; }
+  virtual QString baseExecutable(Tool::ExecutableType, Tool::OutputExecutableType) const;
+  virtual QString execName() const = 0;
+};
+
+class Linker : public Base
+{
+private:
+  virtual QString execName() const { return "boostlink.pic.exe"; }
   virtual bool checkExecutableResult(Tool::ExecutableType execType, QStringList &lines) const;
   virtual PURL::Directory checkExecutableWorkingDirectory() const;
 };
@@ -37,7 +44,7 @@ private:
 };
 
 //----------------------------------------------------------------------------
-class Compiler : public Tool::Base
+class Compiler : public Base
 {
 private:
   virtual QStringList checkExecutableOptions(Tool::ExecutableType execType) const;
@@ -50,6 +57,7 @@ class Group : public Tool::Group
 public:
   Group(const QString &extension, const QString &text);
   PURL::Url checkExecutableUrl() const { return _checkExecTmp.url(); }
+  bool newExecutableNames() const { return _newExecutableNames; }
   virtual QString comment() const;
   virtual Tool::Category checkDevicesCategory() const { return Tool::Category::Nb_Types; }
   virtual Tool::ExecutableType preferedExecutableType() const { return Tool::ExecutableType::Windows; }
@@ -62,11 +70,13 @@ protected:
 private:
   Log::StringView _sview;
   PURL::TempFile  _checkExecTmp;
+  bool            _newExecutableNames;
 
   virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const;
   virtual Compile::Process *processFactory(const Compile::Data &data) const;
-  virtual Compile::Config *configFactory(::Project *project) const;
+  virtual Compile::Config *configFactory(::Project& project) const;
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType type, const PURL::Directory &execDir, Tool::ExecutableType execType) const;
+  virtual VersionData getToolchainVersion();
 };
 
 } // namespace
