@@ -16,7 +16,7 @@ namespace Boost
 class Config : public Compile::Config
 {
 public:
-  Config(Project *project) : Compile::Config(project) {}
+  Config(Project& project) : Compile::Config(&project) {}
 };
 
 } // namespace
