@@ -27,16 +27,16 @@ Tool::SourceGenerator *Boost::GroupBasic::sourceGeneratorFactory() const
   return new BasicSourceGenerator;
 }
 
-Tool::Group::BaseData Boost::GroupBasic16::baseFactory(Tool::Category category) const
+Tool::Base* Boost::GroupBasic16::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new Boost::CompilerBasic16, Both);
-  if ( category==Tool::Category::Linker )   return BaseData(new Boost::Linker16, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new Boost::CompilerBasic16;
+  if ( category==Tool::Category::Linker )   return new Boost::Linker16;
+  return NULL;
 }
 
-Tool::Group::BaseData Boost::GroupBasic18::baseFactory(Tool::Category category) const
+Tool::Base* Boost::GroupBasic18::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Linker )   return BaseData(new Boost::Linker18, Both);
-  if ( category==Tool::Category::Compiler ) return BaseData(new Boost::CompilerBasic18, Both);
-  return BaseData();
+  if ( category==Tool::Category::Linker )   return new Boost::Linker18;
+  if ( category==Tool::Category::Compiler ) return new Boost::CompilerBasic18;
+  return NULL;
 }
