@@ -23,13 +23,13 @@ private:
 class CompilerBasic16 : public CompilerBasic
 {
 public:
-  virtual QString baseExecutable(Tool::ExecutableType, Tool::OutputExecutableType) const { return "boostbasic.pic16.exe"; }
+  virtual QString execName() const { return "boostbasic.pic16.exe"; }
 };
 
 class CompilerBasic18 : public CompilerBasic
 {
 public:
-  virtual QString baseExecutable(Tool::ExecutableType, Tool::OutputExecutableType) const { return "boostbasic.pic18.exe"; }
+  virtual QString execName() const { return "boostbasic.pic18.exe"; }
 };
 
 //----------------------------------------------------------------------------
@@ -51,7 +51,7 @@ public:
   virtual QString label() const { return i18n("BoostBasic Compiler for PIC16"); }
 
 private:
-  virtual BaseData baseFactory(Tool::Category) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category) const;
   virtual bool supportedArchitecture(Pic::Architecture architecture) const { return ( architecture==Pic::Architecture::P16X ); }
 };
 
@@ -62,7 +62,7 @@ public:
   virtual QString label() const { return i18n("BoostBasic Compiler for PIC18"); }
 
 private:
-  virtual BaseData baseFactory(Tool::Category) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category) const;
   virtual bool supportedArchitecture(Pic::Architecture architecture) const
     { return ( architecture==Pic::Architecture::P18C || architecture==Pic::Architecture::P18F || architecture==Pic::Architecture::P18J ); }
 };
