@@ -28,16 +28,16 @@ Tool::SourceGenerator *Boost::GroupCpp::sourceGeneratorFactory() const
   return new CSourceGenerator;
 }
 
-Tool::Group::BaseData Boost::GroupCpp16::baseFactory(Tool::Category category) const
+Tool::Base* Boost::GroupCpp16::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new Boost::CompilerCpp16, Both);
-  if ( category==Tool::Category::Linker )   return BaseData(new Boost::Linker16, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new Boost::CompilerCpp16;
+  if ( category==Tool::Category::Linker )   return new Boost::Linker16;
+  return NULL;
 }
 
-Tool::Group::BaseData Boost::GroupCpp18::baseFactory(Tool::Category category) const
+Tool::Base* Boost::GroupCpp18::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new Boost::CompilerCpp18, Both);
-  if ( category==Tool::Category::Linker )   return BaseData(new Boost::Linker18, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new Boost::CompilerCpp18;
+  if ( category==Tool::Category::Linker )   return new Boost::Linker18;
+  return NULL;
 }
