@@ -69,16 +69,16 @@ PURL::Directory C18::Group::internalAutodetectDirectory(Compile::DirectoryType t
   return PURL::Directory();
 }
 
-Compile::Config *C18::Group::configFactory(::Project *project) const
+Compile::Config *C18::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
 
-Tool::Group::BaseData C18::Group::baseFactory(Tool::Category category) const
+Tool::Base* C18::Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new Compiler, Both);
-  if ( category==Tool::Category::Linker )   return BaseData(new Linker, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new Compiler;
+  if ( category==Tool::Category::Linker )   return new Linker;
+  return NULL;
 }
 
 QString C18::Group::informationText() const
