@@ -51,9 +51,9 @@ public:
 private:
   virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const;
   virtual Compile::Process *processFactory(const Compile::Data &data) const;
-  virtual Compile::Config *configFactory(::Project *project) const;
-  virtual BaseData baseFactory(Tool::Category category) const;
-  virtual Tool::SourceGenerator *sourceGeneratorFactory() const { /*TODO*/ return 0; }
+  virtual Compile::Config *configFactory(::Project& project) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category category) const;
+  virtual Tool::SourceGenerator *sourceGeneratorFactory() const { /*TODO*/ return NULL; }
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType type, const PURL::Directory &execDir, Tool::ExecutableType execType) const;
 };
 
