@@ -17,7 +17,7 @@ namespace C18
 class Config : public Compile::Config
 {
 public:
-  Config(Project *project) : Compile::Config(project) {}
+  Config(Project& project) : Compile::Config(&project) {}
   enum { Nb_WarningLevels = 3 };
   static const char * const WARNING_LEVEL_LABELS[Nb_WarningLevels];
   uint warningLevel() const { return QMIN(Compile::Config::warningLevel(Tool::Category::Compiler), uint(Nb_WarningLevels)); }
