@@ -12,8 +12,9 @@
 #include "tools/c18/c18_config.h"
 
 //----------------------------------------------------------------------------
-C18::ConfigWidget::ConfigWidget(Project *project)
-  : ToolConfigWidget(project), _warningLevel(0)
+C18::ConfigWidget::ConfigWidget(Project& project)
+: ToolConfigWidget(project),
+  _warningLevel(0)
 {}
 
 void C18::ConfigWidget::initEntries()
