@@ -20,7 +20,7 @@ Q_OBJECT
 protected:
   virtual QString deviceName() const { return QString::null; }
   virtual QStringList genericArguments(const Compile::Config &config) const;
-  virtual void logStderrLine(const QString &line);
+  virtual void logLine(::Process::OutputType type, const QString &line);
   virtual QString outputFiles() const;
 };
 
