@@ -9,7 +9,7 @@
 #include "cc5x_ui.h"
 
 //----------------------------------------------------------------------------
-CC5X::ConfigWidget::ConfigWidget(Project *project)
+CC5X::ConfigWidget::ConfigWidget(Project& project)
   : ToolConfigWidget(project)
 {}
 
