@@ -81,7 +81,7 @@ Compile::Process *CCSC::Group::processFactory(const Compile::Data &data) const
   return 0;
 }
 
-Compile::Config *CCSC::Group::configFactory(::Project *project) const
+Compile::Config *CCSC::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
@@ -91,10 +91,10 @@ QString CCSC::Group::informationText() const
   return i18n("<a href=\"%1\">CCS Compiler</a> is a C compiler distributed by CCS.").arg("http://www.ccsinfo.com/content.php?page=compilers");
 }
 
-Tool::Group::BaseData CCSC::Group::baseFactory(Tool::Category category) const
+Tool::Base* CCSC::Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new CCSC::Base, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new CCSC::Base;
+  return NULL;
 }
 
 VersionData CCSC::Group::getToolchainVersion()
