@@ -46,9 +46,9 @@ private:
 
   virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const;
   virtual Compile::Process *processFactory(const Compile::Data &data) const;
-  virtual Compile::Config *configFactory(::Project *project) const;
-  virtual BaseData baseFactory(Tool::Category) const;
-  virtual Tool::SourceGenerator *sourceGeneratorFactory() const { /*TODO*/ return 0; }
+  virtual Compile::Config *configFactory(::Project& project) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category) const;
+  virtual Tool::SourceGenerator *sourceGeneratorFactory() const { /*TODO*/ return NULL; }
   virtual VersionData getToolchainVersion();
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType, const PURL::Directory &, Tool::ExecutableType) const { return PURL::Directory(); }
 };
