@@ -21,7 +21,7 @@ protected:
   virtual QString deviceName() const { return QString::null; }
   virtual QString familyName() const;
   virtual QStringList genericArguments(const Compile::Config &config) const;
-  virtual void logStderrLine(const QString &line);
+  virtual void logLine(::Process::OutputType type, const QString &line);
   virtual QString outputFiles() const;
   virtual PURL::Url url(PURL::FileType type = PURL::Nb_FileTypes, uint i = 0) const;
 
