@@ -13,11 +13,10 @@
 
 QValueList<const Device::Data *> CustomTool::Group::getSupportedDevices(const QString &) const
 {
-  QValueVector<QString> devices = Device::lister().supportedDevices();
   QValueList<const Device::Data *> list;
-  for (uint i=0; i<devices.count(); i++) {
-    const Device::Data *data = Device::lister().data(devices[i]);
-    list.append(data);
-  }
+  QStringList devices = Device::lister().supportedDevices();
+  QStringList::const_iterator it;
+  for (it=devices.begin(); it!=devices.end(); ++it)
+    list.append(Device::lister().data(*it));
   return list;
 }
