@@ -26,11 +26,11 @@ public:
   virtual PURL::FileType implementationType(PURL::ToolType) const { return PURL::Nb_FileTypes; }
 
 protected:
-  virtual BaseData baseFactory(Tool::Category) const { return BaseData(); }
-  virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const;
-  virtual Compile::Process *processFactory(const Compile::Data &) const { return 0; }
-  virtual Compile::Config *configFactory(::Project *) const { return 0; }
-  virtual Tool::SourceGenerator *sourceGeneratorFactory() const { return 0; }
+  virtual ::Tool::Base* baseFactory(Tool::Category) const { return NULL; }
+  virtual QValueList<const Device::Data*> getSupportedDevices(const QString &s) const;
+  virtual Compile::Process* processFactory(const Compile::Data &) const { return NULL; }
+  virtual Compile::Config* configFactory(::Project&) const { return NULL; }
+  virtual Tool::SourceGenerator *sourceGeneratorFactory() const { return NULL; }
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType, const PURL::Directory &, Tool::ExecutableType) const { return PURL::Directory(); }
 };
 
