@@ -28,28 +28,6 @@ void GPUtils::AssembleFile::logLine(::Process::OutputType, const QString &line)
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
-//-----------------------------------------------------------------------------
-QStringList GPUtils::AssembleStandaloneFile::genericArguments(const Compile::Config &config) const
-{
-  QStringList args;
-  args += "-L"; // force list
-  args += "-o%O";
-  uint wl = static_cast<const Config &>(config).gpasmWarningLevel();
-  if ( wl!=Config::Nb_WarningLevels ) args += "-w" + QString::number(wl);
-  args += config.includeDirs(Tool::Category::Assembler, "-I");
-  args += "-p%DEVICE";
-  HexBuffer::Format format = config.hexFormat();
-  if( format!=HexBuffer::Nb_Formats ) args += QString("-a") + HexBuffer::FORMATS[format];
-  args += config.customOptions(Tool::Category::Assembler);
-  args += "%I";
-  return args;
-}
-
-QString GPUtils::AssembleStandaloneFile::outputFiles() const
-{
-  return "PURL::Lst PURL::Cod PURL::Hex";
-}
-
 //-----------------------------------------------------------------------------
 QStringList GPUtils::AssembleProjectFile::genericArguments(const Compile::Config &config) const
 {
