@@ -13,7 +13,7 @@
 #include "tools/gputils/gputils_config.h"
 
 //----------------------------------------------------------------------------
-GPUtils::ConfigWidget::ConfigWidget(Project *project)
+GPUtils::ConfigWidget::ConfigWidget(Project& project)
   : ToolConfigWidget(project), _gpasmWarning(0)
 {}
 
@@ -30,7 +30,6 @@ void GPUtils::ConfigWidget::initEntries()
     _gpasmWarning->insertItem(i18n("as in LIST directive"));
     container()->addWidget(_gpasmWarning, row,row, 1,1);
     createIncludeDirectoriesEntry();
-    if ( _project==0 ) createHexFormatEntry();
   }
   if ( _category==Tool::Category::Linker ) {
     createHexFormatEntry();
