@@ -24,7 +24,7 @@ const char * const ToolConfigWidget::ARGUMENTS_TYPE_LABELS[Nb_ArgumentsTypes] =
   I18N_NOOP("Automatic"), I18N_NOOP("Custom")
 };
 
-ToolConfigWidget::ToolConfigWidget(Project *project)
+ToolConfigWidget::ToolConfigWidget(Project& project)
   : ::ConfigWidget(0), _group(0), _project(project),
     _customOptions(0), _customLibraries(0), _includeDirs(0), _hexFormat(0),
     _config(0), _tmpConfig(0), _process(0), _tmpProject(0)
@@ -46,7 +46,7 @@ ToolConfigWidget::ToolConfigWidget(Project *project)
   _arguments->setReadOnly(true);
   container->addWidget(_arguments, 1,1, 1,2);
   KPushButton *button = new KPushButton(KGuiItem(QString::null, "help"), container);
-  connect(button, SIGNAL(clicked()), SIGNAL(displayHelp()));
+  connect(button, SIGNAL(clicked()), SLOT(displayHelpSlot()));
   container->addWidget(button, 1,1, 3,3);
   _argumentsEditor = new EditListBox(1, container, "arguments_editor", EditListBox::DuplicatesAllowed,
                                      EditListBox::Add | EditListBox::Remove | EditListBox::UpDown | EditListBox::RemoveAll | EditListBox::Reset);
@@ -67,7 +67,7 @@ void ToolConfigWidget::init(Tool::Category category, const Tool::Group &group)
   _group = &group;
   _config = _group->createConfig(_project);
   _tmpProject = new Project(PURL::Url());
-  _tmpConfig = _group->createConfig(_tmpProject);
+  _tmpConfig = _group->createConfig(*_tmpProject);
   Compile::Data data(_category, QValueList<Compile::Item>(), QString::null, _project, Compile::NormalLinking, Compile::Build);
   _process = _group->createCompileProcess(data, 0);
 
@@ -86,7 +86,7 @@ ToolConfigWidget::~ToolConfigWidget()
 PURL::DirectoriesWidget *ToolConfigWidget::createDirectoriesEntry(const QString &text)
 {
   uint row = container()->numRows();
-  PURL::DirectoriesWidget *sdw = new PURL::DirectoriesWidget(text, _project ? _project->directory().path() : QString::null, container());
+  PURL::DirectoriesWidget *sdw = new PURL::DirectoriesWidget(text, _project.directory().path(), container());
   connect(sdw, SIGNAL(changed()), SIGNAL(changed()));
   container()->addWidget(sdw, row,row, 0,2);
   return sdw;
@@ -179,3 +179,8 @@ void ToolConfigWidget::updateArguments()
   }
   _arguments->setText(arguments(type).join(" "));
 }
+
+void ToolConfigWidget::displayHelpSlot()
+{
+  emit displayHelp(_category);
+}
