@@ -28,13 +28,13 @@ class ToolConfigWidget : public ::ConfigWidget
 {
 Q_OBJECT
 public:
-  ToolConfigWidget(Project *project);
+  ToolConfigWidget(Project& project);
   void init(Tool::Category category, const Tool::Group &group);
   virtual ~ToolConfigWidget();
 
 signals:
   void changed();
-  void displayHelp();
+  void displayHelp(Tool::Category category);
 
 public slots:
   virtual void loadConfig();
@@ -43,11 +43,12 @@ public slots:
 private slots:
   void updateArguments();
   void resetCustomArguments();
+  void displayHelpSlot();
 
 protected:
   const Tool::Group *_group;
   Tool::Category _category;
-  Project       *_project;
+  Project&       _project;
   QLineEdit     *_customOptions, *_customLibraries;
   PURL::DirectoriesWidget *_includeDirs;
   QComboBox     *_hexFormat;
