@@ -10,13 +10,15 @@
 
 #include "tool_config_widget.h"
 #include "toolchain_config_widget.h"
+#include "tools/list/tool_list.h"
 
+//----------------------------------------------------------------------------
 ToolchainConfigWidget *Tool::GroupUI::toolchainConfigWidgetFactory(QWidget *parent) const
 {
-  return new ToolchainConfigWidget(static_cast<const Group &>(group()), parent);
+  return new ToolchainConfigWidget(static_cast<Group&>(group()), parent);
 }
 
-ToolConfigWidget *Tool::GroupUI::createConfigWidget(Category category, ::Project *project) const
+ToolConfigWidget *Tool::GroupUI::createConfigWidget(Category category, ::Project& project) const
 {
   ToolConfigWidget *cw = configWidgetFactory(category, project);
   Q_ASSERT(cw);
