@@ -17,11 +17,12 @@ class ToolchainConfigWidget;
 namespace Tool
 {
 
+//----------------------------------------------------------------------------
 class GroupUI : public ::Group::BaseGui
 {
 public:
-  ToolConfigWidget *createConfigWidget(Category category, ::Project *project) const;
-  virtual ToolConfigWidget *configWidgetFactory(Category category, ::Project *project) const = 0;
+  ToolConfigWidget *createConfigWidget(Category category, ::Project& project) const;
+  virtual ToolConfigWidget *configWidgetFactory(Category category, ::Project& project) const = 0;
   virtual ToolchainConfigWidget *toolchainConfigWidgetFactory(QWidget *parent) const;
 };
 
