@@ -20,6 +20,7 @@
 #include "toolchain_config_widget.h"
 #include "tool_group_ui.h"
 
+//-----------------------------------------------------------------------------
 ToolchainsConfigCenter::ToolchainsConfigCenter(const Tool::Group &sgroup, QWidget *parent)
   : TreeListDialog(parent, "configure_toolchains_dialog", true,
                    i18n("Configure Toolchains"), Ok|User1|User2|Cancel, Cancel, false)
@@ -34,8 +35,9 @@ ToolchainsConfigCenter::ToolchainsConfigCenter(const Tool::Group &sgroup, QWidge
 
   QWidget *current = 0;
   FOR_EACH(PURL::SourceFamily, family) {
-    Tool::Lister::ConstIterator it;
-    for (it=Tool::lister().begin(); it!=Tool::lister().end(); ++it) {
+    for (Tool::Lister::ConstIterator it = Tool::Lister::instance().begin();
+         it != Tool::Lister::instance().end();
+         ++it) {
       PURL::FileType type = it.data()->implementationType(family.data().toolType);
       if ( type==PURL::Nb_FileTypes || type.data().sourceFamily!=family ) continue;
       if ( family==PURL::SourceFamily::Asm && it.data()->implementationType(PURL::ToolType::Compiler)!=PURL::Nb_FileTypes ) continue;
