@@ -22,16 +22,17 @@
 #include "common/gui/container.h"
 
 //----------------------------------------------------------------------------
-ToolchainConfigWidget::ToolchainConfigWidget(const Tool::Group &group, QWidget *parent)
+ToolchainConfigWidget::ToolchainConfigWidget(Tool::Group &group, QWidget *parent)
   : ::ConfigWidget(parent),
     _group(group), _dirty(false), _outputType(0), _devicesData(group.nbCheckDevices())
 {
-  _config = group.createConfig(0);
+  _config = group.createConfig(*Main::project());
 }
 
 ToolchainConfigWidget::~ToolchainConfigWidget()
 {
   delete _config;
+  _config = NULL;
 }
 
 void ToolchainConfigWidget::init()
@@ -50,7 +51,7 @@ void ToolchainConfigWidget::init()
 
   label = new QLabel(i18n("Executable Type:"), container);
   container->addWidget(label, row,row, 0,0);
-  _execType = new KeyComboBox<Tool::ExecutableType>(container);
+  _execType.reset(new KeyComboBox<Tool::ExecutableType>(container));
   FOR_EACH(Tool::ExecutableType, type) _execType->appendItem(type, type.label());
   connect(_execType->widget(), SIGNAL(activated(int)), SLOT(forceDetect()));
   container->addWidget(_execType->widget(), row,row, 1,2);
@@ -62,7 +63,7 @@ void ToolchainConfigWidget::init()
   if ( nbOutputTypes>1 ) {
     label = new QLabel(i18n("Output Executable Type:"), container);
     container->addWidget(label, row,row, 0,0);
-    _outputType = new KeyComboBox<Tool::OutputExecutableType>(container);
+    _outputType.reset(new KeyComboBox<Tool::OutputExecutableType>(container));
     FOR_EACH(Tool::OutputExecutableType, type)
       if ( _group.hasOutputExecutableType(type) ) _outputType->appendItem(type, type.label());
     connect(_outputType->widget(), SIGNAL(activated(int)), SLOT(forceDetect()));
@@ -123,7 +124,7 @@ void ToolchainConfigWidget::loadConfig()
   _execType->widget()->blockSignals(true);
   _execType->setCurrentItem(Compile::Config::executableType(_group));
   _execType->widget()->blockSignals(false);
-  if (_outputType) {
+  if (_outputType.get() != NULL) {
     _outputType->widget()->blockSignals(true);
     _outputType->setCurrentItem(Compile::Config::outputExecutableType(_group));
     _outputType->widget()->blockSignals(false);
@@ -140,7 +141,7 @@ void ToolchainConfigWidget::loadConfig()
 void ToolchainConfigWidget::saveConfig()
 {
   Compile::Config::setExecutableType(_group, executableType());
-  if (_outputType) Compile::Config::setOutputExecutableType(_group, outputType());
+  if (_outputType.get() != NULL) Compile::Config::setOutputExecutableType(_group, outputType());
   FOR_EACH(Compile::DirectoryType, type)
     if ( _dirs[type] ) Compile::Config::setDirectory(_group, type, _dirs[type]->directory());
 }
@@ -195,7 +196,7 @@ Tool::ExecutableType ToolchainConfigWidget::executableType() const
 
 Tool::OutputExecutableType ToolchainConfigWidget::outputType() const
 {
-  return (_outputType==0 ? Compile::Config::outputExecutableType(_group) : _outputType->currentItem());
+  return (_outputType.get() == NULL ? Compile::Config::outputExecutableType(_group) : _outputType->currentItem());
 }
 
 QString ToolchainConfigWidget::baseExecutable(Tool::Category category) const
@@ -218,6 +219,10 @@ QString ToolchainConfigWidget::baseExecutable(Tool::Category category) const
 void ToolchainConfigWidget::detect()
 {
   if ( !_dirty ) return;
+  _dirty = false;
+
+  _group.getToolchainVersion();
+
   FOR_EACH(Tool::Category, k) {
     if ( _data[k].label==0 ) continue;
     if ( !_group.base(k)->checkExecutable() ) _data[k].label->setText(i18n("Unknown"));
@@ -233,6 +238,7 @@ void ToolchainConfigWidget::detect()
       else _data[k].label->setText(i18n("Detecting \"%1\"...").arg(exec));
     }
   }
+
   if ( _group.checkDevicesCategory()==Tool::Category::Nb_Types ) {
     QStringList supported = _group.supportedDevices();
     _devicesLabel->setText(i18n("Hardcoded (%1)").arg(supported.count()));
@@ -249,13 +255,13 @@ void ToolchainConfigWidget::detect()
       else _devicesLabel->setText(i18n("Detecting ..."));
     }
   }
+
   FOR_EACH(Compile::DirectoryType, type) {
     if ( _dirs[type]==0 || type==Compile::DirectoryType::Executable ) continue;
     PURL::Directory execDir = _dirs[Compile::DirectoryType::Executable]->directory();
     PURL::Directory dir = _group.autodetectDirectory(type, execDir, executableType());
     if ( !dir.isEmpty() ) _dirs[type]->setDirectory(dir);
   }
-  _dirty = false;
 }
 
 void ToolchainConfigWidget::showDetails()
