@@ -9,6 +9,8 @@
 #ifndef TOOLCHAIN_CONFIG_WIDGET_H
 #define TOOLCHAIN_CONFIG_WIDGET_H
 
+#include <memory>
+
 #include <qwidgetstack.h>
 #include <qlabel.h>
 #include <kpushbutton.h>
@@ -26,9 +28,9 @@ class ToolchainConfigWidget : public ::ConfigWidget
 {
   Q_OBJECT
 public:
-  ToolchainConfigWidget(const Tool::Group &group, QWidget *parent);
+  ToolchainConfigWidget(Tool::Group &group, QWidget *parent);
   virtual ~ToolchainConfigWidget();
-  const Tool::Group &group() const { return _group; }
+  Tool::Group &group() const { return _group; }
   void init();
 
 public slots:
@@ -52,11 +54,11 @@ protected slots:
   void checkDevicesDone();
 
 protected:
-  const Tool::Group &_group;
-  Compile::Config   *_config;
-  bool               _dirty;
-  KeyComboBox<Tool::ExecutableType>       *_execType;
-  KeyComboBox<Tool::OutputExecutableType> *_outputType;
+  Tool::Group&     _group;
+  Compile::Config* _config;
+  bool             _dirty;
+  std::auto_ptr<KeyComboBox<Tool::ExecutableType> > _execType;
+  std::auto_ptr<KeyComboBox<Tool::OutputExecutableType> > _outputType;
   QLabel            *_devicesLabel;
   QMap<Compile::DirectoryType, PURL::DirectoryWidget *> _dirs;
   class ExecData {
