@@ -9,6 +9,6 @@
 #include "jal_ui.h"
 
 //----------------------------------------------------------------------------
-JAL::ConfigWidget::ConfigWidget(Project *project)
+JAL::ConfigWidget::ConfigWidget(Project& project)
   : ToolConfigWidget(project)
 {}
