@@ -31,10 +31,10 @@ QString JAL::Group::informationText() const
   return i18n("<a href=\"%1\">JAL</a> is a high-level language for PIC microcontrollers.").arg("http://jal.sourceforge.net");
 }
 
-Tool::Group::BaseData JAL::Group::baseFactory(Tool::Category category) const
+Tool::Base* JAL::Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new ::JAL::Base, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new ::JAL::Base;
+  return NULL;
 }
 
 const char * const SUPPORTED_DEVICES[] = {
@@ -61,7 +61,7 @@ Compile::Process *JAL::Group::processFactory(const Compile::Data &data) const
   return new CompileFile;
 }
 
-Compile::Config *JAL::Group::configFactory(::Project *project) const
+Compile::Config *JAL::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
