@@ -38,10 +38,10 @@ public:
   virtual QString auxiliaryDebugInfoGenerator() const { return "gputils"; }
 
 private:
-  virtual BaseData baseFactory(Tool::Category c) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category c) const;
   virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const;
   virtual Compile::Process *processFactory(const Compile::Data &data) const;
-  virtual Compile::Config *configFactory(::Project *project) const;
+  virtual Compile::Config *configFactory(::Project& project) const;
   virtual Tool::SourceGenerator *sourceGeneratorFactory() const;
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType, const PURL::Directory &, Tool::ExecutableType) const { return PURL::Directory(); }
 };
