@@ -8,7 +8,7 @@
  ***************************************************************************/
 #include "jal_compile.h"
 
-void JAL::CompileFile::logStderrLine(const QString &line)
+void JAL::CompileFile::logLine(::Process::OutputType, const QString &line)
 {
   if ( line.contains('\r') ) return; // what are those lines ?
   // #### TODO
