@@ -31,10 +31,10 @@ QString JALV2::Group::informationText() const
   return i18n("<a href=\"%1\">JAL V2</a> is a new compiler for the high-level language JAL.").arg("http://www.casadeyork.com/jalv2");
 }
 
-Tool::Group::BaseData JALV2::Group::baseFactory(Tool::Category category) const
+Tool::Base* JALV2::Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new ::JALV2::Base, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new ::JALV2::Base;
+  return NULL;
 }
 
 const char * const SUPPORTED_DEVICES[] = {
@@ -66,7 +66,7 @@ Compile::Process *JALV2::Group::processFactory(const Compile::Data &data) const
   return new CompileFile;
 }
 
-Compile::Config *JALV2::Group::configFactory(::Project *project) const
+Compile::Config *JALV2::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
