@@ -18,7 +18,7 @@ class CompileFile : public Compile::Process
 Q_OBJECT
 protected:
   virtual QString deviceName() const { return _data.device; }
-  virtual void logStderrLine(const QString &line);
+  virtual void logLine(::Process::OutputType type, const QString &line);
   virtual QStringList genericArguments(const Compile::Config &config) const;
   virtual QString outputFiles() const;
 };
