@@ -17,7 +17,7 @@ namespace JALV2
 class Config : public Compile::Config
 {
 public:
-  Config(Project *project) : Compile::Config(project) {}
+  Config(Project& project) : Compile::Config(&project) {}
 };
 
 } // namespace
