@@ -12,6 +12,7 @@
 #include "devices/list/device_list.h"
 #include "libgui/project.h"
 #include "tool_list.h"
+#include "progs/list/prog_list.h"
 
 //----------------------------------------------------------------------------
 PURL::Directory Compile::Config::directory(const Tool::Group &group, DirectoryType type)
@@ -107,14 +108,23 @@ QString Compile::Config::device(const Project *project)
   return Device::lister().checkName(device);
 }
 
-const Tool::Group &Compile::Config::toolGroup(const Project *project)
+const Tool::Group& Compile::Config::toolGroup(const Project *project)
 {
   QString s = globalValue(project, "tool", QString::null);
-  const Tool::Group *group = Tool::lister().group(s);
-  if ( group==0 ) return *Tool::lister().begin().data();
+  const Tool::Group* group = Tool::Lister::instance().group(s);
+  if (group == NULL) return *Tool::Lister::instance().begin().data();
   return *group;
 }
 
+const Programmer::Group& Compile::Config::programmerGroup(const Project *project)
+{
+  QString s = globalValue(project, "programmer", QString::null);
+  const Programmer::Group* group = Programmer::Lister::instance().group(s);
+  if (group == NULL && project != NULL) group = &programmerGroup(NULL);
+  if (group == NULL) return *Programmer::Lister::instance().begin().data();
+  else return *group;
+}
+
 QStringList Compile::Config::customOptions(Tool::Category category) const
 {
   return QStringList::split(' ', rawCustomOptions(category));
