@@ -12,6 +12,7 @@
 #include "common/global/purl.h"
 #include "devices/base/hex_buffer.h"
 #include "tools/base/tool_group.h"
+#include "progs/base/prog_group.h"
 class Project;
 
 //----------------------------------------------------------------------------
@@ -50,6 +51,8 @@ public:
   static void setGlobalValue(Project *project, const QString &key, const QString &value);
   static QStringList globalListValues(const Project *project, const QString &key, const QStringList &defaultValues);
   static void setGlobalListValues(Project *project, const QString &key, const QStringList &value);
+  static const Programmer::Group& programmerGroup(const Project* project);
+  static void setProgrammerGroup(Project *project, const Programmer::Group &group) { setGlobalValue(project, "programmer", group.name()); }
 
   static PURL::Directory directory(const Tool::Group &group, DirectoryType type);
   static void setDirectory(const Tool::Group &group, DirectoryType type, const PURL::Directory &dir);
@@ -59,8 +62,8 @@ public:
   static void setOutputExecutableType(const Tool::Group &group, Tool::OutputExecutableType type);
 
 protected:
-  const Tool::Group *_group;
-  Project *_project;
+  const Tool::Group* _group;
+  Project*           _project;
 
   void setValue(Tool::Category category, const QString &key, const QString &value);
   QString value(Tool::Category category, const QString &key, const QString &defaultValue) const;
