@@ -41,7 +41,7 @@ private:
   bool _compileOnly;
   QValueList<Data> _todo;
   Data _next;
-  BaseProcess *_base;
+  std::auto_ptr<BaseProcess> _base;
   QString _label;
   uint _customCommandIndex;
 
