@@ -28,29 +28,32 @@ const Tool::OutputType::Data Tool::OutputType::DATA[Nb_Types] = {
 };
 
 //-----------------------------------------------------------------------------
-const Compile::ArgumentData Compile::ARGUMENT_DATA[] = {
-  { "$(SRCPATH)",  I18N_NOOP("Replaced by the source directory.") },
-  { "$LKR(xxx)",   I18N_NOOP("Replaced by \"xxx\" when there is a custom linker script.") },
-  { "$WINE(xxx)",  I18N_NOOP("Replaced by \"xxx\" when \"wine\" is used.") },
-  { "%OBJS",       I18N_NOOP("Replaced by the list of additionnal objects.") },
-  { "%LIBS",       I18N_NOOP("Replaced by the list of additionnal libraries.") },
-  { "%O",          I18N_NOOP("Replaced by the output filename.") },
-  { "%PROJECT",    I18N_NOOP("Replaced by the project name.") },
-  { "%COFF",       I18N_NOOP("Replaced by the COFF filename.") },
-  { "%MAP",        I18N_NOOP("Replaced by the map filename.") },
-  { "%SYM",        I18N_NOOP("Replaced by the symbol filename.") },
-  { "%LIST",       I18N_NOOP("Replaced by the list filename.") },
-  { "%DEVICE",     I18N_NOOP("Replaced by the device name.") },
-  { "%FAMILY",     I18N_NOOP("Replaced by the device family name (when needed).") },
-  { "%I",          I18N_NOOP("Replaced by the relative input filepath(s).") },
-  { "%OBJECT",     I18N_NOOP("Replaced by the object file name.") },
-  { "%LKR_PATH",   I18N_NOOP("Replaced by the linker script path.") },
-  { "%LKR_NAME",   I18N_NOOP("Replaced by the linker script basename.") },
-  { "%LKR",        I18N_NOOP("Replaced by the linker script filename.") },
-  { "%SEP",        I18N_NOOP("Replaced by a separation into two arguments.") },
-  { 0, 0 }
+const CustomArgument::Data Compile::CommonArgType::DATA[Nb_Types] = {
+  { CustomArgument::ArgType::Replace,    "$(SRCPATH)",  I18N_NOOP("Replaced by the source directory.") },
+  { CustomArgument::ArgType::Replace,    "%O",          I18N_NOOP("Replaced by the output filename.") },
+  { CustomArgument::ArgType::Replace,    "%PROJECT",    I18N_NOOP("Replaced by the project name.") },
+  { CustomArgument::ArgType::Replace,    "%DEVICE",     I18N_NOOP("Replaced by the device name.") },
+  { CustomArgument::ArgType::ReplaceAll, "%I",          I18N_NOOP("Replaced by the relative input filepath(s).") },
 };
 
+const CustomArgument::Data Compile::NormalArgType::DATA[Nb_Types] = {
+  { CustomArgument::ArgType::ReplaceIf,  "$LKR(xxx)",  I18N_NOOP("Replaced by \"xxx\" when there is a custom linker script.") },
+  { CustomArgument::ArgType::ReplaceIf,  "$WINE(xxx)", I18N_NOOP("Replaced by \"xxx\" when \"wine\" is used.") },
+  { CustomArgument::ArgType::ReplaceAll, "%OBJS",      I18N_NOOP("Replaced by the list of additionnal objects.") },
+  { CustomArgument::ArgType::ReplaceAll, "%LIBS",      I18N_NOOP("Replaced by the list of additionnal libraries.") },
+  { CustomArgument::ArgType::Replace,    "%FAMILY",    I18N_NOOP("Replaced by the device family name (when needed).") },
+  { CustomArgument::ArgType::Replace,    "%LKR_PATH",  I18N_NOOP("Replaced by the linker script path.") },
+  { CustomArgument::ArgType::Replace,    "%LKR_NAME",  I18N_NOOP("Replaced by the linker script basename.") },
+  { CustomArgument::ArgType::Replace,    "%LKR",       I18N_NOOP("Replaced by the linker script filename.") },
+  { CustomArgument::ArgType::Replace,    "%COFF",      I18N_NOOP("Replaced by the COFF filename.") },
+  { CustomArgument::ArgType::Replace,    "%MAP",       I18N_NOOP("Replaced by the map filename.") },
+  { CustomArgument::ArgType::Replace,    "%SYM",       I18N_NOOP("Replaced by the symbol filename.") },
+  { CustomArgument::ArgType::Replace,    "%LIST",      I18N_NOOP("Replaced by the list filename.") },
+  { CustomArgument::ArgType::Replace,    "%OBJECT",    I18N_NOOP("Replaced by the object file name.") },
+  { CustomArgument::ArgType::Separator,  "%SEP",       I18N_NOOP("Replaced by a separation into two arguments.") }
+};
+
+
 //-----------------------------------------------------------------------------
 Compile::FileData::List Compile::FileData::List::onlyExistingFiles() const
 {
@@ -96,10 +99,102 @@ void Compile::LogWidget::lineClicked(int line)
   e->setCursorPosition(_map[line].line, 0);
 }
 
+//-----------------------------------------------------------------------------
+Compile::GenericProcess::GenericProcess()
+: _process(NULL)
+{
+  FOR_EACH(CommonArgType, type) {
+    addArg(ArgType::Common, type.type(), type.data());
+  }
+}
+
+PURL::Directory Compile::GenericProcess::directory(uint) const
+{
+  return Main::project()->directory();
+}
+
+QStringList Compile::GenericProcess::replaceAllValue(const IdData &idata) const
+{
+  ASSERT(idata.id == ArgType::Common);
+  CommonArgType::Type type =  CommonArgType::Type(idata.index);
+  QStringList args;
+  switch (type) {
+    case CommonArgType::RelativeInputFilepath:
+      for (uint k=0; k<nbFiles(); k++) args += inputFilepath(k);
+      break;
+    default: ASSERT(false); break;
+  }
+  return args;
+}
+
+QString Compile::GenericProcess::replaceValue(const IdData &idata) const
+{
+  ASSERT(idata.id == ArgType::Common);
+  CommonArgType::Type type = CommonArgType::Type(idata.index);
+  switch (type) {
+    case CommonArgType::SourcePath:
+      return directory().path();
+    case CommonArgType::OutputFilepath:
+      return outputFilepath();
+    case CommonArgType::ProjectName:
+      return Main::project()->name();
+    case CommonArgType::DeviceName:
+      return deviceName();
+    default: break;
+  }
+  ASSERT(false);
+  return QString::null;
+}
+
+QString Compile::GenericProcess::postReplaceValue(const IdData &idata,
+                                                  const QString &arg) const
+{
+  ASSERT(idata.id == ArgType::Common);
+  CommonArgType::Type type = CommonArgType::Type(idata.index);
+  switch (type) {
+    case CommonArgType::SourcePath: {
+      QString tmp = arg;
+      tmp.replace("//", "/");
+      return tmp;
+    }
+    default: break;
+  }
+  return arg;
+}
+
+bool Compile::GenericProcess::replaceIfCondition(const IdData &idata) const
+{
+  ASSERT(idata.id == ArgType::Common);
+  ASSERT(false);
+  return false;
+}
+
+PURL::Url Compile::GenericProcess::url(PURL::FileType type, uint) const
+{
+  if (type==PURL::Hex)
+    return Main::project()->url().toFileType(type);
+  else if (type==PURL::Library)
+    return Main::project()->url().toExtension(libraryExtension());
+  else {
+    return PURL::Url();
+  }
+}
+
+QString Compile::GenericProcess::filepath(PURL::FileType type, uint i) const
+{
+  return url(type, i).relativeTo(directory(), Compile::Config::executableType(group()).data().separator);
+}
+
+QString Compile::GenericProcess::outputFilepath() const
+{
+  return filepath(PURL::Hex);
+}
+
 //-----------------------------------------------------------------------------
 Compile::BaseProcess::BaseProcess()
-  : QObject(0, "compile_process"), _manager(0), _process(0)
-{}
+: _manager(NULL)
+{
+}
 
 void Compile::BaseProcess::init(const Data &data, Manager *manager)
 {
@@ -107,13 +202,6 @@ void Compile::BaseProcess::init(const Data &data, Manager *manager)
   _manager = manager;
 }
 
-PURL::Directory Compile::BaseProcess::directory(uint i) const
-{
-  if (_data.project) return _data.project->directory();
-  Q_ASSERT( i<_data.items.count() );
-  return _data.items[i].url.directory();
-}
-
 bool Compile::BaseProcess::start()
 {
   _stdout = QString::null;
@@ -122,7 +210,8 @@ bool Compile::BaseProcess::start()
   _process = new ::Process::LineSignal;
   connect(_process, SIGNAL(done(int)), SLOT(done(int)));
   connect(_process, SIGNAL(timeout()), SLOT(timeout()));
-  connect(_process, SIGNAL(logLine(::Process::OutputType, const QString &)), SLOT(logLine(::Process::OutputType, const QString &)));
+  connect(_process, SIGNAL(logLine(::Process::OutputType, const QString &)),
+          SLOT(logLine(::Process::OutputType, const QString &)));
   _process->setWorkingDirectory(directory().path());
   setupProcess();
   _manager->log(Log::LineType::Command, _process->arguments().join(" "));
@@ -146,55 +235,33 @@ void Compile::BaseProcess::timeout()
   _manager->processFailed();
 }
 
-//-----------------------------------------------------------------------------
-void Compile::Process::init(const Data &data, Manager *manager)
-{
-  BaseProcess::init(data, manager);
-  _config = group().createConfig(const_cast<Project *>(data.project));
-}
-
-Compile::Process::~Process()
-{
-  delete _config;
-}
-
-bool Compile::Process::check() const
-{
-  return group().check(_data.device, _manager);
-}
-
-PURL::Url Compile::Process::url(PURL::FileType type, uint i) const
+PURL::Url Compile::BaseProcess::url(PURL::FileType type, uint i) const
 {
   PURL::Url url;
-  if ( _data.project && (type==PURL::Hex || _data.category==Tool::Category::Linker || _data.category==Tool::Category::BinToHex) )
-    url = _data.project->url();
-  else if ( _data.project && (type==PURL::Library || _data.category==Tool::Category::Librarian) )
-    return _data.project->url().toExtension(libraryExtension());
+  if (type==PURL::Hex || _data.category==Tool::Category::Linker || _data.category==Tool::Category::BinToHex)
+    url = Main::project()->url();
+  else if (type==PURL::Library || _data.category==Tool::Category::Librarian)
+    return Main::project()->url().toExtension(libraryExtension());
   else {
-    Q_ASSERT( i<_data.items.count() );
+    ASSERT( i<_data.items.count() );
     url = _data.items[i].url;
   }
   if ( type==PURL::Nb_FileTypes ) return url;
   return url.toFileType(type);
 }
 
-QString Compile::Process::filepath(PURL::FileType type, uint i) const
+Compile::FileData Compile::BaseProcess::fileData(PURL::FileType type, FileActions actions) const
 {
-  return url(type, i).relativeTo(directory(), Compile::Config::executableType(group()).data().separator);
+  return FileData(url(type, nbFiles()-1), actions);
 }
 
-QString Compile::Process::outputFilepath() const
+QString Compile::BaseProcess::outputFilepath() const
 {
   if ( _data.category==Tool::Category::Librarian ) return filepath(PURL::Library);
   return filepath(PURL::Hex);
 }
 
-Compile::FileData Compile::Process::fileData(PURL::FileType type, FileActions actions) const
-{
-  return FileData(url(type, nbFiles()-1), actions);
-}
-
-Compile::FileData::List Compile::Process::files(bool *ok) const
+Compile::FileData::List Compile::BaseProcess::files(bool *ok) const
 {
   if (ok) *ok = true;
   FileData::List list;
@@ -209,7 +276,7 @@ Compile::FileData::List Compile::Process::files(bool *ok) const
         continue;
       }
       if ( type.data().group==PURL::LinkerScript ) {
-        PURL::Url lkr = Main::toolGroup().linkerScript(_data.project, _data.linkingType);
+        PURL::Url lkr = Main::toolGroup()->linkerScript(*_data.project, _data.linkingType);
         list += FileData(lkr, Included | InProject);
       } else {
         FileActions actions = Generated;
@@ -223,69 +290,117 @@ Compile::FileData::List Compile::Process::files(bool *ok) const
   return list;
 }
 
-bool Compile::Process::checkIs(const QString &s, const QString &key)
+//-----------------------------------------------------------------------------
+Compile::Process::Process()
 {
-  if ( !s.contains(key) ) return false;
-  if ( s!=key ) qWarning("Argument should be only %s, the rest will be ignored...", key.latin1());
-  return true;
+  FOR_EACH(NormalArgType, type) {
+    addArg(ArgType::Normal, type.type(), type.data());
+  }
 }
 
-QString Compile::Process::replaceIf(const QString &s, const QString &key, bool condition)
+void Compile::Process::init(const Data &data, Manager *manager)
 {
-  QRegExp rexp("(.*)\\$" + key + "\\(([^)]*)\\)(.*)");
-  if ( !rexp.exactMatch(s) ) return s;
-  return rexp.cap(1) + (condition ? rexp.cap(2) : QString::null) + rexp.cap(3);
+  BaseProcess::init(data, manager);
+  _config.reset(group().createConfig(const_cast<Project&>(*data.project)));
+}
+
+bool Compile::Process::check() const
+{
+  return group().check(_data.device, _manager);
+}
+
+QStringList Compile::Process::replaceAllValue(const IdData &idata) const
+{
+  if (idata.id == ArgType::Common) return BaseProcess::replaceAllValue(idata);
+  Q_ASSERT(idata.id == ArgType::Normal);
+  NormalArgType::Type type = NormalArgType::Type(idata.index);
+  Tool::ExecutableType execType = Compile::Config::executableType(group());
+  QStringList args;
+  switch (type) {
+    case NormalArgType::AdditionnalLibraries:
+      if (_data.project) args += _data.project->librariesForLinker(QString::null, execType);
+      break;
+    case NormalArgType::AdditionnalObjects:
+      if (_data.project) args += _data.project->objectsForLinker(objectExtension(), execType);
+      else {
+        PURL::Url tmp = url(PURL::Object);
+        if ( !objectExtension().isEmpty() ) tmp = tmp.toExtension(objectExtension());
+        args += tmp.relativeTo(directory(), execType.data().separator);
+      }
+      break;
+    default: Q_ASSERT(false); break;
+  }
+  return args;
+}
+
+QString Compile::Process::replaceValue(const IdData &idata) const
+{
+  if (idata.id == ArgType::Common) return BaseProcess::replaceValue(idata);
+  Q_ASSERT(idata.id == ArgType::Normal);
+  NormalArgType::Type type = NormalArgType::Type(idata.index);
+  Tool::ExecutableType execType = Compile::Config::executableType(group());
+  switch(type) {
+    case NormalArgType::DeviceFamilyName:
+      return familyName();
+    case NormalArgType::LinkerScriptPath: {
+      PURL::Url lkr = Main::toolGroup()->linkerScript(*_data.project, _data.linkingType);
+      return lkr.path();
+    }
+    case NormalArgType::LinkerScriptBasename: {
+      PURL::Url lkr = Main::toolGroup()->linkerScript(*_data.project, _data.linkingType);
+      return lkr.filename();
+    }
+    case NormalArgType::LinkerScriptFilename: {
+      PURL::Url lkr = Main::toolGroup()->linkerScript(*_data.project, _data.linkingType);
+      return lkr.filepath();
+    }
+    case NormalArgType::CoffFilename:
+      return filepath(PURL::Coff);
+    case NormalArgType::MapFilename:
+      return filepath(PURL::Map);
+    case NormalArgType::SymFilename:
+      return url().toExtension("sym").relativeTo(directory(), execType.data().separator);
+    case NormalArgType::ListFilename:
+      return filepath(PURL::Lst);
+    case NormalArgType::ObjectFilename:
+      return filepath(PURL::Object);
+    default: break;
+  }
+  Q_ASSERT(false);
+  return QString::null;
+}
+
+QString Compile::Process::postReplaceValue(const IdData &idata,
+                                           const QString &arg) const
+{
+  if (idata.id == ArgType::Common) return BaseProcess::postReplaceValue(idata, arg);
+  Q_ASSERT(idata.id == ArgType::Normal);
+  return arg;
+}
+
+bool Compile::Process::replaceIfCondition(const IdData &idata) const
+{
+  if (idata.id == ArgType::Common) return BaseProcess::replaceIfCondition(idata);
+  Q_ASSERT(idata.id == ArgType::Normal);
+  NormalArgType::Type type = NormalArgType::Type(idata.index);
+  switch(type) {
+    case NormalArgType::ReplaceIfCustomLinkerScript:
+      return hasLinkerScript();
+    case NormalArgType::ReplaceIfWine: {
+      Tool::ExecutableType execType = Compile::Config::executableType(group());
+      return (execType == Tool::ExecutableType::Windows);
+    }
+    default: break;
+  }
+  Q_ASSERT(false);
+  return false;
 }
 
 QStringList Compile::Process::arguments() const
 {
   bool custom = _config->hasCustomArguments(_data.category);
-  Tool::ExecutableType execType = Compile::Config::executableType(group());
   QStringList args = (custom ? _config->customArguments(_data.category) : genericArguments(*_config));
-  PURL::Url lkr = Main::toolGroup().linkerScript(_data.project, _data.linkingType);
-  QStringList nargs;
-  for (uint i=0; i<args.count(); i++) {
-    if ( args[i].contains("$(SRCPATH)") ) {
-      args[i].replace("$(SRCPATH)", directory().path());
-      args[i].replace("//", "/");
-    }
-    args[i] = replaceIf(args[i], "WINE", execType==Tool::ExecutableType::Windows);
-    args[i] = replaceIf(args[i], "LKR", hasLinkerScript());
-    if ( checkIs(args[i], "%OBJS") ) { // before %O
-      if (_data.project) nargs += _data.project->objectsForLinker(objectExtension(), execType);
-      else {
-        PURL::Url tmp = url(PURL::Object);
-        if ( !objectExtension().isEmpty() ) tmp = tmp.toExtension(objectExtension());
-        nargs += tmp.relativeTo(directory(), execType.data().separator);
-      }
-      continue;
-    }
-    if ( checkIs(args[i], "%LIBS") ) {
-      if (_data.project) nargs += _data.project->librariesForLinker(QString::null, execType);
-      continue;
-    }
-    args[i].replace("%OBJECT", filepath(PURL::Object)); // before %O
-    args[i].replace("%O", outputFilepath());
-    args[i].replace("%COFF", filepath(PURL::Coff));
-    if (_data.project) args[i].replace("%PROJECT", _data.project->name());
-    else  args[i].replace("%PROJECT", url().basename());
-    args[i].replace("%MAP", filepath(PURL::Map));
-    args[i].replace("%SYM", url().toExtension("sym").relativeTo(directory(), execType.data().separator));
-    args[i].replace("%LIST", filepath(PURL::Lst));
-    args[i].replace("%DEVICE", deviceName());
-    args[i].replace("%FAMILY", familyName());
-    args[i].replace("%LKR_PATH", lkr.path()); // before %LKR
-    args[i].replace("%LKR_NAME", lkr.filename()); // before LKR
-    args[i].replace("%LKR", lkr.filepath());
-    if ( checkIs(args[i], "%I") ) {
-      for (uint k=0; k<nbFiles(); k++) nargs += inputFilepath(k);
-      continue;
-    }
-    if ( !args[i].isEmpty() ) nargs += args[i];
-  }
-  args.clear();
-  for (uint i=0; i<nargs.count(); i++) args += QStringList::split("%SEP", nargs[i]);
-  return args;
+  return process(args);
 }
 
 void Compile::Process::setupProcess()
@@ -342,7 +457,7 @@ void Compile::Process::doLog(Log::LineType type, const QString &message, const Q
     _manager->log(type, message);
     return;
   }
-  PURL::Url url = PURL::Url::fromPathOrUrl(surl);
+  PURL::Url url = PURL::fromPathOrUrl(surl, true);
   QString s;
   if ( !url.isEmpty() ) {
     if ( !url.exists() && !url.isInto(directory()) ) url = PURL::Url(directory(), surl);
@@ -361,10 +476,17 @@ void Compile::Process::doLog(Log::LineType type, const QString &message, const Q
 void Compile::CustomProcess::setupProcess()
 {
   _process->setUseShell(true);
-  _process->setup(_command, QStringList(), false);
+  QStringList args = QStringList::split(" ", _command);
+  args = process(args);
+  _process->setup(args.join(" "), QStringList(), false);
 }
 
 void Compile::CustomProcess::logLine(::Process::OutputType, const QString &line)
 {
   _manager->log(Log::LineType::Normal, line);
 }
+
+QString Compile::CustomProcess::deviceName() const
+{
+  return GPUtils::toDeviceName(_data.device);
+}
