@@ -9,14 +9,18 @@
 #ifndef COMPILE_PROCESS_H
 #define COMPILE_PROCESS_H
 
+#include <memory>
+
 #include "common/common/qflags.h"
 #include "common/global/purl.h"
 #include "common/global/process.h"
+#include "common/common/args.h"
 #include "libgui/log_view.h"
 #include "devices/base/hex_buffer.h"
 #include "tools/base/tool_group.h"
 #include "tools/base/generic_tool.h"
 #include "libgui/main_global.h"
+#include "compile_config.h"
 namespace Process { class LineSignal; }
 
 namespace Tool
@@ -50,10 +54,21 @@ public:
   };
 };
 
-struct ArgumentData {
-  const char *key, *description;
-};
-extern const ArgumentData ARGUMENT_DATA[];
+BEGIN_DECLARE_ENUM(ArgType)
+  Common = 0, Normal
+END_DECLARE_ENUM_NO_DATA(ArgType)
+
+BEGIN_DECLARE_ENUM(CommonArgType)
+  SourcePath = 0, OutputFilepath, ProjectName, DeviceName, RelativeInputFilepath
+END_DECLARE_ENUM(CommonArgType, CustomArgument::Data)
+
+BEGIN_DECLARE_ENUM(NormalArgType)
+  ReplaceIfCustomLinkerScript = 0, ReplaceIfWine,
+  AdditionnalObjects, AdditionnalLibraries, DeviceFamilyName,
+  LinkerScriptPath, LinkerScriptBasename, LinkerScriptFilename,
+  CoffFilename, MapFilename, SymFilename, ListFilename, ObjectFilename,
+  Separator
+END_DECLARE_ENUM(NormalArgType, CustomArgument::Data)
 
 class ParseErrorData {
 public:
@@ -82,9 +97,10 @@ enum Operation { Build, Clean, CreateDebugInfo };
 
 class Data {
 public:
-  Data() {}
-  Data(Tool::Category c, const QValueList<Item> &i, const QString &d, const Project *p, LinkingType lt, Operation o)
-    : category(c), items(i), device(d), project(p), linkingType(lt), operation(o) {}
+  Data()
+    : category(Tool::Category::Nb_Types), project(NULL) {}
+  Data(Tool::Category c, const QValueList<Item> &i, const QString &d, const Project& p, LinkingType lt, Operation o)
+    : category(c), items(i), device(d), project(&p), linkingType(lt), operation(o) {}
   Tool::Category category;
   QValueList<Item> items;
   QString device;
@@ -120,14 +136,39 @@ private:
 };
 
 //-----------------------------------------------------------------------------
-class BaseProcess : public QObject
+class GenericProcess : public QObject, public CustomArgument::Processor
+{
+Q_OBJECT
+public:
+  GenericProcess();
+
+protected:
+  ::Process::LineSignal* _process;
+
+  const Tool::Group& group() const { return *Main::toolGroup(); }
+  virtual uint nbFiles() const = 0;
+  virtual PURL::Directory directory(uint i = 0) const;
+  virtual PURL::Url url(PURL::FileType type = PURL::Nb_FileTypes, uint i = 0) const;
+  QString filepath(PURL::FileType type, uint i=0) const;
+  virtual QString outputFilepath() const;
+  virtual QString inputFilepath(uint i) const { return filepath(PURL::Nb_FileTypes, i); }
+  virtual QString deviceName() const = 0;
+  virtual QString libraryExtension() const { return "lib"; }
+  virtual QStringList replaceAllValue(const IdData &idata) const;
+  virtual bool replaceIfCondition(const IdData &idata) const;
+  virtual QString replaceValue(const IdData &idata) const;
+  virtual QString postReplaceValue(const IdData &idata, const QString &arg) const;
+};
+
+//-----------------------------------------------------------------------------
+class BaseProcess : public GenericProcess
 {
 Q_OBJECT
 public:
   BaseProcess();
   virtual void init(const Data &data, Manager *manager);
   virtual bool check() const = 0;
-  virtual FileData::List files(bool *ok) const = 0;
+  virtual FileData::List files(bool *ok) const;
   bool start();
 
 signals:
@@ -137,12 +178,14 @@ signals:
 protected:
   Manager *_manager;
   Data    _data;
-  ::Process::LineSignal *_process;
   QString _stdout, _stderr;
 
-  const Tool::Group &group() const { return Main::toolGroup(); }
-  PURL::Directory directory(uint i = 0) const;
   virtual void setupProcess() = 0;
+  virtual PURL::Url url(PURL::FileType type = PURL::Nb_FileTypes, uint i = 0) const;
+  virtual QString outputFilepath() const;
+  virtual QString outputFiles() const = 0;
+  virtual uint nbFiles() const { return _data.items.count(); }
+  FileData fileData(PURL::FileType type, FileActions actions) const;
 
 protected slots:
   virtual void logLine(::Process::OutputType type, const QString &line) = 0;
@@ -155,28 +198,18 @@ class Process : public BaseProcess
 {
 Q_OBJECT
 public:
-  virtual ~Process();
+  Process();
   virtual void init(const Data &data, Manager *manager);
   virtual bool check() const;
-  virtual FileData::List files(bool *ok) const;
   virtual QStringList genericArguments(const Compile::Config &config) const = 0;
   void checkArguments() const;
 
 protected:
-  Config  *_config;
+  std::auto_ptr<Config> _config;
 
-  virtual PURL::Url url(PURL::FileType type = PURL::Nb_FileTypes, uint i = 0) const;
-  QString filepath(PURL::FileType type, uint i=0) const;
-  virtual QString outputFilepath() const;
-  virtual QString outputFiles() const = 0;
-  virtual uint nbFiles() const { return _data.items.count(); }
-  virtual QString inputFilepath(uint i) const { return filepath(PURL::Nb_FileTypes, i); }
-  virtual QString deviceName() const = 0;
   virtual QString familyName() const { return QString::null; }
   virtual QString objectExtension() const { return QString::null; }
-  virtual QString libraryExtension() const { return "lib"; }
-  virtual bool hasLinkerScript() const { return group().hasCustomLinkerScript(_data.project); }
-  FileData fileData(PURL::FileType type, FileActions actions) const;
+  virtual bool hasLinkerScript() const { return group().hasCustomLinkerScript(*_data.project); }
   bool parseErrorLine(const QString &s, const ParseErrorData &data);
   virtual Log::LineType filterType(const QString &type) const;
   void doLog(const QString &type, const QString &message, const QString &surl, uint line);
@@ -185,9 +218,10 @@ protected:
   QStringList arguments() const;
   const Tool::Base *tool() const { return group().base(_data.category); }
 
-private:
-  static bool checkIs(const QString &s, const QString &key);
-  static QString replaceIf(const QString &s, const QString &key, bool condition);
+  virtual QStringList replaceAllValue(const IdData &idata) const;
+  virtual bool replaceIfCondition(const IdData &idata) const;
+  virtual QString replaceValue(const IdData &idata) const;
+  virtual QString postReplaceValue(const IdData &idata, const QString &arg) const;
 };
 
 //-----------------------------------------------------------------------------
@@ -201,6 +235,8 @@ public:
 
 protected:
   virtual void setupProcess();
+  virtual QString outputFiles() const { return QString::null; }
+  virtual QString deviceName() const;
 
 protected slots:
   virtual void logLine(::Process::OutputType type, const QString &line);
