@@ -18,11 +18,12 @@ namespace Tool
 class Lister : public ::Group::Lister<Group>
 {
 public:
+  static const Lister& instance();
+
+private:
   Lister();
 };
 
-extern const Lister &lister();
-
 } // namespace
 
 #endif
