@@ -20,38 +20,39 @@
 #include "libgui/project.h"
 
 //----------------------------------------------------------------------------
-HelpDialog::HelpDialog(QWidget *parent)
+HelpDialog::HelpDialog(QWidget *parent, const CustomArgument::ArgList &args)
   : Dialog(parent, "help_dialog", false, i18n("Help Dialog"), Close, Close, false)
 {
   QGridLayout *top = new QGridLayout(mainWidget(), 1, 1, 10, 10);
   uint k = 0;
-  for (; Compile::ARGUMENT_DATA[k].key; k++) {
-    QLabel *label = new QLabel(Compile::ARGUMENT_DATA[k].key, mainWidget());
+  for (CustomArgument::ArgList::const_iterator it = args.begin();
+       it != args.end();
+       ++it) {
+    const CustomArgument::Data &data = *it;
+    QLabel *label = new QLabel(data.key, mainWidget());
     top->addWidget(label, k, 0);
-    label = new QLabel(i18n(Compile::ARGUMENT_DATA[k].description), mainWidget());
+    label = new QLabel(i18n(data.label), mainWidget());
     top->addWidget(label, k, 1);
+    ++k;
   }
   top->setColStretch(2, 1);
   top->setRowStretch(k, 1);
 }
 
 //----------------------------------------------------------------------------
-ToolsConfigWidget::ToolsConfigWidget(Project *project, QWidget *parent)
-  : ::ConfigWidget(parent), _project(project), _helpDialog(0)
+ToolsConfigWidget::ToolsConfigWidget(Project& project, QWidget *parent)
+: ::ConfigWidget(parent), _project(project), _helpDialog(0)
 {
   uint row = 0;
 
   QLabel *label = new QLabel(i18n("Toolchain:"), this);
   addWidget(label, row,row, 0,0);
-  _tool = new KeyComboBox<QString>(this);
-  Tool::Lister::ConstIterator it;
-  for (it=Tool::lister().begin(); it!=Tool::lister().end(); ++it)
-    _tool->appendItem(it.key(), it.data()->label());
+  _tool.reset(new ListerComboBox<Tool::Lister>(this));
   connect(_tool->widget(), SIGNAL(activated(int)), SLOT(toolChanged()));
   addWidget(_tool->widget(), row,row, 1,1);
   label = new QLabel(i18n("Output type:"), this);
   addWidget(label, row,row, 2,2);
-  _output = new KeyComboBox<Tool::OutputType>(this);
+  _output.reset(new KeyComboBox<Tool::OutputType>(this));
   FOR_EACH(Tool::OutputType, type) _output->appendItem(type, type.label());
   addWidget(_output->widget(), row,row, 3,3);
   row++;
@@ -64,34 +65,48 @@ ToolsConfigWidget::ToolsConfigWidget(Project *project, QWidget *parent)
   FOR_EACH(Tool::Category, category) {
     _stacks[category] = new KeyWidgetStack<QString>(_tabWidget);
     _stacks[category]->widget()->setMargin(10);
-    Tool::Lister::ConstIterator it;
-    for (it=Tool::lister().begin(); it!=Tool::lister().end(); ++it) {
+    for (Tool::Lister::ConstIterator it = Tool::Lister::instance().begin();
+         it != Tool::Lister::instance().end();
+         ++it) {
       if ( it.data()->isCustom() ) continue;
-      if ( !it.data()->needs(_project, category) ) continue;
+      if ( !it.data()->needs(category) ) continue;
       ToolConfigWidget *cw = static_cast<const Tool::GroupUI *>(it.data()->gui())->createConfigWidget(category, project);
       Q_ASSERT(cw);
       _stacks[category]->appendItem(it.key(), cw);
-      connect(cw, SIGNAL(displayHelp()), SLOT(displayHelp()));
+      connect(cw, SIGNAL(displayHelp(Tool::Category)), SLOT(displayHelp(Tool::Category)));
     }
   }
   _customWidget = new QWidget(_mainStack);
   _mainStack->addWidget(_customWidget);
   QVBoxLayout *vbox = new QVBoxLayout(_customWidget);
+  QHBoxLayout *hbox = new QHBoxLayout(vbox);
   label = new QLabel(i18n("Custom shell commands:"), _customWidget);
-  vbox->addWidget(label);
+  hbox->addWidget(label, 1);
+  KPushButton *button = new KPushButton(KGuiItem(QString::null, "help"), _customWidget);
+  connect(button, SIGNAL(clicked()), SLOT(customDisplayHelp()));
+  hbox->addWidget(button);
   _commandsEditor = new EditListBox(1, _customWidget, "command_editor", EditListBox::DuplicatesAllowed);
   vbox->addWidget(_commandsEditor);
 
   setColStretch(4, 1);
 }
 
+ToolsConfigWidget::~ToolsConfigWidget()
+{
+  for (StackMap::iterator it = _stacks.begin(); it != _stacks.end(); ++it) {
+    delete it->second;
+    it->second = NULL;
+  }
+}
+
 void ToolsConfigWidget::toolChanged()
 {
-  QString name = _tool->currentItem();
-  bool canMakeLibrary = Tool::lister().group(name)->needs(_project, Tool::Category::Librarian);
+  const Tool::Group& group = _tool->group();
+  bool canMakeLibrary = group.needs(Tool::Category::Librarian);
   _output->widget()->setEnabled(canMakeLibrary);
   if ( !canMakeLibrary ) _output->setCurrentItem(Tool::OutputType::Executable);
-  if ( name==Tool::Group::CUSTOM_NAME ) _mainStack->raiseWidget(_customWidget);
+  QString name = group.name();
+  if (name == Tool::Group::CUSTOM_NAME) _mainStack->raiseWidget(_customWidget);
   else {
     _mainStack->raiseWidget(_tabWidget);
     FOR_EACH(Tool::Category, k) {
@@ -109,27 +124,26 @@ void ToolsConfigWidget::toolChanged()
 
 void ToolsConfigWidget::loadConfig()
 {
-  const Tool::Group &group = Compile::Config::toolGroup(_project);
-  _tool->setCurrentItem(group.name());
-  _output->setCurrentItem(_project->outputType());
-  QStringList commands = Compile::Config::customCommands(_project);
+  const Tool::Group &group = Compile::Config::toolGroup(&_project);
+  _tool->setGroup(group);
+  _output->setCurrentItem(_project.outputType());
+  QStringList commands = Compile::Config::customCommands(&_project);
   _commandsEditor->setTexts(commands);
   toolChanged();
   FOR_EACH(Tool::Category, k) {
-    KeyWidgetStack<QString>::ConstIterator it;
-    for (it=_stacks[k]->begin(); it!=_stacks[k]->end(); ++it) {
-      if ( it.key()==Tool::Group::CUSTOM_NAME ) continue;
-      static_cast<ToolConfigWidget *>(_stacks[k]->item(it.key()))->loadConfig();
+    for (KeyWidgetStack<QString>::const_iterator it = _stacks[k]->begin(); it != _stacks[k]->end(); ++it) {
+      if ( it->first==Tool::Group::CUSTOM_NAME ) continue;
+      static_cast<ToolConfigWidget *>(_stacks[k]->item(it->first))->loadConfig();
     }
   }
 }
 
 void ToolsConfigWidget::saveConfig()
 {
-  QString name = _tool->currentItem();
-  Compile::Config::setToolGroup(_project, *Tool::lister().group(name));
-  _project->setOutputType(_output->currentItem());
-  Compile::Config::setCustomCommands(_project, _commandsEditor->texts());
+  Compile::Config::setToolGroup(&_project, _tool->group());
+  _project.setOutputType(_output->currentItem());
+  Compile::Config::setCustomCommands(&_project, _commandsEditor->texts());
+  QString name = _tool->group().name();
   FOR_EACH(Tool::Category, k) {
     if ( !_stacks[k]->contains(name) ) continue;
     QWidget *w = _stacks[k]->item(name);
@@ -137,8 +151,25 @@ void ToolsConfigWidget::saveConfig()
   }
 }
 
-void ToolsConfigWidget::displayHelp()
+void ToolsConfigWidget::displayHelp(Tool::Category category)
 {
-  if ( _helpDialog.isNull() ) _helpDialog = new HelpDialog(this);
+  if ( _helpDialog.isNull() ) {
+    Compile::Data data;
+    data.category = category;
+    Compile::Process* process = _tool->group().processFactory(data);
+    CustomArgument::ArgList args = process->argList();
+    delete process;
+    _helpDialog = new HelpDialog(this, args);
+  }
   _helpDialog->show();
 }
+
+void ToolsConfigWidget::customDisplayHelp()
+{
+  if ( _customHelpDialog.isNull() ) {
+    Compile::CustomProcess process(QString::null);
+    CustomArgument::ArgList args = process.argList();
+    _customHelpDialog = new HelpDialog(this, args);
+  }
+  _customHelpDialog->show();
+}
