@@ -10,6 +10,9 @@
 #ifndef TOOLS_CONFIG_WIDGET_H
 #define TOOLS_CONFIG_WIDGET_H
 
+#include <map>
+#include <memory>
+
 #include <qcombobox.h>
 #include <qtabwidget.h>
 #include <qvaluevector.h>
@@ -20,6 +23,7 @@
 #include "common/gui/editlistbox.h"
 #include "tools/base/generic_tool.h"
 #include "tools/list/compile_process.h"
+#include "tools/list/tool_list.h"
 class Project;
 class ToolConfigWidget;
 
@@ -28,7 +32,7 @@ class HelpDialog : public Dialog
 {
 Q_OBJECT
 public:
-  HelpDialog(QWidget *parent);
+  HelpDialog(QWidget *parent, const CustomArgument::ArgList &arguments);
 };
 
 //----------------------------------------------------------------------------
@@ -36,26 +40,30 @@ class ToolsConfigWidget : public ConfigWidget
 {
 Q_OBJECT
 public:
-  ToolsConfigWidget(Project *project, QWidget *parent);
+  ToolsConfigWidget(Project& project, QWidget *parent);
+  ~ToolsConfigWidget();
   virtual void loadConfig();
 
 public slots:
   virtual void saveConfig();
-  virtual void displayHelp();
+  void customDisplayHelp();
+  void displayHelp(Tool::Category category);
 
 private slots:
   void toolChanged();
 
 private:
-  Project      *_project;
-  KeyComboBox<QString> *_tool;
-  KeyComboBox<Tool::OutputType> *_output;
+  Project&      _project;
+  std::auto_ptr<ListerComboBox<Tool::Lister> > _tool;
+  std::auto_ptr<KeyComboBox<Tool::OutputType> > _output;
   QWidgetStack *_mainStack;
   QWidget      *_customWidget;
   EditListBox  *_commandsEditor;
   QTabWidget   *_tabWidget;
-  QMap<Tool::Category, KeyWidgetStack<QString> *> _stacks;
+  typedef std::map<Tool::Category, KeyWidgetStack<QString>*> StackMap;
+  StackMap      _stacks;
   QGuardedPtr<Dialog> _helpDialog;
+  QGuardedPtr<Dialog> _customHelpDialog;
 };
 
 #endif
