@@ -9,6 +9,6 @@
 #include "mpc_ui.h"
 
 //----------------------------------------------------------------------------
-MPC::ConfigWidget::ConfigWidget(Project *project)
+MPC::ConfigWidget::ConfigWidget(Project& project)
   : ToolConfigWidget(project)
 {}
