@@ -41,7 +41,7 @@ Compile::Process *MPC::Group::processFactory(const Compile::Data &data) const
   return 0;
 }
 
-Compile::Config *MPC::Group::configFactory(::Project *project) const
+Compile::Config *MPC::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
@@ -51,8 +51,8 @@ QString MPC::Group::informationText() const
   return i18n("<a href=\"%1\">MPC Compiler</a> is a C compiler distributed by Byte Craft.").arg("http://www.bytecraft.com/mpccaps.html");
 }
 
-Tool::Group::BaseData MPC::Group::baseFactory(Tool::Category category) const
+Tool::Base* MPC::Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new MPC::Base, Both);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new MPC::Base;
+  return NULL;
 }
