@@ -20,7 +20,7 @@ class ConfigWidget : public ToolConfigWidget
 {
 Q_OBJECT
 public:
-  ConfigWidget(Project *project);
+  ConfigWidget(Project& project);
   virtual void initEntries();
 };
 
@@ -28,7 +28,7 @@ public:
 class GroupUI : public Tool::GroupUI
 {
 public:
-  virtual ::ToolConfigWidget *configWidgetFactory(Tool::Category, ::Project *project) const { return new ConfigWidget(project); }
+  virtual ::ToolConfigWidget *configWidgetFactory(Tool::Category, ::Project& project) const { return new ConfigWidget(project); }
 };
 
 } // namespace
