@@ -63,12 +63,12 @@ QString PIC30::Group::informationText() const
   return i18n("The <a href=\"%1\">PIC30 ToolChain</a> is a toolsuite for 16-bit PICs available from Microchip. Most of it is available under the GNU Public License.").arg("http://microchip.com/stellent/idcplg?IdcService=SS_GET_PAGE&nodeId=1406&dDocName=en010065&part=SW006012");
 }
 
-Tool::Group::BaseData PIC30::Group::baseFactory(Tool::Category category) const
+Tool::Base* PIC30::Group::baseFactory(Tool::Category category) const
 {
   if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler
-       || category==Tool::Category::Linker || category==Tool::Category::BinToHex ) return BaseData(new ::PIC30::Base, Both);
-  if ( category==Tool::Category::Librarian ) return BaseData(new ::PIC30::Base, ProjectOnly);
-  return BaseData();
+       || category==Tool::Category::Linker || category==Tool::Category::BinToHex ) return new ::PIC30::Base;
+  if ( category==Tool::Category::Librarian ) return new ::PIC30::Base;
+  return NULL;
 }
 
 QValueList<const Device::Data *> PIC30::Group::getSupportedDevices(const QString &) const
@@ -86,26 +86,18 @@ QValueList<const Device::Data *> PIC30::Group::getSupportedDevices(const QString
 Compile::Process *PIC30::Group::processFactory(const Compile::Data &data) const
 {
   switch (data.category.type()) {
-    case Tool::Category::Compiler:
-      if (data.project) return new PIC30::CompileProjectFile;
-      return new PIC30::CompileStandaloneFile;
-    case Tool::Category::Assembler:
-      if (data.project) return new PIC30::AssembleProjectFile;
-      return new PIC30::AssembleStandaloneFile;
-    case Tool::Category::Linker:
-      if (data.project) return new PIC30::LinkProject;
-      return new PIC30::LinkStandalone;
-    case Tool::Category::Librarian:
-      Q_ASSERT(data.project);
-      return new PIC30::LibraryProject;
-    case Tool::Category::BinToHex: return new PIC30::BinToHex;
-    case Tool::Category::Nb_Types: break;
+    case Tool::Category::Compiler:  return new PIC30::CompileProjectFile;
+    case Tool::Category::Assembler: return new PIC30::AssembleProjectFile;
+    case Tool::Category::Linker:    return new PIC30::LinkProject;
+    case Tool::Category::Librarian: return new PIC30::LibraryProject;
+    case Tool::Category::BinToHex:  return new PIC30::BinToHex;
+    case Tool::Category::Nb_Types:  break;
   }
   Q_ASSERT(false);
-  return 0;
+  return NULL;
 }
 
-Compile::Config *PIC30::Group::configFactory(::Project *project) const
+Compile::Config *PIC30::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
