@@ -41,10 +41,10 @@ public:
   virtual PURL::FileType implementationType(PURL::ToolType type) const;
 
 private:
-  virtual BaseData baseFactory(Tool::Category category) const;
-  virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const;
-  virtual Compile::Process *processFactory(const Compile::Data &data) const;
-  virtual Compile::Config *configFactory(::Project *project) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category category) const;
+  virtual QValueList<const Device::Data*> getSupportedDevices(const QString &s) const;
+  virtual Compile::Process* processFactory(const Compile::Data &data) const;
+  virtual Compile::Config* configFactory(::Project& project) const;
   virtual Tool::SourceGenerator *sourceGeneratorFactory() const;
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType type, const PURL::Directory &execDir, Tool::ExecutableType execType) const;
 };
