@@ -36,19 +36,6 @@ void PIC30::CompileFile::logLine(::Process::OutputType, const QString &line)
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
-//-----------------------------------------------------------------------------
-QStringList PIC30::CompileStandaloneFile::genericArguments(const Compile::Config &config) const
-{
-  QStringList args = CompileFile::genericArguments(config);
-  args += "%I";
-  return args;
-}
-
-QString PIC30::CompileStandaloneFile::outputFiles() const
-{
-  return CompileFile::outputFiles() + " PURL::Object PURL::Elf";
-}
-
 //-----------------------------------------------------------------------------
 QStringList PIC30::CompileProjectFile::genericArguments(const Compile::Config &config) const
 {
@@ -81,15 +68,6 @@ void PIC30::AssembleFile::logLine(::Process::OutputType, const QString &line)
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
-//-----------------------------------------------------------------------------
-QStringList PIC30::AssembleStandaloneFile::genericArguments(const Compile::Config &config) const
-{
-  QStringList args = AssembleFile::genericArguments(config);
-  args += "-p%DEVICE";
-  args += "%I";
-  return args;
-}
-
 //-----------------------------------------------------------------------------
 QStringList PIC30::AssembleProjectFile::genericArguments(const Compile::Config &config) const
 {
@@ -133,14 +111,6 @@ void PIC30::Link::logLine(::Process::OutputType, const QString &line)
   doLog(Log::LineType::Normal, line, QString::null, 0); // unrecognized
 }
 
-//-----------------------------------------------------------------------------
-QStringList PIC30::LinkStandalone::genericArguments(const Compile::Config &config) const
-{
-  QStringList args = Link::genericArguments(config);
-  args += config.customLibraries(Tool::Category::Linker);
-  return args;
-}
-
 //-----------------------------------------------------------------------------
 QStringList PIC30::LinkProject::genericArguments(const Compile::Config &config) const
 {
