@@ -31,15 +31,6 @@ protected:
   virtual void logLine(::Process::OutputType type, const QString &line);
 };
 
-//-----------------------------------------------------------------------------
-class CompileStandaloneFile : public CompileFile
-{
-Q_OBJECT
-protected:
-  virtual QStringList genericArguments(const Compile::Config &config) const;
-  virtual QString outputFiles() const;
-};
-
 //-----------------------------------------------------------------------------
 class CompileProjectFile : public CompileFile
 {
@@ -59,14 +50,6 @@ protected:
   virtual void logLine(::Process::OutputType type, const QString &line);
 };
 
-//-----------------------------------------------------------------------------
-class AssembleStandaloneFile : public AssembleFile
-{
-Q_OBJECT
-protected:
-  virtual QStringList genericArguments(const Compile::Config &config) const;
-};
-
 //-----------------------------------------------------------------------------
 class AssembleProjectFile : public AssembleFile
 {
@@ -86,14 +69,6 @@ protected:
   virtual void logLine(::Process::OutputType type, const QString &line);
 };
 
-//-----------------------------------------------------------------------------
-class LinkStandalone : public Link
-{
-Q_OBJECT
-protected:
-  virtual QStringList genericArguments(const Compile::Config &config) const;
-};
-
 //-----------------------------------------------------------------------------
 class LinkProject : public Link
 {
