@@ -9,7 +9,7 @@
 #include "picc_ui.h"
 
 //----------------------------------------------------------------------------
-PICC::ConfigWidget::ConfigWidget(Project *project)
+PICC::ConfigWidget::ConfigWidget(Project& project)
   : ToolConfigWidget(project)
 {}
 
