@@ -40,6 +40,12 @@ QString PICC::Base18::baseExecutable(Tool::ExecutableType, Tool::OutputExecutabl
   return "picc18";
 }
 
+QString PICC::BaseDs::baseExecutable(Tool::ExecutableType, Tool::OutputExecutableType) const
+{
+  if ( _category.type()==Tool::Category::Librarian ) return "libr";
+  return "dspicc";
+}
+
 //----------------------------------------------------------------------------
 QValueList<const Device::Data *> PICC::Group::getSupportedDevices(const QString &s) const
 {
@@ -58,11 +64,9 @@ Compile::Process *PICC::Group::processFactory(const Compile::Data &data) const
 {
   switch (data.category.type()) {
     case Tool::Category::Compiler:
-      if (data.project) return new PICC::CompileProjectFile;
-      return new PICC::CompileStandaloneFile;
+      return new PICC::CompileProjectFile;
     case Tool::Category::Assembler:
-      if (data.project) return new PICC::AssembleProjectFile;
-      return new PICC::AssembleStandaloneFile;
+      return new PICC::AssembleProjectFile;
     case Tool::Category::Linker:
       Q_ASSERT(data.project);
       return new PICC::LinkProject;
@@ -75,7 +79,7 @@ Compile::Process *PICC::Group::processFactory(const Compile::Data &data) const
   return 0;
 }
 
-Compile::Config *PICC::Group::configFactory(::Project *project) const
+Compile::Config *PICC::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
@@ -87,17 +91,23 @@ PURL::FileType PICC::Group::implementationType(PURL::ToolType type) const
   return PURL::Nb_FileTypes;
 }
 
+bool PICC::Group::needs(Tool::Category category) const
+{
+  if (category == Tool::Category::Assembler) return false;
+  return Tool::Group::needs(category);
+}
+
 //----------------------------------------------------------------------------
 QString PICC::PICCLiteGroup::informationText() const
 {
   return i18n("<a href=\"%1\">PICC-Lite</a> is a freeware C compiler distributed by HTSoft.").arg("http://www.htsoft.com");
 }
 
-Tool::Group::BaseData PICC::PICCLiteGroup::baseFactory(Tool::Category category) const
+Tool::Base* PICC::PICCLiteGroup::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return BaseData(new BaseLite, Both);
-  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return BaseData(new BaseLite, ProjectOnly);
-  return BaseData();
+  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return new BaseLite;
+  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return new BaseLite;
+  return NULL;
 }
 
 //----------------------------------------------------------------------------
@@ -106,11 +116,11 @@ QString PICC::PICCGroup::informationText() const
   return i18n("<a href=\"%1\">PICC</a> is a C compiler distributed by HTSoft.").arg("http://www.htsoft.com");
 }
 
-Tool::Group::BaseData PICC::PICCGroup::baseFactory(Tool::Category category) const
+Tool::Base* PICC::PICCGroup::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return BaseData(new BaseNormal, Both);
-  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return BaseData(new BaseNormal, ProjectOnly);
-  return BaseData();
+  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return new BaseNormal;
+  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return new BaseNormal;
+  return NULL;
 }
 
 //----------------------------------------------------------------------------
@@ -119,9 +129,22 @@ QString PICC::PICC18Group::informationText() const
   return i18n("<a href=\"%1\">PICC 18</a> is a C compiler distributed by HTSoft.").arg("http://www.htsoft.com");
 }
 
-Tool::Group::BaseData PICC::PICC18Group::baseFactory(Tool::Category category) const
+Tool::Base* PICC::PICC18Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return BaseData(new Base18, Both);
-  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return BaseData(new Base18, ProjectOnly);
-  return BaseData();
+  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return new Base18;
+  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return new Base18;
+  return NULL;
+}
+
+//----------------------------------------------------------------------------
+QString PICC::DsPICCGroup::informationText() const
+{
+  return i18n("<a href=\"%1\">dsPICC</a> is a C compiler distributed by HTSoft.").arg("http://www.htsoft.com");
+}
+
+Tool::Base* PICC::DsPICCGroup::baseFactory(Tool::Category category) const
+{
+  if ( category==Tool::Category::Compiler || category==Tool::Category::Assembler ) return new BaseDs;
+  if ( category==Tool::Category::Linker || category==Tool::Category::Librarian )   return new BaseDs;
+  return NULL;
 }
