@@ -29,29 +29,11 @@ void PICC::Process::logLine(::Process::OutputType, const QString &line)
   doLog(Log::LineType::Normal, line, QString::null, 0);
 }
 
-//-----------------------------------------------------------------------------
-QStringList PICC::CompileStandaloneFile::genericArguments(const Compile::Config &config) const
-{
-  QStringList args = Process::genericArguments(config);
-  args += "-M%MAP";
-  args += "-G%SYM";
-  args += "--ASMLIST";
-  args += config.includeDirs(Tool::Category::Compiler, "-I");
-  args += config.customOptions(Tool::Category::Compiler);
-  args += "%I";
-  return args;
-}
-
-QString PICC::CompileStandaloneFile::outputFiles() const
-{
-  return "PURL::Lst PURL::Map obj PURL::Hex PURL::Coff sym sdb hxl rlf";
-}
-
 //-----------------------------------------------------------------------------
 QStringList PICC::CompileProjectFile::genericArguments(const Compile::Config &config) const
 {
   QStringList args = Process::genericArguments(config);
-  args += "-S";
+  args += "-C";
   args += config.includeDirs(Tool::Category::Compiler, "-I");
   args += config.customOptions(Tool::Category::Compiler);
   args += "%I";
@@ -60,25 +42,7 @@ QStringList PICC::CompileProjectFile::genericArguments(const Compile::Config &co
 
 QString PICC::CompileProjectFile::outputFiles() const
 {
-  return "PURL::AsmPICC";
-}
-
-//-----------------------------------------------------------------------------
-QStringList PICC::AssembleStandaloneFile::genericArguments(const Compile::Config &config) const
-{
-  QStringList args = Process::genericArguments(config);
-  args += "-M%MAP";
-  args += "-G%SYM";
-  args += "--ASMLIST";
-  args += config.includeDirs(Tool::Category::Assembler, "-I");
-  args += config.customOptions(Tool::Category::Assembler);
-  args += "%I";
-  return args;
-}
-
-QString PICC::AssembleStandaloneFile::outputFiles() const
-{
-  return "PURL::Lst PURL::Map obj PURL::Hex sym sdb hxl rlf";
+  return "obj PURL::Lst rlf";
 }
 
 //-----------------------------------------------------------------------------
@@ -95,7 +59,7 @@ QStringList PICC::AssembleProjectFile::genericArguments(const Compile::Config &c
 
 QString PICC::AssembleProjectFile::outputFiles() const
 {
-  return "obj PURL::Lst rlf";
+  return "obj PURL::Lst rlf sdb";
 }
 
 //-----------------------------------------------------------------------------
@@ -115,7 +79,7 @@ QStringList PICC::LinkProject::genericArguments(const Compile::Config &config) c
 
 QString PICC::LinkProject::outputFiles() const
 {
-  return "PURL::Map PURL::Hex PURL::Coff sym sdb hxl";
+  return "PURL::Map PURL::Hex PURL::Coff sym hxl";
 }
 
 //-----------------------------------------------------------------------------
