@@ -24,15 +24,6 @@ protected:
   virtual QString objectExtension() const { return "obj"; }
 };
 
-//-----------------------------------------------------------------------------
-class CompileStandaloneFile : public Process
-{
-Q_OBJECT
-protected:
-  virtual QString outputFiles() const;
-  virtual QStringList genericArguments(const Compile::Config &config) const;
-};
-
 //-----------------------------------------------------------------------------
 class CompileProjectFile : public Process
 {
@@ -42,15 +33,6 @@ protected:
   virtual QStringList genericArguments(const Compile::Config &config) const;
 };
 
-//-----------------------------------------------------------------------------
-class AssembleStandaloneFile : public Process
-{
-Q_OBJECT
-protected:
-  virtual QString outputFiles() const;
-  virtual QStringList genericArguments(const Compile::Config &config) const;
-};
-
 //-----------------------------------------------------------------------------
 class AssembleProjectFile : public Process
 {
