@@ -19,7 +19,7 @@ class ConfigWidget : public ToolConfigWidget
 {
 Q_OBJECT
 public:
-  ConfigWidget(Project *project);
+  ConfigWidget(Project& project);
   virtual void initEntries();
 };
 
@@ -27,7 +27,7 @@ public:
 class GroupUI : public Tool::GroupUI
 {
 public:
-  virtual ToolConfigWidget *configWidgetFactory(Tool::Category category, ::Project *project) const;
+  virtual ToolConfigWidget *configWidgetFactory(Tool::Category category, Project& project) const;
 };
 
 } // namespace
