@@ -31,15 +31,15 @@ QString SDCC::Group::informationText() const
 const ::Tool::Base *SDCC::Group::base(Tool::Category category) const
 {
   if ( category==Tool::Category::Assembler || category==Tool::Category::Librarian )
-    return Tool::lister().group("gputils")->base(category);
+    return Tool::Lister::instance().group("gputils")->base(category);
   return Tool::Group::base(category);
 }
 
-Tool::Group::BaseData SDCC::Group::baseFactory(Tool::Category category) const
+Tool::Base* SDCC::Group::baseFactory(Tool::Category category) const
 {
-  if ( category==Tool::Category::Compiler ) return BaseData(new ::SDCC::Base, Both);
-  if ( category==Tool::Category::Linker)    return BaseData(new ::SDCC::Base, ProjectOnly);
-  return BaseData();
+  if ( category==Tool::Category::Compiler ) return new ::SDCC::Base;
+  if ( category==Tool::Category::Linker)    return new ::SDCC::Base;
+  return NULL;
 }
 
 SDCC::Group::Group()
@@ -61,14 +61,14 @@ QStringList SDCC::Group::checkDevicesOptions(uint i) const
 
 PURL::Directory SDCC::Group::internalAutodetectDirectory(Compile::DirectoryType type, const PURL::Directory &dir, Tool::ExecutableType execType) const
 {
-  return Tool::lister().group("gputils")->autodetectDirectory(type, dir, execType);
+  return Tool::Lister::instance().group("gputils")->autodetectDirectory(type, dir, execType);
 }
 
-bool SDCC::Group::needs(bool withProject, Tool::Category category) const
+bool SDCC::Group::needs(Tool::Category category) const
 {
   // doesn't need to assemble (compile already does that for us)
-  if ( category==Tool::Category::Librarian ) return Tool::lister().group("gputils")->needs(withProject, category);
-  return Tool::Group::needs(withProject, category);
+  if ( category==Tool::Category::Librarian ) return Tool::Lister::instance().group("gputils")->needs(category);
+  return Tool::Group::needs(category);
 }
 
 Compile::Process *SDCC::Group::processFactory(const Compile::Data &data) const
@@ -76,10 +76,9 @@ Compile::Process *SDCC::Group::processFactory(const Compile::Data &data) const
   switch (data.category.type()) {
     case Tool::Category::Assembler:
     case Tool::Category::Librarian:
-      return Tool::lister().group("gputils")->processFactory(data);
+      return Tool::Lister::instance().group("gputils")->processFactory(data);
     case Tool::Category::Compiler:
-      if (data.project) return new SDCC::CompileProjectFile;
-      return new SDCC::CompileStandaloneFile;
+      return new SDCC::CompileProjectFile;
     case Tool::Category::Linker:
       return new SDCC::LinkProjectFile;
     default: break;
@@ -87,7 +86,7 @@ Compile::Process *SDCC::Group::processFactory(const Compile::Data &data) const
   return 0;
 }
 
-Compile::Config *SDCC::Group::configFactory(::Project *project) const
+Compile::Config *SDCC::Group::configFactory(::Project& project) const
 {
   return new Config(project);
 }
