@@ -38,22 +38,22 @@ public:
   virtual uint nbCheckDevices() const { return SDCC::Nb_Families; }
   virtual bool hasDirectory(Compile::DirectoryType type) const { return type==Compile::DirectoryType::Header || type==Compile::DirectoryType::LinkerScript; }
   virtual PURL::FileType linkerScriptType() const { return PURL::Lkr; }
-  virtual PURL::Url linkerScript(const ::Project *project, Compile::LinkingType type) const { return Tool::lister().group("gputils")->linkerScript(project, type); }
+  virtual PURL::Url linkerScript(const ::Project& project, Compile::LinkingType type) const { return Tool::Lister::instance().group("gputils")->linkerScript(project, type); }
   virtual Tool::ExecutableType preferedExecutableType() const { return Tool::ExecutableType::Unix; }
   virtual Tool::CompileFileType compileFileType() const { return Tool::CompileFileType::Separate; }
   virtual Tool::Category checkDevicesCategory() const { return Tool::Category::Compiler; }
   virtual QStringList checkDevicesOptions(uint i) const;
-  virtual bool needs(bool withProject, Tool::Category category) const;
+  virtual bool needs(Tool::Category category) const;
   virtual PURL::FileType implementationType(PURL::ToolType type) const;
   virtual bool generateDebugInformation(const QString &device) const;
 
 private:
   Log::StringView _sview;
   PURL::TempFile  _checkDevicesTmp;
-  virtual BaseData baseFactory(Tool::Category category) const;
+  virtual ::Tool::Base* baseFactory(Tool::Category category) const;
   virtual QValueList<const Device::Data *> getSupportedDevices(const QString &s) const { return SDCC::getSupportedDevices(s); }
   virtual Compile::Process *processFactory(const Compile::Data &data) const;
-  virtual Compile::Config *configFactory(::Project *project) const;
+  virtual Compile::Config *configFactory(::Project& project) const;
   virtual Tool::SourceGenerator *sourceGeneratorFactory() const;
   virtual PURL::Directory internalAutodetectDirectory(Compile::DirectoryType type, const PURL::Directory &execDir, Tool::ExecutableType execType) const;
 };
