@@ -23,16 +23,7 @@ protected:
   virtual QStringList genericArguments(const Compile::Config &config) const;
   virtual QString outputFiles() const;
   virtual void logLine(::Process::OutputType type, const QString &line);
-  virtual bool hasLinkerScript() const { return ( _data.linkingType==Compile::Icd2DebugLinking || Main::toolGroup().hasCustomLinkerScript(_data.project) ); }
-};
-
-//-----------------------------------------------------------------------------
-class CompileStandaloneFile : public Process
-{
-Q_OBJECT
-private:
-  virtual QStringList genericArguments(const Compile::Config &config) const;
-  virtual QString outputFiles() const;
+  virtual bool hasLinkerScript() const { return ( _data.linkingType==Compile::Icd2DebugLinking || Main::toolGroup()->hasCustomLinkerScript(*_data.project) ); }
 };
 
 //-----------------------------------------------------------------------------
