@@ -1,14 +1,16 @@
 #include <pic18f452.h>
 
+int test = 0;
+
 void main(void)
 {
-  float f = TRISA;
+  float fvar = TRISA;
   int a = TRISB;
   LATA = 0xFF;
   LATAbits.LATA1 = 0;
 //       UIE = 0x55;
-  f /= a;
-  a = f;
+  fvar /= a;
+  a = fvar;
   TRISA = a;
   while(1);
 }
